@@ -24,15 +24,14 @@
 #include <glib/gstdio.h>
 #include <glib/gi18n.h>
 
+#include "gldi-icon-names.h"
 #include "cairo-dock-keyfile-utilities.h"
 #include "cairo-dock-gui-advanced.h"
 #include "cairo-dock-gui-simple.h"
 #include "cairo-dock-gui-manager.h"
-#include "cairo-dock-desklet-manager.h"
 #include "cairo-dock-dock-factory.h"
-#include "cairo-dock-module-manager.h"
-#include "cairo-dock-module-factory.h"
-#include "cairo-dock-notifications.h"
+#include "cairo-dock-desklet-manager.h"
+#include "cairo-dock-module-manager.h"  // gldi_module_get
 #include "cairo-dock-gui-simple.h"
 #include "cairo-dock-gui-backend.h"
 
@@ -82,7 +81,7 @@ GtkWidget *cairo_dock_make_switch_gui_button (void)
 	if (s_pMainGuiBackend->cTooltip)
 		gtk_widget_set_tooltip_text (pSwitchButton, s_pMainGuiBackend->cTooltip);
 	
-	GtkWidget *pImage = gtk_image_new_from_stock (GTK_STOCK_JUMP_TO, GTK_ICON_SIZE_BUTTON);
+	GtkWidget *pImage = gtk_image_new_from_icon_name (GLDI_ICON_NAME_JUMP_TO, GTK_ICON_SIZE_BUTTON);
 	gtk_button_set_image (GTK_BUTTON (pSwitchButton), pImage);
 	g_signal_connect (G_OBJECT (pSwitchButton), "clicked", G_CALLBACK(on_click_switch_mode), NULL);
 	return pSwitchButton;
@@ -132,7 +131,7 @@ static gboolean _update_module_state (gchar *cModuleName)
 {
 	if (s_pMainGuiBackend && s_pMainGuiBackend->update_module_state)
 	{
-		CairoDockModule *pModule = cairo_dock_find_module_from_name (cModuleName);
+		GldiModule *pModule = gldi_module_get (cModuleName);
 		if (pModule != NULL)
 		{
 			s_pMainGuiBackend->update_module_state (cModuleName, pModule->pInstancesList != NULL);
@@ -195,7 +194,7 @@ void cairo_dock_gui_trigger_reload_shortkeys (void)
 }
 
 
-void cairo_dock_gui_trigger_update_module_container (CairoDockModuleInstance *pInstance, gboolean bIsDetached)
+void cairo_dock_gui_trigger_update_module_container (GldiModuleInstance *pInstance, gboolean bIsDetached)
 {
 	if (s_pMainGuiBackend && s_pMainGuiBackend->update_module_instance_container)
 		s_pMainGuiBackend->update_module_instance_container (pInstance, bIsDetached);  // on n'a encore pas de moyen simple d'etre prevenu de la destruction de l'instance, donc on effectue l'action tout de suite. -> si, regarder l'icone ...
@@ -261,7 +260,7 @@ void cairo_dock_close_gui (void)
 		s_pMainGuiBackend->close_gui ();
 }
 
-void cairo_dock_show_items_gui (Icon *pIcon, CairoContainer *pContainer, CairoDockModuleInstance *pModuleInstance, int iShowPage)
+void cairo_dock_show_items_gui (Icon *pIcon, GldiContainer *pContainer, GldiModuleInstance *pModuleInstance, int iShowPage)
 {
 	GtkWidget *pWindow = NULL;
 	if (s_pMainGuiBackend && s_pMainGuiBackend->show_gui)
