@@ -26,19 +26,19 @@
 
 #include "config.h"
 #include "gldi-config.h"
-#include "cairo-dock-config.h"
-#include "cairo-dock-module-factory.h"
+#include "gldi-icon-names.h"
+#include "cairo-dock-module-manager.h"
+#include "cairo-dock-module-instance-manager.h"
 #include "cairo-dock-log.h"
 #include "cairo-dock-gui-factory.h"
 #include "cairo-dock-icon-facility.h"
 #include "cairo-dock-keyfile-utilities.h"
 #include "cairo-dock-animations.h"
 #include "cairo-dock-dialog-manager.h"
+#include "cairo-dock-icon-manager.h"  // cairo_dock_search_icon_size
 #include "cairo-dock-dock-manager.h"
 #include "cairo-dock-dock-factory.h"
-#include "cairo-dock-launcher-factory.h"
-#include "cairo-dock-desktop-file-factory.h"
-#include "cairo-dock-X-manager.h"
+#include "cairo-dock-desktop-manager.h"  // gldi_desktop_get_width
 #include "cairo-dock-gui-manager.h"
 #include "cairo-dock-gui-factory.h"
 #include "cairo-dock-gui-backend.h"
@@ -54,8 +54,6 @@
 #define CAIRO_DOCK_SIMPLE_PANEL_WIDTH 1200 // matttbe: 800
 #define CAIRO_DOCK_SIMPLE_PANEL_HEIGHT 700 // matttbe: 500
 
-#define CAIRO_DOCK_CATEGORY_ICON_SIZE 32  // a little bit larger than the tab icons (28px)
-
 typedef struct {
 	const gchar *cName;
 	const gchar *cIcon;
@@ -79,7 +77,6 @@ static CDCategoryEnum s_iCurrentCategory = 0;
 
 extern gchar *g_cCairoDockDataDir;
 extern CairoDock *g_pMainDock;
-extern CairoDockDesktopGeometry g_desktopGeometry;
 
 static CDWidget *_build_items_widget (void);
 static CDWidget *_build_config_widget (void);
@@ -92,7 +89,7 @@ static void cairo_dock_select_category (GtkWidget *pMainWindow, CDCategoryEnum i
 static CDCategory s_pCategories[CD_NB_CATEGORIES] = {
 	{
 		N_("Current items"),
-		"icon-all.svg",
+		CAIRO_DOCK_SHARE_DATA_DIR"/icons/icon-all.svg",
 		N_("Current items"),
 		_build_items_widget,
 		NULL,
@@ -100,7 +97,7 @@ static CDCategory s_pCategories[CD_NB_CATEGORIES] = {
 		NULL
 	},{
 		N_("Add-ons"),
-		"icon-plug-ins.svg",
+		CAIRO_DOCK_SHARE_DATA_DIR"/icons/icon-plug-ins.svg",
 		N_("Add-ons"),
 		_build_plugins_widget,
 		NULL,
@@ -108,7 +105,7 @@ static CDCategory s_pCategories[CD_NB_CATEGORIES] = {
 		NULL
 	},{
 		N_("Configuration"),
-		"gtk-preferences",
+		"preferences-system",
 		N_("Configuration"),
 		_build_config_widget,
 		NULL,
@@ -116,7 +113,7 @@ static CDCategory s_pCategories[CD_NB_CATEGORIES] = {
 		NULL
 	},{
 		N_("Themes"),
-		"icon-appearance.svg",
+		CAIRO_DOCK_SHARE_DATA_DIR"/icons/icon-appearance.svg",
 		N_("Themes"),
 		_build_themes_widget,
 		NULL,
@@ -188,18 +185,18 @@ GtkWidget *cairo_dock_build_generic_gui_window2 (const gchar *cTitle, int iWidth
 	if (cTitle != NULL)
 		gtk_window_set_title (GTK_WINDOW (pMainWindow), cTitle);
 	
-	GtkWidget *pMainVBox = _gtk_vbox_new (0*CAIRO_DOCK_FRAME_MARGIN);  // all elements will be packed in a VBox
+	GtkWidget *pMainVBox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0*CAIRO_DOCK_FRAME_MARGIN);  // all elements will be packed in a VBox
 	gtk_container_add (GTK_CONTAINER (pMainWindow), pMainVBox);
 	
 	//\_____________ add apply/quit buttons.
-	GtkWidget *pButtonsHBox = _gtk_hbox_new (CAIRO_DOCK_FRAME_MARGIN*2);
+	GtkWidget *pButtonsHBox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, CAIRO_DOCK_FRAME_MARGIN*2);
 	gtk_box_pack_end (GTK_BOX (pMainVBox),
 		pButtonsHBox,
 		FALSE,
 		FALSE,
 		0);
 	
-	GtkWidget *pQuitButton = gtk_button_new_from_stock (GTK_STOCK_CLOSE);
+	GtkWidget *pQuitButton = gtk_button_new_with_label (_("Close"));
 	g_signal_connect (G_OBJECT (pQuitButton), "clicked", G_CALLBACK(on_click_quit), pMainWindow);
 	gtk_box_pack_end (GTK_BOX (pButtonsHBox),
 		pQuitButton,
@@ -207,7 +204,7 @@ GtkWidget *cairo_dock_build_generic_gui_window2 (const gchar *cTitle, int iWidth
 		FALSE,
 		0);
 	
-	GtkWidget *pApplyButton = gtk_button_new_from_stock (GTK_STOCK_APPLY);
+	GtkWidget *pApplyButton = gtk_button_new_with_label (_("Apply"));
 	g_signal_connect (G_OBJECT (pApplyButton), "clicked", G_CALLBACK(on_click_apply), pMainWindow);
 	gtk_box_pack_end (GTK_BOX (pButtonsHBox),
 		pApplyButton,
@@ -225,9 +222,6 @@ GtkWidget *cairo_dock_build_generic_gui_window2 (const gchar *cTitle, int iWidth
 	
 	//\_____________ add a status-bar.
 	GtkWidget *pStatusBar = gtk_statusbar_new ();
-	#if (GTK_MAJOR_VERSION < 3)
-	gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (pStatusBar), FALSE);  // removed in GTK3 (gtk_window_set_has_resize_grip)
-	#endif
 	gtk_box_pack_start (GTK_BOX (pButtonsHBox),  // pMainVBox
 		pStatusBar,
 		FALSE,
@@ -237,8 +231,8 @@ GtkWidget *cairo_dock_build_generic_gui_window2 (const gchar *cTitle, int iWidth
 	
 	//\_____________ resize the window (placement is done later).
 	gtk_window_resize (GTK_WINDOW (pMainWindow),
-		MIN (iWidth, g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL]),
-		MIN (iHeight, g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL] - (g_pMainDock && g_pMainDock->container.bIsHorizontal ? g_pMainDock->iMaxDockHeight : 0)));
+		MIN (iWidth, gldi_desktop_get_width()),
+		MIN (iHeight, gldi_desktop_get_height() - (g_pMainDock && g_pMainDock->container.bIsHorizontal ? g_pMainDock->iMaxDockHeight : 0)));
 	
 	gtk_widget_show_all (pMainWindow);
 	
@@ -246,12 +240,13 @@ GtkWidget *cairo_dock_build_generic_gui_window2 (const gchar *cTitle, int iWidth
 }
 
 
-static inline GtkWidget *_make_image (const gchar *cImage, int iSize)
+/**static inline GtkWidget *_make_image (const gchar *cImage, int iSize)
 {
 	g_return_val_if_fail (cImage != NULL, NULL);
 	GtkWidget *pImage = NULL;
 	if (strncmp (cImage, "gtk-", 4) == 0)
 	{
+		
 		if (iSize >= 48)
 			iSize = GTK_ICON_SIZE_DIALOG;
 		else if (iSize >= 32)
@@ -281,12 +276,12 @@ static inline GtkWidget *_make_image (const gchar *cImage, int iSize)
 		}
 	}
 	return pImage;
-}
+}*/
 static GtkWidget *_make_notebook_label (const gchar *cLabel, const gchar *cImage, int iSize)
 {
-	GtkWidget *hbox = _gtk_hbox_new (CAIRO_DOCK_FRAME_MARGIN);
+	GtkWidget *hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, CAIRO_DOCK_FRAME_MARGIN);
 	
-	GtkWidget *pImage = _make_image (cImage, iSize);
+	GtkWidget *pImage = _gtk_image_new_from_file (cImage, iSize);
 	GtkWidget *pAlign = gtk_alignment_new (0.5, 0.5, 0., 1.);
 	gtk_alignment_set_padding (GTK_ALIGNMENT (pAlign), 0, 0, CAIRO_DOCK_FRAME_MARGIN, 0);
 	gtk_container_add (GTK_CONTAINER (pAlign), pImage);
@@ -316,14 +311,8 @@ static void _build_category_widget (CDCategory *pCategory)
 	gtk_widget_show_all (pCategory->pCdWidget->pWidget);
 }
 
-#if GTK_CHECK_VERSION (2, 22, 0)
 static void _on_switch_page (G_GNUC_UNUSED GtkNotebook *pNoteBook, GtkWidget *page, guint page_num, G_GNUC_UNUSED gpointer user_data)
 {
-#else
-static void _on_switch_page (GtkNotebook *pNoteBook, G_GNUC_UNUSED GtkNotebookPage *old_page, guint page_num, G_GNUC_UNUSED gpointer user_data)
-{
-	GtkWidget *page = gtk_notebook_get_nth_page (pNoteBook, page_num);
-#endif
 	CDCategory *pCategory = _get_category (page_num);
 	g_return_if_fail (pCategory != NULL);
 	if (pCategory->pCdWidget == NULL)
@@ -389,9 +378,9 @@ GtkWidget *cairo_dock_build_simple_gui_window (void)
 		
 		GtkWidget *hbox = _make_notebook_label (gettext (pCategory->cName),
 			pCategory->cIcon,
-			CAIRO_DOCK_CATEGORY_ICON_SIZE);
+			GTK_ICON_SIZE_LARGE_TOOLBAR);
 		gtk_size_group_add_widget (pSizeGroup, hbox);
-		GtkWidget *vbox = _gtk_vbox_new (CAIRO_DOCK_FRAME_MARGIN);
+		GtkWidget *vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, CAIRO_DOCK_FRAME_MARGIN);
 		gtk_notebook_append_page (GTK_NOTEBOOK (pNoteBook),
 			vbox,
 			hbox);
@@ -507,7 +496,7 @@ static void update_desklet_visibility_params (CairoDesklet *pDesklet)
 	}
 }
 
-static void update_module_instance_container (CairoDockModuleInstance *pInstance, gboolean bDetached)
+static void update_module_instance_container (GldiModuleInstance *pInstance, gboolean bDetached)
 {
 	if (s_pSimpleConfigWindow == NULL || pInstance == NULL)
 		return;
@@ -519,7 +508,7 @@ static void update_module_instance_container (CairoDockModuleInstance *pInstance
 	}
 }
 
-static GtkWidget *show_gui (Icon *pIcon, CairoContainer *pContainer, CairoDockModuleInstance *pModuleInstance, int iShowPage)
+static GtkWidget *show_gui (Icon *pIcon, GldiContainer *pContainer, GldiModuleInstance *pModuleInstance, int iShowPage)
 {
 	cairo_dock_build_simple_gui_window ();
 	
@@ -531,6 +520,15 @@ static GtkWidget *show_gui (Icon *pIcon, CairoContainer *pContainer, CairoDockMo
 	return s_pSimpleConfigWindow;
 }
 
+static GtkWidget *show_addons (void)
+{
+	cairo_dock_build_simple_gui_window ();
+	
+	cairo_dock_select_category (s_pSimpleConfigWindow, CD_CATEGORY_PLUGINS);  // will build the GTK widget
+	
+	return s_pSimpleConfigWindow;
+}
+
 static void reload_items (void)
 {
 	if (s_pSimpleConfigWindow == NULL)
@@ -588,7 +586,7 @@ static void set_status_message_on_gui (const gchar *cMessage)
 	gtk_statusbar_push (GTK_STATUSBAR (pStatusBar), 0, cMessage);
 }
 
-static void reload_current_widget (CairoDockModuleInstance *pInstance, int iShowPage)
+static void reload_current_widget (GldiModuleInstance *pInstance, int iShowPage)
 {
 	g_return_if_fail (s_pSimpleConfigWindow != NULL);
 	
@@ -599,12 +597,12 @@ static void reload_current_widget (CairoDockModuleInstance *pInstance, int iShow
 	}
 }
 
-static void show_module_instance_gui (CairoDockModuleInstance *pModuleInstance, int iShowPage)
+static void show_module_instance_gui (GldiModuleInstance *pModuleInstance, int iShowPage)
 {
 	show_gui (pModuleInstance->pIcon, NULL, pModuleInstance, iShowPage);
 }
 
-static CairoDockGroupKeyWidget *get_widget_from_name (G_GNUC_UNUSED CairoDockModuleInstance *pInstance, const gchar *cGroupName, const gchar *cKeyName)
+static CairoDockGroupKeyWidget *get_widget_from_name (G_GNUC_UNUSED GldiModuleInstance *pInstance, const gchar *cGroupName, const gchar *cKeyName)
 {
 	g_return_val_if_fail (s_pSimpleConfigWindow != NULL, NULL);
 	cd_debug ("%s (%s, %s)", __func__, cGroupName, cKeyName);
@@ -631,6 +629,7 @@ void cairo_dock_register_simple_gui_backend (void)
 	pBackend->update_modules_list 				= update_modules_list;
 	pBackend->update_shortkeys 					= update_shortkeys;
 	pBackend->show_gui 							= show_gui;
+	pBackend->show_addons 						= show_addons;
 	pBackend->reload_items 						= reload_items;
 	pBackend->reload 							= reload;
 	pBackend->cDisplayedName 					= _("Advanced Mode");  // name of the other backend.
