@@ -18,19 +18,21 @@
 */
 
 #include "config.h"
+#include "gldi-icon-names.h"
 #include "cairo-dock-struct.h"
 #include "cairo-dock-gui-factory.h"
+#include "cairo-dock-icon-manager.h"  // cairo_dock_search_icon_size
 #include "cairo-dock-gui-manager.h"
 #include "cairo-dock-container.h"
 #include "cairo-dock-log.h"
+#include "cairo-dock-menu.h"  // cairo_dock_add_in_menu_with_stock_and_data
 #include "cairo-dock-keyfile-utilities.h"
 #include "cairo-dock-keybinder.h"
 #include "cairo-dock-themes-manager.h"  // cairo_dock_update_conf_file
-#include "cairo-dock-X-manager.h"
+#include "cairo-dock-desktop-manager.h"  // gldi_desktop_get_width
 #include "cairo-dock-widget-shortkeys.h"
 
 #define CAIRO_DOCK_PREVIEW_HEIGHT 250
-extern CairoDockDesktopGeometry g_desktopGeometry;
 
 static void _shortkeys_widget_reload (CDWidget *pCdWidget);
 
@@ -68,11 +70,11 @@ static void _on_key_grab_cb (GtkWidget *pInputDialog, GdkEventKey *event, GtkTre
 		if (gtk_tree_selection_get_selected (pSelection, &pModel, &iter))  // we retrieve it from the current selection, this way if the binding has been destroyed meanwhile (very unlikely), we're safe.
 		{
 			// Bind the new shortkey
-			CairoKeyBinding *binding = NULL;
+			GldiShortkey *binding = NULL;
 			gtk_tree_model_get (pModel, &iter,
 				CD_SHORTKEY_MODEL_BINDING, &binding, -1);
 			
-			cd_keybinder_rebind (binding, key, NULL);
+			gldi_shortkey_rebind (binding, key, NULL);
 			
 			// update the model
 			gtk_list_store_set (GTK_LIST_STORE (pModel), &iter,
@@ -117,13 +119,13 @@ static void _cairo_dock_initiate_change_shortkey (G_GNUC_UNUSED GtkMenuItem *pMe
 	gtk_widget_add_events (pInputDialog, GDK_KEY_PRESS_MASK);
 	g_signal_connect (GTK_WIDGET(pInputDialog), "key-press-event", G_CALLBACK(_on_key_grab_cb), pTreeView);
 
-	GtkWidget *pMainVBox = _gtk_vbox_new (CAIRO_DOCK_FRAME_MARGIN);
+	GtkWidget *pMainVBox = gtk_box_new (GTK_ORIENTATION_VERTICAL, CAIRO_DOCK_FRAME_MARGIN);
 	gtk_container_add (GTK_CONTAINER (pInputDialog), pMainVBox);
 
 	GtkWidget *pLabel = gtk_label_new (_("Press the shortkey"));
 	gtk_box_pack_start(GTK_BOX (pMainVBox), pLabel, FALSE, FALSE, 0);
 
-	GtkWidget *pCancelButton = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
+	GtkWidget *pCancelButton = gtk_button_new_with_label (_("Cancel"));
 	g_signal_connect (G_OBJECT (pCancelButton), "clicked", G_CALLBACK(on_cancel_shortkey), pInputDialog);
 	gtk_box_pack_start (GTK_BOX (pMainVBox), pCancelButton, FALSE, FALSE, 0);
 
@@ -138,7 +140,7 @@ static gboolean _on_click_shortkey_tree_view (GtkTreeView *pTreeView, GdkEventBu
 		{
 			GtkWidget *pMenu = gtk_menu_new ();
 			
-			cairo_dock_add_in_menu_with_stock_and_data (_("Change the shortkey"), GTK_STOCK_PROPERTIES, G_CALLBACK (_cairo_dock_initiate_change_shortkey), pMenu, pTreeView);
+			cairo_dock_add_in_menu_with_stock_and_data (_("Change the shortkey"), GLDI_ICON_NAME_PROPERTIES, G_CALLBACK (_cairo_dock_initiate_change_shortkey), pMenu, pTreeView);
 			
 			gtk_widget_show_all (pMenu);
 			gtk_menu_popup (GTK_MENU (pMenu),
@@ -180,10 +182,14 @@ static void _cairo_dock_render_shortkey (G_GNUC_UNUSED GtkTreeViewColumn *tree_c
 	}
 	g_free (cShortkey);
 }
-void cairo_dock_add_shortkey_to_model (CairoKeyBinding *binding, GtkListStore *pModel)
+void cairo_dock_add_shortkey_to_model (GldiShortkey *binding, GtkListStore *pModel)
 {
-	//g_print (" + %s\n",  pModule->pVisitCard->cIconFilePath);
-	GdkPixbuf *pixbuf = gdk_pixbuf_new_from_file_at_size (binding->cIconFilePath, 32, 32, NULL);
+	cd_debug ("Add shortkey with image: ",  binding->cIconFilePath);
+	int iSize = cairo_dock_search_icon_size (GTK_ICON_SIZE_LARGE_TOOLBAR);
+	gchar *cIcon = cairo_dock_search_icon_s_path (binding->cIconFilePath,
+		iSize);
+	GdkPixbuf *pixbuf = gdk_pixbuf_new_from_file_at_size (cIcon, iSize, iSize, NULL);
+	g_free (cIcon);
 	GtkTreeIter iter;
 	memset (&iter, 0, sizeof (GtkTreeIter));
 	gtk_list_store_append (GTK_LIST_STORE (pModel), &iter);
@@ -208,7 +214,7 @@ static GtkWidget *cairo_dock_build_shortkeys_widget (void)
 		G_TYPE_BOOLEAN,  // grabbed or not
 		G_TYPE_POINTER);  // binding
 	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (pModel), CD_SHORTKEY_MODEL_NAME, GTK_SORT_ASCENDING);
-	cd_keybinder_foreach ((GFunc) cairo_dock_add_shortkey_to_model, pModel);
+	gldi_shortkeys_foreach ((GFunc) cairo_dock_add_shortkey_to_model, pModel);
 	
 	// make the treeview
 	GtkWidget *pOneWidget = gtk_tree_view_new_with_model (GTK_TREE_MODEL (pModel));
@@ -252,9 +258,13 @@ ShortkeysWidget *cairo_dock_shortkeys_widget_new (void)
 	pShortkeysWidget->pShortKeysTreeView = cairo_dock_build_shortkeys_widget ();
 	
 	GtkWidget *pScrolledWindow = gtk_scrolled_window_new (NULL, NULL);
-	g_object_set (pScrolledWindow, "height-request", MIN (2*CAIRO_DOCK_PREVIEW_HEIGHT, gldi_get_desktop_height() - 175), NULL);
+	g_object_set (pScrolledWindow, "height-request", MIN (2*CAIRO_DOCK_PREVIEW_HEIGHT, gldi_desktop_get_height() - 175), NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (pScrolledWindow), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+	#if GTK_CHECK_VERSION (3, 8, 0)
+	gtk_container_add (GTK_CONTAINER (pScrolledWindow), pShortkeysWidget->pShortKeysTreeView);
+	#else
 	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (pScrolledWindow), pShortkeysWidget->pShortKeysTreeView);
+	#endif
 	
 	pShortkeysWidget->widget.pWidget = pScrolledWindow;
 	
@@ -268,5 +278,5 @@ static void _shortkeys_widget_reload (CDWidget *pCdWidget)
 	GtkTreeModel *pModel = gtk_tree_view_get_model (GTK_TREE_VIEW (pShortkeysWidget->pShortKeysTreeView));
 	g_return_if_fail (pModel != NULL);
 	gtk_list_store_clear (GTK_LIST_STORE (pModel));
-	cd_keybinder_foreach ((GFunc) cairo_dock_add_shortkey_to_model, pModel);
+	gldi_shortkeys_foreach ((GFunc) cairo_dock_add_shortkey_to_model, pModel);
 }
