@@ -397,7 +397,7 @@ int main (int argc, char** argv)
 		// below options are probably useless for most of people.
 		{"keep-above", 'a', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
 			&bKeepAbove,
-			_("Keep the dock above other windows whatever."), NULL},
+			_("Keep the dock above other windows."), NULL},
 		{"no-sticky", 's', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
 			&bNoSticky,
 			_("Don't make the dock appear on all desktops."), NULL},
@@ -762,7 +762,7 @@ int main (int argc, char** argv)
 		}
 		else
 			cThemeName = "Default-Single";
-		gchar *cCommand = g_strdup_printf ("/bin/cp -r \"%s/%s\"/* \"%s\"", CAIRO_DOCK_SHARE_DATA_DIR"/themes", cThemeName, g_cCurrentThemePath);
+		gchar *cCommand = g_strdup_printf ("cp -r \"%s/%s\"/* \"%s\"", CAIRO_DOCK_SHARE_DATA_DIR"/themes", cThemeName, g_cCurrentThemePath);
 		cd_message (cCommand);
 		int r = system (cCommand);
 		if (r < 0)
