@@ -27,14 +27,14 @@
 #include "cairo-dock-dock-facility.h" // input shapes
 #include "cairo-dock-draw.h"  // for transitions
 #include "cairo-dock-draw-opengl.h"  // idem
-#include "cairo-dock-dialog-manager.h"  // cairo_dock_replace_all_dialogs
-#include "cairo-dock-applications-manager.h"  // cairo_dock_search_window_overlapping_dock
+#include "cairo-dock-desklet-manager.h"  // CAIRO_CONTAINER_IS_OPENGL
+#include "cairo-dock-dialog-manager.h"  // gldi_dialogs_replace_all
 #include "cairo-dock-dock-manager.h"
+#include "cairo-dock-applications-manager.h"  // myTaskbarParam.cAnimationOnDemandsAttention
+#include "cairo-dock-dock-visibility.h"  // gldi_dock_search_overlapping_window
 #include "cairo-dock-log.h"
-#include "cairo-dock-notifications.h"
 #include "cairo-dock-backends-manager.h"
 #include "cairo-dock-container.h"
-#include "cairo-dock-overlay.h"
 #include "cairo-dock-animations.h"
 
 extern gboolean g_bUseOpenGL;
@@ -51,9 +51,8 @@ static gboolean _update_fade_out_dock (G_GNUC_UNUSED gpointer pUserData, CairoDo
 		pDock->bFadeInOut = FALSE;
 		//g_print ("set below\n");
 		gtk_window_set_keep_below (GTK_WINDOW (pDock->container.pWidget), TRUE);
-		// si fenetre maximisee, on met direct iFadeCounter a 0.  // malheureusement X met du temps a faire passer le dock derriere, et ca donne un "sursaut" :-/
-		///if (cairo_dock_search_window_covering_dock (pDock, FALSE, FALSE) != NULL)
-		///	pDock->iFadeCounter = 0;
+		// si fenetre maximisee, on met direct iFadeCounter a 0.
+		// malheureusement X met du temps a faire passer le dock derriere, et ca donne un "sursaut" :-/
 	}
 	
 	//g_print ("pDock->iFadeCounter : %d\n", pDock->iFadeCounter);
@@ -63,14 +62,14 @@ static gboolean _update_fade_out_dock (G_GNUC_UNUSED gpointer pUserData, CairoDo
 	}
 	else
 	{
-		cairo_dock_remove_notification_func_on_object (pDock,
+		gldi_object_remove_notification (pDock,
 			NOTIFICATION_UPDATE,
-			(CairoDockNotificationFunc) _update_fade_out_dock,
+			(GldiNotificationFunc) _update_fade_out_dock,
 			NULL);
 	}
 	
 	cairo_dock_redraw_container (CAIRO_CONTAINER (pDock));
-	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
+	return GLDI_NOTIFICATION_LET_PASS;
 }
 
 void cairo_dock_pop_up (CairoDock *pDock)
@@ -78,9 +77,9 @@ void cairo_dock_pop_up (CairoDock *pDock)
 	//g_print ("%s (%d)\n", __func__, pDock->bIsBelow);
 	if (pDock->bIsBelow)
 	{
-		cairo_dock_remove_notification_func_on_object (pDock,
+		gldi_object_remove_notification (pDock,
 			NOTIFICATION_UPDATE,
-			(CairoDockNotificationFunc) _update_fade_out_dock,
+			(GldiNotificationFunc) _update_fade_out_dock,
 			NULL);
 		pDock->iFadeCounter = 0;
 		cairo_dock_redraw_container (CAIRO_CONTAINER (pDock));
@@ -95,14 +94,14 @@ void cairo_dock_pop_down (CairoDock *pDock)
 	//g_print ("%s (%d, %d)\n", __func__, pDock->bIsBelow, pDock->container.bInside);
 	if (! pDock->bIsBelow && pDock->iVisibility == CAIRO_DOCK_VISI_KEEP_BELOW && ! pDock->container.bInside)
 	{
-		if (cairo_dock_search_window_overlapping_dock (pDock) != NULL)
+		if (gldi_dock_search_overlapping_window (pDock) != NULL)
 		{
 			pDock->iFadeCounter = 0;
 			pDock->bFadeInOut = TRUE;
-			cairo_dock_register_notification_on_object (pDock,
+			gldi_object_register_notification (pDock,
 				NOTIFICATION_UPDATE,
-				(CairoDockNotificationFunc) _update_fade_out_dock,
-				CAIRO_DOCK_RUN_FIRST, NULL);
+				(GldiNotificationFunc) _update_fade_out_dock,
+				GLDI_RUN_FIRST, NULL);
 			if (g_pKeepingBelowBackend != NULL && g_pKeepingBelowBackend->init)
 				g_pKeepingBelowBackend->init (pDock);
 			cairo_dock_launch_animation (CAIRO_CONTAINER (pDock));
@@ -136,7 +135,7 @@ gfloat cairo_dock_calculate_magnitude (gint iMagnitudeIndex)  // merci a Robrob
 }
 
 
-void cairo_dock_launch_animation (CairoContainer *pContainer)
+void cairo_dock_launch_animation (GldiContainer *pContainer)
 {
 	if (pContainer->iSidGLAnimation == 0 && pContainer->iface.animation_loop != NULL)
 	{
@@ -180,7 +179,7 @@ void cairo_dock_start_hiding (CairoDock *pDock)
 		pDock->bIsHiding = TRUE;
 		
 		// empty the input shape (so that the dock doesn't disturb us immediately)
-		if (pDock->pHiddenShapeBitmap && pDock->iInputState != CAIRO_DOCK_INPUT_HIDDEN)
+		if (pDock->iInputState != CAIRO_DOCK_INPUT_HIDDEN)  // if pDock->pHiddenShapeBitmap == NULL (at the beginning), set iInputState anyway, so that when the input-shapes are created, pDock->pHiddenShapeBitmap will be applied to the dock.
 		{
 			//g_print ("+++ input shape hidden on start hiding\n");
 			cairo_dock_set_input_shape_hidden (pDock);
@@ -223,7 +222,7 @@ void cairo_dock_start_showing (CairoDock *pDock)
 			cairo_dock_set_input_shape_at_rest (pDock);
 			pDock->iInputState = CAIRO_DOCK_INPUT_AT_REST;
 			
-			cairo_dock_replace_all_dialogs ();
+			gldi_dialogs_replace_all ();
 		}
 		
 		// init the animation
@@ -236,9 +235,11 @@ void cairo_dock_start_showing (CairoDock *pDock)
 }
 
 
-void cairo_dock_start_icon_animation (Icon *pIcon, CairoDock *pDock)
+void gldi_icon_start_animation (Icon *pIcon)
 {
-	g_return_if_fail (pIcon != NULL && pDock != NULL);
+	g_return_if_fail (pIcon != NULL);
+	CairoDock *pDock = CAIRO_DOCK (cairo_dock_get_icon_container(pIcon));
+	g_return_if_fail (CAIRO_DOCK_IS_DOCK (pDock));  // currently only animate icons that are inside a dock
 	cd_message ("%s (%s, %d)", __func__, pIcon->cName, pIcon->iAnimationState);
 	
 	if (pIcon->iAnimationState != CAIRO_DOCK_STATE_REST &&
@@ -249,27 +250,30 @@ void cairo_dock_start_icon_animation (Icon *pIcon, CairoDock *pDock)
 	}
 }
 
-void cairo_dock_request_icon_animation (Icon *pIcon, CairoContainer *pContainer, const gchar *cAnimation, int iNbRounds)
+void gldi_icon_request_animation (Icon *pIcon, const gchar *cAnimation, int iNbRounds)
 {
-	CairoDock *pDock;
-	if (! CAIRO_DOCK_IS_DOCK (pContainer))  // at the moment, only docks can animate their icons
-		return;
-	else
-		pDock = CAIRO_DOCK (pContainer);
+	CairoDock *pDock = CAIRO_DOCK (cairo_dock_get_icon_container(pIcon));
+	g_return_if_fail (CAIRO_DOCK_IS_DOCK (pDock));  // currently only animate icons that are inside a dock
+	
 	if (pIcon->iAnimationState != CAIRO_DOCK_STATE_REST)  // on le fait avant de changer d'animation, pour le cas ou l'icone ne serait plus placee au meme endroit (rebond).
 		cairo_dock_redraw_container (CAIRO_CONTAINER (pDock));
-	cairo_dock_stop_icon_animation (pIcon);
+	gldi_icon_stop_animation (pIcon);
 	
 	if (cAnimation == NULL || iNbRounds == 0 || pIcon->iAnimationState != CAIRO_DOCK_STATE_REST)
 		return ;
-	cairo_dock_notify_on_object (pIcon, NOTIFICATION_REQUEST_ICON_ANIMATION, pIcon, pDock, cAnimation, iNbRounds);
-	cairo_dock_start_icon_animation (pIcon, pDock);
+	gldi_object_notify (pIcon, NOTIFICATION_REQUEST_ICON_ANIMATION, pIcon, pDock, cAnimation, iNbRounds);
+	gldi_icon_start_animation (pIcon);
 }
 
-void cairo_dock_request_icon_attention (Icon *pIcon, CairoDock *pDock, const gchar *cAnimation, int iNbRounds)
+void gldi_icon_request_attention (Icon *pIcon, const gchar *cAnimation, int iNbRounds)
 {
+	CairoDock *pDock = CAIRO_DOCK (cairo_dock_get_icon_container(pIcon));
+	g_return_if_fail (CAIRO_DOCK_IS_DOCK (pDock));  // currently only animate icons that are inside a dock
+	
 	// stop any current animation
-	cairo_dock_stop_icon_animation (pIcon);
+	gldi_icon_stop_animation (pIcon);
+	if (pIcon->iAnimationState != CAIRO_DOCK_STATE_REST)
+		return ;
 	
 	// set the 'attention animation' flag
 	pIcon->bIsDemandingAttention = TRUE;
@@ -285,7 +289,7 @@ void cairo_dock_request_icon_attention (Icon *pIcon, CairoDock *pDock, const gch
 			cAnimation = "rotate";
 	}
 	
-	cairo_dock_request_icon_animation (pIcon, CAIRO_CONTAINER (pDock), cAnimation, iNbRounds);
+	gldi_icon_request_animation (pIcon, cAnimation, iNbRounds);
 	cairo_dock_mark_icon_as_clicked (pIcon);  // pour eviter qu'un simple survol ne stoppe l'animation.
 	
 	// if the icon is in a sub-dock, also animate the main icon.
@@ -295,21 +299,23 @@ void cairo_dock_request_icon_attention (Icon *pIcon, CairoDock *pDock, const gch
 		Icon *pPointingIcon = cairo_dock_search_icon_pointing_on_dock (pDock, &pParentDock);
 		if (pPointingIcon != NULL)
 		{
-			cairo_dock_request_icon_attention (pPointingIcon, pParentDock, cAnimation, iNbRounds);
+			gldi_icon_request_attention (pPointingIcon, cAnimation, iNbRounds);
 		}
 	}
 	else if (pDock->iVisibility == CAIRO_DOCK_VISI_KEEP_BELOW && pDock->bIsBelow)
 		cairo_dock_pop_up (pDock);
 }
 
-void cairo_dock_stop_icon_attention (Icon *pIcon, CairoDock *pDock)
+void gldi_icon_stop_attention (Icon *pIcon)
 {
 	if (! pIcon->bIsDemandingAttention)
 		return;
 	cd_debug ("%s (%s)", __func__, pIcon->cName);
-	cairo_dock_stop_icon_animation (pIcon);
-	//cairo_dock_redraw_icon (pIcon, CAIRO_CONTAINER (pDock));  // a faire avant, lorsque l'icone est encore en mode demande d'attention.
+	gldi_icon_stop_animation (pIcon);
 	pIcon->bIsDemandingAttention = FALSE;
+	
+	CairoDock *pDock = CAIRO_DOCK (cairo_dock_get_icon_container(pIcon));
+	g_return_if_fail (pDock != NULL);
 	gtk_widget_queue_draw (pDock->container.pWidget);  // redraw all the dock, since the animation of the icon can be larger than the icon itself.
 	
 	// on stoppe la demande d'attention recursivement vers le bas.
@@ -328,7 +334,7 @@ void cairo_dock_stop_icon_attention (Icon *pIcon, CairoDock *pDock)
 			Icon *pPointingIcon = cairo_dock_search_icon_pointing_on_dock (pDock, &pParentDock);
 			if (pPointingIcon != NULL)
 			{
-				cairo_dock_stop_icon_attention (pPointingIcon, pParentDock);
+				gldi_icon_stop_attention (pPointingIcon);
 			}
 		}
 	}
@@ -341,16 +347,16 @@ void cairo_dock_stop_icon_attention (Icon *pIcon, CairoDock *pDock)
 
 void cairo_dock_trigger_icon_removal_from_dock (Icon *pIcon)
 {
-	CairoDock *pDock = cairo_dock_search_dock_from_name (pIcon->cParentDockName);
+	CairoDock *pDock = CAIRO_DOCK (cairo_dock_get_icon_container(pIcon));
 	if (pDock != NULL)
 	{
-		cairo_dock_stop_icon_animation (pIcon);
+		gldi_icon_stop_animation (pIcon);
 		if (cairo_dock_animation_will_be_visible (pDock))  // sinon inutile de se taper toute l'animation.
 			pIcon->fInsertRemoveFactor = 1.0;
 		else
 			pIcon->fInsertRemoveFactor = 0.05;
-		cairo_dock_notify_on_object (pDock, NOTIFICATION_REMOVE_ICON, pIcon, pDock);
-		cairo_dock_start_icon_animation (pIcon, pDock);
+		gldi_object_notify (pDock, NOTIFICATION_REMOVE_ICON, pIcon, pDock);
+		gldi_icon_start_animation (pIcon);
 	}
 }
 
@@ -371,93 +377,16 @@ void cairo_dock_stop_marking_icon_animation_as (Icon *pIcon, CairoDockAnimationS
 }
 
 
-void cairo_dock_update_removing_inserting_icon_size_default (Icon *icon)
-{
-	icon->fInsertRemoveFactor *= .85;
-	if (icon->fInsertRemoveFactor > 0)
-	{
-		if (icon->fInsertRemoveFactor < 0.05)
-			icon->fInsertRemoveFactor = 0.05;
-	}
-	else if (icon->fInsertRemoveFactor < 0)
-	{
-		if (icon->fInsertRemoveFactor > -0.05)
-			icon->fInsertRemoveFactor = -0.05;
-	}
-}
-
-
-gboolean cairo_dock_update_inserting_removing_icon_notification (G_GNUC_UNUSED gpointer pUserData, Icon *pIcon, CairoDock *pDock, gboolean *bContinueAnimation)
-{
-	if (pIcon->iGlideDirection != 0)
-	{
-		pIcon->fGlideOffset += pIcon->iGlideDirection * .1;
-		if (fabs (pIcon->fGlideOffset) > .99)
-		{
-			pIcon->fGlideOffset = pIcon->iGlideDirection;
-			pIcon->iGlideDirection = 0;
-		}
-		else if (fabs (pIcon->fGlideOffset) < .01)
-		{
-			pIcon->fGlideOffset = 0;
-			pIcon->iGlideDirection = 0;
-		}
-		*bContinueAnimation = TRUE;
-		cairo_dock_redraw_container (CAIRO_CONTAINER (pDock));
-	}
-	
-	if (pIcon->fInsertRemoveFactor == 0)
-		pIcon->bBeingRemovedByCairo = FALSE;
-	if (! pIcon->bBeingRemovedByCairo)
-		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
-	
-	cairo_dock_update_removing_inserting_icon_size_default (pIcon);
-	
-	if (fabs (pIcon->fInsertRemoveFactor) > 0.05)
-	{
-		cairo_dock_mark_icon_as_inserting_removing (pIcon);
-		*bContinueAnimation = TRUE;
-	}
-	cairo_dock_redraw_container (CAIRO_CONTAINER (pDock));
-	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
-}
-
-gboolean cairo_dock_on_insert_remove_icon_notification (G_GNUC_UNUSED gpointer pUserData, Icon *pIcon, G_GNUC_UNUSED CairoDock *pDock)
-{
-	if (pIcon->iAnimationState == CAIRO_DOCK_STATE_REMOVE_INSERT)  // already in insert/remove state
-		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
-	
-	if (pIcon->fInsertRemoveFactor == 0)  // animation not needed.
-		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
-	
-	cairo_dock_mark_icon_as_inserting_removing (pIcon);  // On prend en charge le dessin de l'icone pendant sa phase d'insertion/suppression.
-	
-	///if (fabs (pIcon->fInsertRemoveFactor) < .1)  // useless or not needed animation.
-	///	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
-	
-	pIcon->bBeingRemovedByCairo = TRUE;
-	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
-}
-
-gboolean cairo_dock_stop_inserting_removing_icon_notification (G_GNUC_UNUSED gpointer pUserData, Icon *pIcon)
-{
-	pIcon->fGlideOffset = 0;
-	pIcon->iGlideDirection = 0;
-	pIcon->bBeingRemovedByCairo = FALSE;
-	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
-}
-
-
 
 #define cairo_dock_get_transition(pIcon) (pIcon)->pTransition
 
 #define cairo_dock_set_transition(pIcon, transition) (pIcon)->pTransition = transition
 
-static gboolean _cairo_dock_transition_step (G_GNUC_UNUSED gpointer pUserData, Icon *pIcon, CairoContainer *pContainer, gboolean *bContinueAnimation)
+static gboolean _cairo_dock_transition_step (G_GNUC_UNUSED gpointer pUserData, Icon *pIcon, GldiContainer *pContainer, gboolean *bContinueAnimation)
 {
 	CairoDockTransition *pTransition = cairo_dock_get_transition (pIcon);
 	if (pTransition == NULL)
-		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
+		return GLDI_NOTIFICATION_LET_PASS;
 	
 	pTransition->iCount ++;
 	int iDetlaT = (pTransition->bFastPace ? cairo_dock_get_animation_delta_t (pContainer) : cairo_dock_get_slow_animation_delta_t (pContainer));
@@ -467,18 +396,18 @@ static gboolean _cairo_dock_transition_step (G_GNUC_UNUSED gpointer pUserData, I
 		pTransition->iElapsedTime = pTransition->iDuration;
 	
 	if (! pTransition->bRemoveWhenFinished && pTransition->iDuration != 0 && pTransition->iElapsedTime >= pTransition->iDuration)  // skip
-		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
+		return GLDI_NOTIFICATION_LET_PASS;
 	
 	gboolean bContinue = FALSE;
 	if (CAIRO_CONTAINER_IS_OPENGL (pTransition->pContainer))
 	{
 		if (pTransition->render_opengl)
 		{
-			if (! cairo_dock_begin_draw_icon (pIcon, pContainer, 0))
-				return CAIRO_DOCK_LET_PASS_NOTIFICATION;
+			if (! cairo_dock_begin_draw_icon (pIcon, 0))
+				return GLDI_NOTIFICATION_LET_PASS;
 			bContinue = pTransition->render_opengl (pIcon, pTransition->pUserData);
-			cairo_dock_end_draw_icon (pIcon, pContainer);
-			cairo_dock_redraw_icon (pIcon, pContainer);
+			cairo_dock_end_draw_icon (pIcon);
+			cairo_dock_redraw_icon (pIcon);
 		}
 		else if (pTransition->render != NULL)
 		{
@@ -502,9 +431,9 @@ static gboolean _cairo_dock_transition_step (G_GNUC_UNUSED gpointer pUserData, I
 	{
 		*bContinueAnimation = TRUE;
 	}
-	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
+	return GLDI_NOTIFICATION_LET_PASS;
 }
-void cairo_dock_set_transition_on_icon (Icon *pIcon, CairoContainer *pContainer, CairoDockTransitionRenderFunc render_step_cairo, CairoDockTransitionGLRenderFunc render_step_opengl, gboolean bFastPace, gint iDuration, gboolean bRemoveWhenFinished, gpointer pUserData, GFreeFunc pFreeUserDataFunc)
+void cairo_dock_set_transition_on_icon (Icon *pIcon, GldiContainer *pContainer, CairoDockTransitionRenderFunc render_step_cairo, CairoDockTransitionGLRenderFunc render_step_opengl, gboolean bFastPace, gint iDuration, gboolean bRemoveWhenFinished, gpointer pUserData, GFreeFunc pFreeUserDataFunc)
 {
 	cairo_dock_remove_transition_on_icon (pIcon);
 	
@@ -519,10 +448,10 @@ void cairo_dock_set_transition_on_icon (Icon *pIcon, CairoContainer *pContainer,
 	pTransition->pFreeUserDataFunc = pFreeUserDataFunc;
 	cairo_dock_set_transition (pIcon, pTransition);
 	
-	cairo_dock_register_notification_on_object (pIcon,
+	gldi_object_register_notification (pIcon,
 		bFastPace ? NOTIFICATION_UPDATE_ICON : NOTIFICATION_UPDATE_ICON_SLOW,
-		(CairoDockNotificationFunc) _cairo_dock_transition_step,
-		CAIRO_DOCK_RUN_AFTER, pUserData);
+		(GldiNotificationFunc) _cairo_dock_transition_step,
+		GLDI_RUN_AFTER, pUserData);
 	
 	cairo_dock_launch_animation (pContainer);
 }
@@ -533,9 +462,9 @@ void cairo_dock_remove_transition_on_icon (Icon *pIcon)
 	if (pTransition == NULL)
 		return ;
 	
-	cairo_dock_remove_notification_func_on_object (pIcon,
+	gldi_object_remove_notification (pIcon,
 		pTransition->bFastPace ? NOTIFICATION_UPDATE_ICON : NOTIFICATION_UPDATE_ICON_SLOW,
-		(CairoDockNotificationFunc) _cairo_dock_transition_step,
+		(GldiNotificationFunc) _cairo_dock_transition_step,
 		pTransition->pUserData);
 	
 	if (pTransition->pFreeUserDataFunc != NULL)
