@@ -307,13 +307,16 @@ static gboolean _on_window_state_changed (G_GNUC_UNUSED gpointer data, GldiWindo
 	return GLDI_NOTIFICATION_LET_PASS;
 }
 
-static gboolean _on_window_class_changed (G_GNUC_UNUSED gpointer data, GldiWindowActor *actor, G_GNUC_UNUSED const gchar *cOldClass, G_GNUC_UNUSED const gchar *cOldWmClass)
+static gboolean _on_window_class_changed (G_GNUC_UNUSED gpointer data, GldiWindowActor *actor, const gchar *cOldClass, G_GNUC_UNUSED const gchar *cOldWmClass)
 {
 	Icon *icon = _get_appli_icon (actor);
 	if (icon == NULL)
 		return GLDI_NOTIFICATION_LET_PASS;
 	
 	// remove the icon from the dock, and then from its class
+	gchar *tmp = actor->cClass;
+	actor->cClass = (gchar*)cOldClass;  // temporarily set the old class to the actor, so that we can detach it from inhibitors
+	
 	CairoDock *pParentDock = NULL;
 	if (cairo_dock_get_icon_container (icon) != NULL)  // if in a dock, detach it
 		pParentDock = gldi_appli_icon_detach (icon);
@@ -321,6 +324,8 @@ static gboolean _on_window_class_changed (G_GNUC_UNUSED gpointer data, GldiWindo
 		gldi_window_detach_from_inhibitors (actor);
 	cairo_dock_remove_appli_from_class (icon);
 	
+	actor->cClass = tmp;
+	
 	// set the new class
 	g_free (icon->cClass);
 	icon->cClass = g_strdup (actor->cClass);
@@ -744,7 +749,6 @@ static gboolean get_config (GKeyFile *pKeyFile, CairoTaskbarParam *pTaskBar)
 		pTaskBar->bAppliOnCurrentDesktopOnly = cairo_dock_get_boolean_key_value (pKeyFile, "TaskBar", "current desktop only", &bFlushConfFileNeeded, FALSE, "Applications", NULL);
 		
 		pTaskBar->bMixLauncherAppli = cairo_dock_get_boolean_key_value (pKeyFile, "TaskBar", "mix launcher appli", &bFlushConfFileNeeded, TRUE, NULL, NULL);
-		pTaskBar->bOpeningAnimation = cairo_dock_get_boolean_key_value (pKeyFile, "TaskBar", "opening animation", &bFlushConfFileNeeded, TRUE, NULL, NULL);
 
 		pTaskBar->bGroupAppliByClass = cairo_dock_get_boolean_key_value (pKeyFile, "TaskBar", "group by class", &bFlushConfFileNeeded, TRUE, "Applications", NULL);
 		pTaskBar->cGroupException = cairo_dock_get_string_key_value (pKeyFile, "TaskBar", "group exception", &bFlushConfFileNeeded, "pidgin;xchat", NULL, NULL);
@@ -845,7 +849,6 @@ static void reload (CairoTaskbarParam *pPrevTaskBar, CairoTaskbarParam *pTaskBar
 		|| pPrevTaskBar->bHideVisibleApplis != pTaskBar->bHideVisibleApplis
 		|| pPrevTaskBar->bAppliOnCurrentDesktopOnly != pTaskBar->bAppliOnCurrentDesktopOnly
 		|| pPrevTaskBar->bMixLauncherAppli != pTaskBar->bMixLauncherAppli
-		|| pPrevTaskBar->bOpeningAnimation != pTaskBar->bOpeningAnimation
 		|| pPrevTaskBar->bOverWriteXIcons != pTaskBar->bOverWriteXIcons
 		|| pPrevTaskBar->iMinimizedWindowRenderType != pTaskBar->iMinimizedWindowRenderType
 		|| pPrevTaskBar->iAppliMaxNameLength != pTaskBar->iAppliMaxNameLength
