@@ -21,8 +21,6 @@
 #ifndef __CAIRO_DOCK_CLASS_MANAGER__
 #define  __CAIRO_DOCK_CLASS_MANAGER__
 
-#include <X11/Xlib.h>
-
 #include "cairo-dock-struct.h"
 G_BEGIN_DECLS
 
@@ -52,6 +50,9 @@ struct _CairoDockClassAppli {
 	GList *pMenuItems;
 	gint iAge;  // age of the first created window of this class
 	gchar *cDockName;  // unique name of the class sub-dock
+	guint iSidOpeningTimeout;  // timeout to stop the launching, if not stopped by the application before
+	gboolean bIsLaunching;  // flag to mark a class as being launched
+	gboolean bHasStartupNotify;  // TRUE if the application sends a "remove" event when its launch is complete (not used yet)
 };
 
 /*
@@ -68,22 +69,14 @@ const GList *cairo_dock_list_existing_appli_with_class (const gchar *cClass);
 
 CairoDock *cairo_dock_get_class_subdock (const gchar *cClass);
 
-gchar *cairo_dock_get_class_subdock_name (const gchar *cClass);
-
 CairoDock* cairo_dock_create_class_subdock (const gchar *cClass, CairoDock *pParentDock);
 
-/*
-* Enregistre une icone de lanceur/applet dans sa classe. N'inhinibe pas la classe.
-* @param pIcon l'inhibiteur.
-* @return TRUE si l'enregistrement s'est effectue correctement ou si l'icone etait deja enregistree, FALSE sinon.
-*/
-//gboolean cairo_dock_add_inhibitor_to_class (const gchar *cClass, Icon *pIcon);
 /*
 * Enregistre une icone d'appli dans sa classe. Ne fais rien aux inhibiteurs.
 * @param pIcon l'icone de l'appli.
 * @return TRUE si l'enregistrement s'est effectue correctement ou si l'appli etait deja enregistree, FALSE sinon.
 */
-gboolean cairo_dock_add_appli_to_class (Icon *pIcon);
+gboolean cairo_dock_add_appli_icon_to_class (Icon *pIcon);
 /*
 * Desenregistre une icone d'appli de sa classe. Ne fais rien aux inhibiteurs.
 * @param pIcon l'icone de l'appli.
@@ -145,10 +138,10 @@ gboolean cairo_dock_prevent_inhibited_class (Icon *pIcon);
 void cairo_dock_deinhibite_class (const gchar *cClass, Icon *pInhibitorIcon);
 /*
 * Met a jour les inhibiteurs controlant une appli donnee pour leur en faire controler une autre.
-* @param Xid l'ID de l'appli.
+* @param pAppli l'appli.
 * @param cClass sa classe.
 */
-void cairo_dock_detach_Xid_from_inhibitors (Window Xid, const gchar *cClass);
+void gldi_window_detach_from_inhibitors (GldiWindowActor *pAppli);
 /*
 * Enleve toutes les applis de toutes les classes, et met a jour les inhibiteurs.
 */
@@ -158,8 +151,6 @@ void cairo_dock_remove_all_applis_from_class_table (void);
 */
 void cairo_dock_reset_class_table (void);
 
-
-cairo_surface_t *cairo_dock_duplicate_inhibitor_surface_for_appli (Icon *pInhibitorIcon, int iWidth, int ifHeight);
 /*
 * Cree la surface d'une appli en utilisant le lanceur correspondant, si la classe n'utilise pas les icones X.
 * @param cClass la classe.
@@ -171,27 +162,14 @@ cairo_surface_t *cairo_dock_duplicate_inhibitor_surface_for_appli (Icon *pInhibi
 */
 cairo_surface_t *cairo_dock_create_surface_from_class (const gchar *cClass, int iWidth, int ifHeight);
 
-/*
-* Met a jour les inhibiteurs controlant une appli donnee pour les faire reagir au changement de visibilite de la fenetre, de la meme maniere que si l'icone etait dans la barre des taches.
-* @param cClass la classe.
-* @param Xid l'ID de l'appli.
-* @param bIsHidden TRUE ssi a fenetre vient de se cacher.
-*/
-void cairo_dock_update_visibility_on_inhibitors (const gchar *cClass, Window Xid, gboolean bIsHidden);
-/*
-* Met a jour les inhibiteurs controlant une appli donnee pour les faire reagir a la prise d'activite de la fenetre, de la meme maniere que si l'icone etait dans la barre des taches.
-* @param cClass la classe.
-* @param Xid l'ID de l'appli.
-*/
-void cairo_dock_update_activity_on_inhibitors (const gchar *cClass, Window Xid);
-/*
-* Met a jour les inhibiteurs controlant une appli donnee pour les redessiner en mode normal lors de la perte d'activite de la fenetre.
-* @param cClass la classe.
-* @param Xid l'ID de l'appli.
-*/
-void cairo_dock_update_inactivity_on_inhibitors (const gchar *cClass, Window Xid);
 
-void cairo_dock_update_name_on_inhibitors (const gchar *cClass, Window Xid, gchar *cNewName);
+/** Run a function on each Icon that inhibites a given window.
+*@param actor the window actor
+*@param callback function to be called
+*@param data data passed to the callback
+*/
+void gldi_window_foreach_inhibitor (GldiWindowActor *actor, GldiIconRFunc callback, gpointer data);
+
 
 Icon *cairo_dock_get_classmate (Icon *pIcon);
 
@@ -208,8 +186,6 @@ Icon *cairo_dock_get_prev_next_classmate_icon (Icon *pIcon, gboolean bNext);
 Icon *cairo_dock_get_inhibitor (Icon *pIcon, gboolean bOnlyInDock);
 
 
-///void cairo_dock_reorder_classes (void);
-
 void cairo_dock_set_class_order_in_dock (Icon *pIcon, CairoDock *pDock);
 
 void cairo_dock_set_class_order_amongst_applis (Icon *pIcon, CairoDock *pDock);
@@ -249,5 +225,12 @@ gchar *cairo_dock_register_class_full (const gchar *cDesktopFile, const gchar *c
 void cairo_dock_set_data_from_class (const gchar *cClass, Icon *pIcon);
 
 
+
+void gldi_class_startup_notify (Icon *pIcon);
+
+void gldi_class_startup_notify_end (const gchar *cClass);
+
+gboolean gldi_class_is_starting (const gchar *cClass);
+
 G_END_DECLS
 #endif
