@@ -24,17 +24,18 @@
 #include "gldi-config.h"
 #include "cairo-dock-log.h"
 #include "cairo-dock-backends-manager.h"
-#include "cairo-dock-notifications.h"
 #include "cairo-dock-draw-opengl.h"
 #include "cairo-dock-opengl-font.h"
 #include "cairo-dock-animations.h"
+#include "cairo-dock-desklet-manager.h"  // CAIRO_CONTAINER_IS_OPENGL
+#include "cairo-dock-dock-manager.h"  // CAIRO_CONTAINER_IS_OPENGL
 #include "cairo-dock-surface-factory.h"
 #include "cairo-dock-draw.h"
 #include "cairo-dock-container.h"
 #include "cairo-dock-icon-factory.h"
 #include "cairo-dock-icon-facility.h"
+#include "cairo-dock-icon-manager.h"  // myIconsParam, NOTIFICATION_UPDATE_ICON_SLOW
 #include "cairo-dock-image-buffer.h"
-#include "cairo-dock-config.h"
 #include "cairo-dock-keyfile-utilities.h"
 #include "cairo-dock-packages.h"
 #include "cairo-dock-overlay.h"
@@ -191,7 +192,6 @@ void cairo_dock_render_overlays_to_texture (CairoDataRenderer *pRenderer, int iN
 	if (pRenderer->bWriteValues && pRenderer->bCanRenderValueAsText)
 	{
 		CairoDataRendererTextParam *pText;
-		int w, h, dw, dh;
 		pText = &pRenderer->pValuesText[iNumValue];
 		if (pText->fWidth != 0 && pText->fHeight != 0)
 		{
@@ -201,10 +201,10 @@ void cairo_dock_render_overlays_to_texture (CairoDataRenderer *pRenderer, int iN
 			glColor3f (pText->pColor[0], pText->pColor[1], pText->pColor[2]);
 			glPushMatrix ();
 			
-			w = pText->fWidth * pRenderer->iWidth;
-			h = pText->fHeight * pRenderer->iHeight;
-			dw = w & 1;
-			dh = h & 1;
+			int w = pText->fWidth * pRenderer->iWidth;
+			int h = pText->fHeight * pRenderer->iHeight;
+			int dw = w & 1;
+			int dh = h & 1;
 			cairo_dock_draw_gl_text_at_position_in_area ((guchar *) pRenderer->cFormatBuffer,
 				pFont,
 				floor (pText->fX * iWidth) + .5*dw,
@@ -294,7 +294,7 @@ void cairo_dock_render_overlays_to_context (CairoDataRenderer *pRenderer, int iN
 }
 
 
-static void _cairo_dock_render_to_context (CairoDataRenderer *pRenderer, Icon *pIcon, CairoContainer *pContainer, cairo_t *pCairoContext)
+static void _cairo_dock_render_to_context (CairoDataRenderer *pRenderer, Icon *pIcon, GldiContainer *pContainer, cairo_t *pCairoContext)
 {
 	cairo_t *ctx = NULL;
 	if (pRenderer->bUseOverlay && pRenderer->pOverlay != NULL)
@@ -351,7 +351,7 @@ static void _cairo_dock_render_to_context (CairoDataRenderer *pRenderer, Icon *p
 		cairo_destroy (ctx);
 }
 
-static void _cairo_dock_render_to_texture (CairoDataRenderer *pRenderer, Icon *pIcon, CairoContainer *pContainer)
+static void _cairo_dock_render_to_texture (CairoDataRenderer *pRenderer, Icon *pIcon, GldiContainer *pContainer)
 {
 	if (pRenderer->bUseOverlay)
 	{
@@ -366,7 +366,7 @@ static void _cairo_dock_render_to_texture (CairoDataRenderer *pRenderer, Icon *p
 	}
 	else
 	{
-		if (! cairo_dock_begin_draw_icon (pIcon, pContainer, 0))
+		if (! cairo_dock_begin_draw_icon (pIcon, 0))
 			return ;
 	}
 	
@@ -397,11 +397,11 @@ static void _cairo_dock_render_to_texture (CairoDataRenderer *pRenderer, Icon *p
 	}
 	else
 	{
-		cairo_dock_end_draw_icon (pIcon, pContainer);
+		cairo_dock_end_draw_icon (pIcon);
 	}
 }
 
-static inline void _refresh (CairoDataRenderer *pRenderer, Icon *pIcon, CairoContainer *pContainer)
+static inline void _refresh (CairoDataRenderer *pRenderer, Icon *pIcon, GldiContainer *pContainer)
 {
 	if (CAIRO_DOCK_CONTAINER_IS_OPENGL (pContainer) && pRenderer->interface.render_opengl)
 	{
@@ -413,11 +413,11 @@ static inline void _refresh (CairoDataRenderer *pRenderer, Icon *pIcon, CairoCon
 	}
 }
 
-static gboolean cairo_dock_update_icon_data_renderer_notification (G_GNUC_UNUSED gpointer pUserData, Icon *pIcon, CairoContainer *pContainer, gboolean *bContinueAnimation)
+static gboolean cairo_dock_update_icon_data_renderer_notification (G_GNUC_UNUSED gpointer pUserData, Icon *pIcon, GldiContainer *pContainer, gboolean *bContinueAnimation)
 {
 	CairoDataRenderer *pRenderer = cairo_dock_get_icon_data_renderer (pIcon);
 	if (pRenderer == NULL)
-		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
+		return GLDI_NOTIFICATION_LET_PASS;
 	
 	if (pRenderer->iSmoothAnimationStep > 0)
 	{
@@ -427,13 +427,13 @@ static gboolean cairo_dock_update_icon_data_renderer_notification (G_GNUC_UNUSED
 		
 		pRenderer->fLatency = (double) pRenderer->iSmoothAnimationStep / iNbIterations;
 		_cairo_dock_render_to_texture (pRenderer, pIcon, pContainer);
-		cairo_dock_redraw_icon (pIcon, pContainer);
+		cairo_dock_redraw_icon (pIcon);
 		
 		if (pRenderer->iSmoothAnimationStep < iNbIterations)
 			*bContinueAnimation = TRUE;
 	}
 	
-	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
+	return GLDI_NOTIFICATION_LET_PASS;
 }
 
 static void _cairo_dock_finish_load_data_renderer (CairoDataRenderer *pRenderer, gboolean bLoadTextures, Icon *pIcon)
@@ -477,8 +477,8 @@ static void _cairo_dock_finish_load_data_renderer (CairoDataRenderer *pRenderer,
 	//\___________________ On charge les labels si l'implementation les a valides.
 	if (pRenderer->pLabels != NULL)
 	{
-		CairoDockLabelDescription textDescription;
-		cairo_dock_copy_label_description (&textDescription, &myIconsParam.quickInfoTextDescription);
+		GldiTextDescription textDescription;
+		gldi_text_description_copy (&textDescription, &myIconsParam.quickInfoTextDescription);
 		
 		CairoDataRendererText *pLabel;
 		cairo_surface_t *pSurface;
@@ -498,15 +498,14 @@ static void _cairo_dock_finish_load_data_renderer (CairoDataRenderer *pRenderer,
 			}
 			if (pLabel->param.fWidth != 0 && pLabel->param.fHeight != 0 && pLabel->cText != NULL)
 			{
-				textDescription.fBackgroundColor[3] = 0.;
+				textDescription.bNoDecorations = TRUE;
+				textDescription.bUseDefaultColors = FALSE;
 				textDescription.iMargin = 0;
 				textDescription.bOutlined = TRUE;  /// tester avec et sans ...
-				textDescription.fColorStart[0] = pLabel->param.pColor[0];
-				textDescription.fColorStart[1] = pLabel->param.pColor[1];
-				textDescription.fColorStart[2] = pLabel->param.pColor[2];
-				textDescription.fColorStop[0] = pLabel->param.pColor[0];
-				textDescription.fColorStop[1] = pLabel->param.pColor[1];
-				textDescription.fColorStop[2] = pLabel->param.pColor[2];
+				textDescription.fColorStart.rgba.red = pLabel->param.pColor[0];
+				textDescription.fColorStart.rgba.green = pLabel->param.pColor[1];
+				textDescription.fColorStart.rgba.blue = pLabel->param.pColor[2];
+				textDescription.fColorStart.rgba.alpha = 1.;
 				pSurface = cairo_dock_create_surface_from_text (pLabel->cText,
 					&textDescription,
 					&pLabel->iTextWidth, &pLabel->iTextHeight);
@@ -530,7 +529,7 @@ static void _cairo_dock_finish_load_data_renderer (CairoDataRenderer *pRenderer,
 	}
 	
 	if (pRenderer->bCanRenderValueAsText && pRenderer->bWriteValues)
-		cairo_dock_set_quick_info (pIcon, NULL, NULL);
+		gldi_icon_set_quick_info (pIcon, NULL);
 	
 	//\___________________ Build an overlay if the renderer will use some.
 	if (pRenderer->bUseOverlay)
@@ -542,7 +541,7 @@ static void _cairo_dock_finish_load_data_renderer (CairoDataRenderer *pRenderer,
 	}
 }
 
-void cairo_dock_add_new_data_renderer_on_icon (Icon *pIcon, CairoContainer *pContainer, CairoDataRendererAttribute *pAttribute)
+void cairo_dock_add_new_data_renderer_on_icon (Icon *pIcon, GldiContainer *pContainer, CairoDataRendererAttribute *pAttribute)
 {
 	//\___________________ if a previous renderer exists, keep its data alive.
 	CairoDataToRenderer *pData = NULL;
@@ -602,10 +601,10 @@ void cairo_dock_add_new_data_renderer_on_icon (Icon *pIcon, CairoContainer *pCon
 	if (CAIRO_DOCK_CONTAINER_IS_OPENGL (pContainer) && pRenderer->interface.render_opengl)
 	{
 		bLoadTextures = TRUE;
-		cairo_dock_register_notification_on_object (pIcon,
+		gldi_object_register_notification (pIcon,
 			NOTIFICATION_UPDATE_ICON_SLOW,
-			(CairoDockNotificationFunc) cairo_dock_update_icon_data_renderer_notification,
-			CAIRO_DOCK_RUN_AFTER, NULL);  // pour l'affichage fluide.
+			(GldiNotificationFunc) cairo_dock_update_icon_data_renderer_notification,
+			GLDI_RUN_AFTER, NULL);  // pour l'affichage fluide.
 	}
 	
 	pRenderer->interface.load (pRenderer, pIcon, pAttribute);
@@ -628,21 +627,21 @@ static gboolean _render_delayed (Icon *pIcon)
 	CairoDataRenderer *pRenderer = cairo_dock_get_icon_data_renderer (pIcon);
 	g_return_val_if_fail (pRenderer != NULL, FALSE);
 	
-	CairoContainer *pContainer = pIcon->pContainer;
-	cd_debug ("Render delayed: (%s, %dx%d)", pIcon->cName, pContainer->iWidth, pContainer->iHeight);
+	GldiContainer *pContainer = pIcon->pContainer;
 	if (pContainer)
 	{
+		cd_debug ("Render delayed: (%s, %dx%d)", pIcon->cName, pContainer->iWidth, pContainer->iHeight);
 		if (pContainer->iWidth == 1 && pContainer->iHeight == 1)  // container not yet resized, retry later
 			return TRUE;
 	
 		_cairo_dock_render_to_texture (pRenderer, pIcon, pContainer);
-		cairo_dock_redraw_icon (pIcon, pContainer);
+		cairo_dock_redraw_icon (pIcon);
 	}
 	
 	pRenderer->iSidRenderIdle = 0;
 	return FALSE;
 }
-void cairo_dock_render_new_data_on_icon (Icon *pIcon, CairoContainer *pContainer, cairo_t *pCairoContext, double *pNewValues)
+void cairo_dock_render_new_data_on_icon (Icon *pIcon, GldiContainer *pContainer, cairo_t *pCairoContext, double *pNewValues)
 {
 	CairoDataRenderer *pRenderer = cairo_dock_get_icon_data_renderer (pIcon);
 	g_return_if_fail (pRenderer != NULL);
@@ -714,11 +713,11 @@ void cairo_dock_render_new_data_on_icon (Icon *pIcon, CairoContainer *pContainer
 				str ++;
 			}
 		}
-		cairo_dock_set_quick_info (pIcon, pContainer, cBuffer);
+		gldi_icon_set_quick_info (pIcon, cBuffer);
 		g_free (cBuffer);
 	}
 	
-	cairo_dock_redraw_icon (pIcon, pContainer);
+	cairo_dock_redraw_icon (pIcon);
 }
 
 
@@ -771,7 +770,7 @@ void cairo_dock_free_data_renderer (CairoDataRenderer *pRenderer)
 	
 	g_free (pRenderer->pValuesText);
 	
-	cairo_dock_destroy_overlay (pRenderer->pOverlay);
+	gldi_object_unref (GLDI_OBJECT(pRenderer->pOverlay));
 	
 	g_free (pRenderer);
 }
@@ -781,10 +780,10 @@ void cairo_dock_remove_data_renderer_on_icon (Icon *pIcon)
 	CairoDataRenderer *pRenderer = cairo_dock_get_icon_data_renderer (pIcon);
 	if (pRenderer != NULL)
 	{
-		cairo_dock_remove_notification_func_on_object (pIcon, NOTIFICATION_UPDATE_ICON_SLOW, (CairoDockNotificationFunc) cairo_dock_update_icon_data_renderer_notification, NULL);
+		gldi_object_remove_notification (pIcon, NOTIFICATION_UPDATE_ICON_SLOW, (GldiNotificationFunc) cairo_dock_update_icon_data_renderer_notification, NULL);
 		
 		if (! pRenderer->bCanRenderValueAsText && pRenderer->bWriteValues)
-			cairo_dock_set_quick_info (pIcon, NULL, NULL);
+			gldi_icon_set_quick_info (pIcon, NULL);
 		
 		cairo_dock_free_data_renderer (pRenderer);
 		cairo_dock_set_data_renderer_on_icon (pIcon, NULL);
@@ -792,7 +791,7 @@ void cairo_dock_remove_data_renderer_on_icon (Icon *pIcon)
 }
 
 
-void cairo_dock_reload_data_renderer_on_icon (Icon *pIcon, CairoContainer *pContainer)
+void cairo_dock_reload_data_renderer_on_icon (Icon *pIcon, GldiContainer *pContainer)
 {
 	cd_debug ("%s (%s)", __func__, pIcon->cName);
 	//\_____________ update the renderer size.
@@ -842,7 +841,7 @@ void cairo_dock_resize_data_renderer_history (Icon *pIcon, int iNewMemorySize)
 		pData->iCurrentIndex = pData->iMemorySize - 1;
 }
 
-void cairo_dock_refresh_data_renderer (Icon *pIcon, CairoContainer *pContainer)
+void cairo_dock_refresh_data_renderer (Icon *pIcon, GldiContainer *pContainer)
 {
 	CairoDataRenderer *pRenderer = cairo_dock_get_icon_data_renderer (pIcon);
 	g_return_if_fail (pRenderer != NULL);
