@@ -21,23 +21,17 @@
 #include <GL/gl.h>
 #include <GL/glu.h>
 
-#include "cairo-dock-icon-facility.h"
 #include "cairo-dock-separator-manager.h"  // gldi_auto_separator_icon_new
 #include "cairo-dock-log.h"
-#include "cairo-dock-dock-manager.h"
-#include "cairo-dock-module-instance-manager.h"
-#include "cairo-dock-container.h"
-#include "cairo-dock-dock-facility.h"
 #include "cairo-dock-draw-opengl.h"  // for the redirected texture
-#include "cairo-dock-data-renderer.h"  // cairo_dock_reload_data_renderer_on_icon
+#include "cairo-dock-data-renderer.h"  // cairo_dock_reload_data_renderer_on_icon/cairo_dock_refresh_data_renderer
 #include "cairo-dock-windows-manager.h"  // gldi_windows_get_active
 #include "cairo-dock-indicator-manager.h"  // myIndicators.bUseClassIndic
-#include "cairo-dock-dock-factory.h"
 #include "cairo-dock-draw.h"
 #include "cairo-dock-animations.h"
 #include "cairo-dock-image-buffer.h"
 #include "cairo-dock-module-manager.h"  // CAIRO_DOCK_MODULE_CAN_DESKLET
-#include "cairo-dock-module-instance-manager.h"  // gldi_module_instance_reload
+#include "cairo-dock-module-instance-manager.h"  // pModuleInstance->
 #include "cairo-dock-icon-factory.h"
 #include "cairo-dock-icon-facility.h"
 #include "cairo-dock-applications-manager.h"  // myTaskbarParam.bHideVisibleApplis
@@ -46,22 +40,18 @@
 #include "cairo-dock-class-icon-manager.h"
 #include "cairo-dock-application-facility.h"
 #include "cairo-dock-launcher-manager.h"
-#include "cairo-dock-config.h"
-#include "cairo-dock-container.h"
+#include "cairo-dock-config.h"  // cairo_dock_is_loading
 #include "cairo-dock-dock-facility.h"
-#include "cairo-dock-dialog-manager.h"
 #include "cairo-dock-log.h"
-#include "cairo-dock-menu.h"
+#include "cairo-dock-menu.h"  // gldi_menu_popup
 #include "cairo-dock-dock-manager.h"
-#include "cairo-dock-dock-visibility.h"
-#include "cairo-dock-draw-opengl.h"
+#include "cairo-dock-dock-visibility.h"  // gldi_dock_search_overlapping_window
 #include "cairo-dock-flying-container.h"
 #include "cairo-dock-backends-manager.h"
 #include "cairo-dock-class-manager.h"  // cairo_dock_check_class_subdock_is_empty
 #include "cairo-dock-desktop-manager.h"
 #include "cairo-dock-windows-manager.h"  // gldi_windows_get_active
-#include "cairo-dock-data-renderer.h"  // cairo_dock_refresh_data_renderer
-#include "cairo-dock-indicator-manager.h"  // myIndicators.bUseClassIndic
+#include "cairo-dock-dock-factory.h"
 
 // dependencies
 extern CairoDockHidingEffect *g_pHidingBackend;
@@ -128,8 +118,8 @@ static gboolean _mouse_is_really_outside (CairoDock *pDock)
 		return TRUE;
 	if (pDock->container.iMouseY < y1
 	|| pDock->container.iMouseY > y2)  // Note: Compiz has a bug: when using the "cube rotation" plug-in, it will reserve 2 pixels for itself on the left and right edges of the screen. So the mouse is not inside the dock when it's at x=0 or x=Ws-1 (no 'enter' event is sent; it's as if the x=0 or x=Ws-1 vertical line of pixels is out of the screen).
-		return TRUE;	
-	
+		return TRUE;
+
 	return FALSE;
 }
 
@@ -138,30 +128,18 @@ void cairo_dock_freeze_docks (gboolean bFreeze)
 	s_bFrozenDock = bFreeze;  /// instead, try to connect to the motion-event and intercept it ...
 }
 
-static gboolean _on_expose (G_GNUC_UNUSED GtkWidget *pWidget,
-#if (GTK_MAJOR_VERSION < 3)
-	GdkEventExpose *pExpose,
-#else
-	cairo_t *ctx,
-#endif
-	CairoDock *pDock)
+static gboolean _on_expose (G_GNUC_UNUSED GtkWidget *pWidget, cairo_t *pCairoContext, CairoDock *pDock)
 {
-	GdkRectangle area;
-	#if (GTK_MAJOR_VERSION < 3)
-	memcpy (&area, &pExpose->area, sizeof (GdkRectangle));
-	#else
-	double x1, x2, y1, y2;
-	cairo_clip_extents (ctx, &x1, &y1, &x2, &y2);
-	area.x = x1;
-	area.y = y1;
-	area.width = x2 - x1;
-	area.height = y2 - y1;  /// or the opposite ?...
-	#endif
-	//g_print ("%s ((%d;%d) %dx%d)\n", __func__, area.x, area.y, area.width, area.height);
-	
-	//\________________ OpenGL rendering
-	if (g_bUseOpenGL && pDock->pRenderer->render_opengl != NULL)
+	if (g_bUseOpenGL && pDock->pRenderer->render_opengl != NULL)  // OpenGL rendering
 	{
+		GdkRectangle area;
+		double x1, x2, y1, y2;
+		cairo_clip_extents (pCairoContext, &x1, &y1, &x2, &y2);
+		area.x = x1;
+		area.y = y1;
+		area.width = x2 - x1;
+		area.height = y2 - y1;
+		
 		if (! gldi_gl_container_begin_draw_full (CAIRO_CONTAINER (pDock), area.x + area.y != 0 ? &area : NULL, TRUE))
 			return FALSE;
 		
@@ -180,13 +158,9 @@ static gboolean _on_expose (G_GNUC_UNUSED GtkWidget *pWidget,
 		
 		gldi_gl_container_end_draw (CAIRO_CONTAINER (pDock));
 	}
-	else if (! g_bUseOpenGL && pDock->pRenderer->render != NULL)
+	else if (! g_bUseOpenGL && pDock->pRenderer->render != NULL)  // cairo rendering
 	{
-		cairo_t *pCairoContext;
-		if (area.x + area.y != 0)
-			pCairoContext = cairo_dock_create_drawing_context_on_area (CAIRO_CONTAINER (pDock), &area, NULL);
-		else
-			pCairoContext = cairo_dock_create_drawing_context_on_container (CAIRO_CONTAINER (pDock));
+		cairo_dock_init_drawing_context_on_container (CAIRO_CONTAINER (pDock), pCairoContext);
 		
 		if (cairo_dock_is_loading ())
 		{
@@ -200,76 +174,8 @@ static gboolean _on_expose (G_GNUC_UNUSED GtkWidget *pWidget,
 		{
 			gldi_object_notify (pDock, NOTIFICATION_RENDER, pDock, pCairoContext);
 		}
-	
-		cairo_destroy (pCairoContext);
 	}
 	return FALSE;
-	/// TODO: check that it works without the code below...
-	/**
-	//\________________ Cairo optimized rendering
-	if (area.x + area.y != 0)  // x et/ou y sont > 0.
-	{
-		if (! cairo_dock_is_hidden (pDock) || (g_pHidingBackend != NULL && g_pHidingBackend->bCanDisplayHiddenDock))  // if the dock is invisible, we don't use the optimized rendering (for always-visible icons for instance)
-		{
-			cairo_t *pCairoContext = cairo_dock_create_drawing_context_on_area (CAIRO_CONTAINER (pDock), &area, NULL);
-			
-			if (pDock->fHideOffset != 0 && g_pHidingBackend != NULL && g_pHidingBackend->pre_render)
-				g_pHidingBackend->pre_render (pDock, pDock->fHideOffset, pCairoContext);
-			
-			if (pDock->iFadeCounter != 0 && g_pKeepingBelowBackend != NULL && g_pKeepingBelowBackend->pre_render)
-				g_pKeepingBelowBackend->pre_render (pDock, (double) pDock->iFadeCounter / myBackendsParam.iHideNbSteps, pCairoContext);
-			
-			if (pDock->pRenderer->render_optimized != NULL)
-				pDock->pRenderer->render_optimized (pCairoContext, pDock, &area);
-			else
-				pDock->pRenderer->render (pCairoContext, pDock);
-			
-			if (pDock->fHideOffset != 0 && g_pHidingBackend != NULL && g_pHidingBackend->post_render)
-				g_pHidingBackend->post_render (pDock, pDock->fHideOffset, pCairoContext);
-		
-			if (pDock->iFadeCounter != 0 && g_pKeepingBelowBackend != NULL && g_pKeepingBelowBackend->post_render)
-				g_pKeepingBelowBackend->post_render (pDock, (double) pDock->iFadeCounter / myBackendsParam.iHideNbSteps, pCairoContext);
-			
-			gldi_object_notify (pDock, NOTIFICATION_RENDER, pDock, pCairoContext);
-			
-			cairo_destroy (pCairoContext);
-			return FALSE;
-		}
-		
-	}
-	
-	//\________________ Cairo rendering
-	cairo_t *pCairoContext = cairo_dock_create_drawing_context_on_container (CAIRO_CONTAINER (pDock));
-	
-	if (cairo_dock_is_loading ())  // transparent pendant le chargement.
-	{
-		
-	}
-	else if (cairo_dock_is_hidden (pDock) && (g_pHidingBackend == NULL || !g_pHidingBackend->bCanDisplayHiddenDock))
-	{
-		cairo_dock_render_hidden_dock (pCairoContext, pDock);
-	}
-	else
-	{
-		if (pDock->fHideOffset != 0 && g_pHidingBackend != NULL && g_pHidingBackend->pre_render)
-			g_pHidingBackend->pre_render (pDock, pDock->fHideOffset, pCairoContext);
-		
-		if (pDock->iFadeCounter != 0 && g_pKeepingBelowBackend != NULL && g_pKeepingBelowBackend->pre_render)
-			g_pKeepingBelowBackend->pre_render (pDock, (double) pDock->iFadeCounter / myBackendsParam.iHideNbSteps, pCairoContext);
-		
-		pDock->pRenderer->render (pCairoContext, pDock);
-		
-		if (pDock->fHideOffset != 0 && g_pHidingBackend != NULL && g_pHidingBackend->post_render)
-			g_pHidingBackend->post_render (pDock, pDock->fHideOffset, pCairoContext);
-		
-		if (pDock->iFadeCounter != 0 && g_pKeepingBelowBackend != NULL && g_pKeepingBelowBackend->post_render)
-			g_pKeepingBelowBackend->post_render (pDock, (double) pDock->iFadeCounter / myBackendsParam.iHideNbSteps, pCairoContext);
-		
-		gldi_object_notify (pDock, NOTIFICATION_RENDER, pDock, pCairoContext);
-	}
-	
-	cairo_destroy (pCairoContext);
-	return FALSE;*/
 }
 
 
@@ -1243,7 +1149,7 @@ static gboolean _on_configure (GtkWidget* pWidget, GdkEventConfigure* pEvent, Ca
 			if (! gldi_gl_container_make_current (CAIRO_CONTAINER (pDock)))
 				return FALSE;
 			
-			cairo_dock_set_ortho_view (CAIRO_CONTAINER (pDock));
+			gldi_gl_container_set_ortho_view (CAIRO_CONTAINER (pDock));
 			
 			glClearAccum (0., 0., 0., 0.);
 			glClear (GL_ACCUM_BUFFER_BIT);
@@ -1511,11 +1417,10 @@ static gboolean _on_drag_motion (GtkWidget *pWidget, GdkDragContext *dc, gint x,
 		Y = x;
 		X = y - pDock->container.iWidth/2;
 	}
-	int w, h;
 	if (pDock->iInputState == CAIRO_DOCK_INPUT_AT_REST)
 	{
-		w = pDock->iMinDockWidth;
-		h = pDock->iMinDockHeight;
+		int w = pDock->iMinDockWidth;
+		int h = pDock->iMinDockHeight;
 		
 		if (X <= -w/2 || X >= w/2)
 			return FALSE;  // on n'accepte pas le drop.
@@ -1736,7 +1641,7 @@ static gboolean _cairo_dock_hide (CairoDock *pDock)
 						pIcon->fInsertRemoveFactor = - 0.05;
 				}
 				
-				if (! pIcon->bIsDemandingAttention && ! pIcon->bAlwaysVisible)
+				if (! pIcon->bIsDemandingAttention && ! pIcon->bAlwaysVisible && ! pIcon->bIsLaunching)
 					gldi_icon_stop_animation (pIcon);  // s'il y'a une autre animation en cours, on l'arrete.
 				else
 					bVisibleIconsPresent = TRUE;
@@ -2265,11 +2170,7 @@ void gldi_dock_init_internals (CairoDock *pDock)
 		GDK_POINTER_MOTION_MASK | GDK_POINTER_MOTION_HINT_MASK);
 	
 	g_signal_connect (G_OBJECT (pWindow),
-		#if (GTK_MAJOR_VERSION < 3)
-		"expose-event",
-		#else
 		"draw",
-		#endif
 		G_CALLBACK (_on_expose),
 		pDock);
 	g_signal_connect (G_OBJECT (pWindow),
