@@ -50,7 +50,7 @@
 #include "cairo-dock-container.h"
 #include "cairo-dock-keybinder.h"
 #include "cairo-dock-indicator-manager.h"  // myIndicatorsParam.bUseClassIndic
-#include "cairo-dock-dialog-manager.h"
+#include "cairo-dock-style-manager.h"
 #include "cairo-dock-opengl.h"
 #include "cairo-dock-dock-visibility.h"
 #include "cairo-dock-dock-manager.h"
@@ -169,7 +169,7 @@ static void _make_sub_dock (CairoDock *pDock, CairoDock *pParentDock, const gcha
 	//\__________________ remove any input shape
 	if (pDock->pShapeBitmap != NULL)
 	{
-		gldi_shape_destroy (pDock->pShapeBitmap);
+		cairo_region_destroy (pDock->pShapeBitmap);
 		pDock->pShapeBitmap = NULL;
 		if (pDock->iInputState != CAIRO_DOCK_INPUT_ACTIVE)
 		{
@@ -629,11 +629,11 @@ static gboolean _get_root_dock_config (CairoDock *pDock)
 			pDock->bBgImageRepeat = cairo_dock_get_boolean_key_value (pKeyFile, "Appearance", "repeat image", &bFlushConfFileNeeded, FALSE, NULL, NULL);
 		}
 		// on recupere la couleur tout le temps pour avoir un plan B.
-		double couleur[4] = {.7, .7, 1., .7};
-		cairo_dock_get_double_list_key_value (pKeyFile, "Appearance", "stripes color dark", &bFlushConfFileNeeded, pDock->fBgColorDark, 4, couleur, NULL, NULL);
+		GldiColor couleur = {{.7, .7, 1., .7}};
+		cairo_dock_get_color_key_value (pKeyFile, "Appearance", "stripes color dark", &bFlushConfFileNeeded, &pDock->fBgColorDark, &couleur, NULL, NULL);
 		
-		double couleur2[4] = {.7, .9, .7, .4};
-		cairo_dock_get_double_list_key_value (pKeyFile, "Appearance", "stripes color bright", &bFlushConfFileNeeded, pDock->fBgColorBright, 4, couleur2, NULL, NULL);
+		GldiColor couleur2 = {{.7, .9, .7, .4}};
+		cairo_dock_get_color_key_value (pKeyFile, "Appearance", "stripes color bright", &bFlushConfFileNeeded, &pDock->fBgColorBright, &couleur2, NULL, NULL);
 	}
 	
 	pDock->bExtendedMode = cairo_dock_get_boolean_key_value (pKeyFile, "Appearance", "extended", &bFlushConfFileNeeded, FALSE, NULL, NULL);
@@ -1125,6 +1125,7 @@ void gldi_dock_set_visibility (CairoDock *pDock, CairoDockVisibility iVisibility
 		}
 		else if (bAutoHideOnAnyOverlap)
 		{
+			pDock->bTemporaryHidden = pDock->bAutoHide;  // needed to use the following function
 			gldi_dock_hide_if_any_window_overlap_or_show (pDock);
 		}
 		else
@@ -1137,7 +1138,7 @@ void gldi_dock_set_visibility (CairoDock *pDock, CairoDockVisibility iVisibility
 			}
 			if (bAutoHideOnOverlap)
 			{
-				pDock->bTemporaryHidden = pDock->bAutoHide;  // astuce pour utiliser la fonction ci-dessous.
+				pDock->bTemporaryHidden = pDock->bAutoHide;  // needed to use the following function
 				gldi_dock_hide_show_if_current_window_is_on_our_way (pDock);
 			}
 		}
@@ -1413,47 +1414,47 @@ static gboolean get_config (GKeyFile *pKeyFile, CairoDocksParam *pDocksParam)
 	CairoDocksParam *pAccessibility = pDocksParam;
 	CairoDocksParam *pSystem = pDocksParam;
 	
-	// cadre.
+	// frame
 	pBackground->iDockRadius = cairo_dock_get_integer_key_value (pKeyFile, "Background", "corner radius", &bFlushConfFileNeeded, 12, NULL, NULL);
 
 	pBackground->iDockLineWidth = cairo_dock_get_integer_key_value (pKeyFile, "Background", "line width", &bFlushConfFileNeeded, 2, NULL, NULL);
 
 	pBackground->iFrameMargin = cairo_dock_get_integer_key_value (pKeyFile, "Background", "frame margin", &bFlushConfFileNeeded, 2, NULL, NULL);
 
-	double couleur[4] = {0., 0., 0.6, 0.4};
-	cairo_dock_get_double_list_key_value (pKeyFile, "Background", "line color", &bFlushConfFileNeeded, pBackground->fLineColor, 4, couleur, NULL, NULL);
+	GldiColor couleur = {{0., 0., 0.6, 0.4}};
+	cairo_dock_get_color_key_value (pKeyFile, "Background", "line color", &bFlushConfFileNeeded, &pBackground->fLineColor, &couleur, NULL, NULL);
 
 	pBackground->bRoundedBottomCorner = cairo_dock_get_boolean_key_value (pKeyFile, "Background", "rounded bottom corner", &bFlushConfFileNeeded, TRUE, NULL, NULL);
 	
-	// image de fond.
-	gchar *cBgImage = cairo_dock_get_string_key_value (pKeyFile, "Background", "background image", &bFlushConfFileNeeded, NULL, NULL, NULL);
-	int iFillBg = cairo_dock_get_integer_key_value (pKeyFile, "Background", "fill bg", &bFlushConfFileNeeded, -1, NULL, NULL);  // -1 pour intercepter le cas ou la cle n'existe pas.
-	if (iFillBg == -1)  // nouvelle cle
+	// background image
+	int iStyle = cairo_dock_get_integer_key_value (pKeyFile, "Background", "style", &bFlushConfFileNeeded, -1, NULL, NULL);  // -1 pour intercepter le cas ou la cle n'existe pas.
+	if (iStyle == -1)  // old params < 3.4
 	{
-		iFillBg = (cBgImage != NULL ? 0 : 1);  // si une image etait definie auparavant, on dit qu'on veut le mode "image"
-		g_key_file_set_integer (pKeyFile, "Background", "fill bg", iFillBg);
+		iStyle = g_key_file_get_integer (pKeyFile, "Background", "fill bg", NULL);
+		iStyle ++;
+		g_key_file_set_integer (pKeyFile, "Background", "style", iStyle);
 	}
-	else
+	
+	if (iStyle == 0)
 	{
-		if (iFillBg != 0)  // remplissage avec un degrade => on ne veut pas d'image
+		pBackground->bUseDefaultColors = TRUE;
+		pBackground->iDockRadius = myStyleParam.iCornerRadius;
+		pBackground->iDockLineWidth = myStyleParam.iLineWidth;
+	}
+	else if (iStyle == 1)
+	{
+		gchar *cBgImage = (iStyle == 1 ? cairo_dock_get_string_key_value (pKeyFile, "Background", "background image", &bFlushConfFileNeeded, NULL, NULL, NULL) : NULL);
+		if (cBgImage != NULL)
 		{
+			pBackground->cBackgroundImageFile = cairo_dock_search_image_s_path (cBgImage);
 			g_free (cBgImage);
-			cBgImage = NULL;
+			pBackground->fBackgroundImageAlpha = cairo_dock_get_double_key_value (pKeyFile, "Background", "image alpha", &bFlushConfFileNeeded, 0.5, NULL, NULL);
+			pBackground->bBackgroundImageRepeat = cairo_dock_get_boolean_key_value (pKeyFile, "Background", "repeat image", &bFlushConfFileNeeded, FALSE, NULL, NULL);
 		}
 	}
 	
-	if (cBgImage != NULL)
-	{
-		pBackground->cBackgroundImageFile = cairo_dock_search_image_s_path (cBgImage);
-		g_free (cBgImage);
-	}
-	
-	pBackground->fBackgroundImageAlpha = cairo_dock_get_double_key_value (pKeyFile, "Background", "image alpha", &bFlushConfFileNeeded, 0.5, NULL, NULL);
-
-	pBackground->bBackgroundImageRepeat = cairo_dock_get_boolean_key_value (pKeyFile, "Background", "repeat image", &bFlushConfFileNeeded, FALSE, NULL, NULL);
-	
-	// degrade du fond.
-	if (pBackground->cBackgroundImageFile == NULL)
+	// background gradation
+	if (iStyle != 0 && pBackground->cBackgroundImageFile == NULL)
 	{
 		pBackground->iNbStripes = cairo_dock_get_integer_key_value (pKeyFile, "Background", "number of stripes", &bFlushConfFileNeeded, 10, NULL, NULL);
 		
@@ -1461,11 +1462,11 @@ static gboolean get_config (GKeyFile *pKeyFile, CairoDocksParam *pDocksParam)
 		{
 			pBackground->fStripesWidth = MAX (.01, MIN (.99, cairo_dock_get_double_key_value (pKeyFile, "Background", "stripes width", &bFlushConfFileNeeded, 0.2, NULL, NULL))) / pBackground->iNbStripes;
 		}
-		double couleur3[4] = {.7, .7, 1., .7};
-		cairo_dock_get_double_list_key_value (pKeyFile, "Background", "stripes color dark", &bFlushConfFileNeeded, pBackground->fStripesColorDark, 4, couleur3, NULL, NULL);
+		GldiColor couleur3 = {{.7, .7, 1., .7}};
+		cairo_dock_get_color_key_value (pKeyFile, "Background", "stripes color dark", &bFlushConfFileNeeded, &pBackground->fStripesColorDark, &couleur3, NULL, NULL);
 		
-		double couleur2[4] = {.7, .9, .7, .4};
-		cairo_dock_get_double_list_key_value (pKeyFile, "Background", "stripes color bright", &bFlushConfFileNeeded, pBackground->fStripesColorBright, 4, couleur2, NULL, NULL);
+		GldiColor couleur2 = {{.7, .9, .7, .4}};
+		cairo_dock_get_color_key_value (pKeyFile, "Background", "stripes color bright", &bFlushConfFileNeeded, &pBackground->fStripesColorBright, &couleur2, NULL, NULL);
 		
 		pBackground->fStripesAngle = cairo_dock_get_double_key_value (pKeyFile, "Background", "stripes angle", &bFlushConfFileNeeded, 90., NULL, NULL);
 	}
@@ -1473,8 +1474,8 @@ static gboolean get_config (GKeyFile *pKeyFile, CairoDocksParam *pDocksParam)
 	pAccessibility->bExtendedMode = cairo_dock_get_boolean_key_value (pKeyFile, "Background", "extended", &bFlushConfFileNeeded, FALSE, "Accessibility", NULL);
 	
 	// hidden bg
-	double hcolor[4] = {.8, .8, .8, .5};
-	cairo_dock_get_double_list_key_value (pKeyFile, "Background", "hidden bg color", &bFlushConfFileNeeded, pBackground->fHiddenBg, 4, hcolor, NULL, NULL);
+	GldiColor hcolor = {{.8, .8, .8, .5}};
+	cairo_dock_get_color_key_value (pKeyFile, "Background", "hidden bg color", &bFlushConfFileNeeded, &pBackground->fHiddenBg, &hcolor, NULL, NULL);
 	
 	// position
 	pPosition->iGapX = cairo_dock_get_integer_key_value (pKeyFile, "Position", "x gap", &bFlushConfFileNeeded, 0, NULL, NULL);
@@ -1730,7 +1731,7 @@ static void reload (CairoDocksParam *pPrevDocksParam, CairoDocksParam *pDocksPar
 	CairoDocksParam *pAccessibility = pDocksParam;
 	// CairoDocksParam *pViews = pDocksParam;
 	// CairoDocksParam *pSystem = pDocksParam;
-	 CairoDocksParam *pPrevBackground = pPrevDocksParam;
+	CairoDocksParam *pPrevBackground = pPrevDocksParam;
 	CairoDocksParam *pPrevPosition = pPrevDocksParam;
 	CairoDocksParam *pPrevAccessibility = pPrevDocksParam;
 	// CairoDocksParam *pPrevViews = pPrevDocksParam;
@@ -1760,7 +1761,9 @@ static void reload (CairoDocksParam *pPrevDocksParam, CairoDocksParam *pDocksPar
 	pDock->fAlign = pPosition->fAlign;
 	
 	if (pPosition->iNumScreen != pPrevPosition->iNumScreen
-	|| pPosition->iScreenBorder != pPrevPosition->iScreenBorder)  // if the orientation or the screen has changed, the available size may have changed too
+	|| pPosition->iScreenBorder != pPrevPosition->iScreenBorder  // if the orientation or the screen has changed, the available size may have changed too
+	|| pPosition->iGapX != pPrevPosition->iGapX
+	|| pPosition->iGapY != pPrevPosition->iGapY)
 	{
 		cairo_dock_update_dock_size (pDock);
 		cairo_dock_move_resize_dock (pDock);
@@ -1850,6 +1853,25 @@ static void unload (void)
  /// INIT ///
 ////////////
 
+static gboolean on_style_changed (G_GNUC_UNUSED gpointer data)
+{
+	cd_debug ("Docks: style change to %d", myDocksParam.bUseDefaultColors);
+	if (myDocksParam.bUseDefaultColors)  // reload bg
+	{
+		cd_debug (" reload dock's bg...");
+		
+		gboolean bNeedUpdateSize = (myDocksParam.iDockLineWidth != myStyleParam.iLineWidth);  // frame size changed
+		myDocksParam.iDockRadius = myStyleParam.iCornerRadius;
+		myDocksParam.iDockLineWidth = myStyleParam.iLineWidth;
+		
+		if (bNeedUpdateSize)  // update docks size and background
+			gldi_docks_foreach_root ((GFunc)cairo_dock_update_dock_size, NULL);
+		else  // update docks background for color change
+			gldi_docks_foreach_root ((GFunc)_reload_bg, NULL);
+	}
+	return GLDI_NOTIFICATION_LET_PASS;
+}
+
 static void init (void)
 {
 	s_hDocksTable = g_hash_table_new_full (g_str_hash,
@@ -1889,6 +1911,10 @@ static void init (void)
 		NOTIFICATION_NEW,
 		(GldiNotificationFunc) _on_new_dialog,
 		GLDI_RUN_AFTER, NULL);
+	gldi_object_register_notification (&myStyleMgr,
+		NOTIFICATION_STYLE_CHANGED,
+		(GldiNotificationFunc) on_style_changed,
+		GLDI_RUN_AFTER, NULL);
 	
 	gldi_docks_visibility_start ();
 }
@@ -2067,13 +2093,13 @@ static void reset_object (GldiObject *obj)
 	
 	// free data
 	if (pDock->pShapeBitmap != NULL)
-		gldi_shape_destroy (pDock->pShapeBitmap);
+		cairo_region_destroy (pDock->pShapeBitmap);
 	
 	if (pDock->pHiddenShapeBitmap != NULL)
-		gldi_shape_destroy (pDock->pHiddenShapeBitmap);
+		cairo_region_destroy (pDock->pHiddenShapeBitmap);
 	
 	if (pDock->pActiveShapeBitmap != NULL)
-		gldi_shape_destroy (pDock->pActiveShapeBitmap);
+		cairo_region_destroy (pDock->pActiveShapeBitmap);
 	
 	if (pDock->pRenderer != NULL && pDock->pRenderer->free_data != NULL)
 	{
