@@ -29,16 +29,21 @@
 
 
 #include "cairo-dock-struct.h"
-#include "cairo-dock-notifications.h"
-#include "cairo-dock-module-factory.h"
+#include "cairo-dock-dialog-manager.h"  // gldi_dialogs_foreach
+#include "cairo-dock-dialog-factory.h"
+#include "cairo-dock-module-instance-manager.h"  // GldiModuleInstance
 #include "cairo-dock-dock-facility.h"
 #include "cairo-dock-dock-manager.h"
+#include "cairo-dock-utils.h"  // cairo_dock_launch_command_full
+#include "cairo-dock-class-manager.h"  // gldi_class_startup_notify
 #include "cairo-dock-indicator-manager.h"
+#include "cairo-dock-applications-manager.h"  // GLDI_OBJECT_IS_APPLI_ICON
+#include "cairo-dock-applet-manager.h"  // GLDI_OBJECT_IS_APPLET_ICON
+#include "cairo-dock-separator-manager.h"  // GLDI_OBJECT_IS_SEPARATOR_ICON
 #include "cairo-dock-themes-manager.h"  // cairo_dock_update_conf_file
 #include "cairo-dock-log.h"
 #include "cairo-dock-draw-opengl.h"
 #include "cairo-dock-draw.h"
-#include "cairo-dock-gui-manager.h"  // cairo_dock_trigger_refresh_launcher_gui
 #include "cairo-dock-animations.h"  // CairoDockHidingEffect
 #include "cairo-dock-icon-facility.h"
 
@@ -48,23 +53,30 @@ extern CairoDockHidingEffect *g_pHidingBackend;
 extern CairoDockImageBuffer g_pIconBackgroundBuffer;
 
 
+void gldi_icon_set_appli (Icon *pIcon, GldiWindowActor *pAppli)
+{
+	if (pIcon->pAppli == pAppli)  // nothing to do
+		return;
+	
+	// unset the current appli if any
+	if (pIcon->pAppli != NULL)
+		gldi_object_unref (GLDI_OBJECT (pIcon->pAppli));
+	
+	// set the appli
+	if (pAppli)
+		gldi_object_ref (GLDI_OBJECT (pAppli));
+	pIcon->pAppli = pAppli;
+}
+
 CairoDockIconGroup cairo_dock_get_icon_type (Icon *icon)
 {
-	CairoDockIconGroup iGroup;
-	if (CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (icon))
+	/*CairoDockIconGroup iGroup;
+	if (GLDI_OBJECT_IS_SEPARATOR_ICON (icon))
 		iGroup = CAIRO_DOCK_SEPARATOR12;
 	else
 		iGroup = (icon->iGroup < CAIRO_DOCK_NB_GROUPS ? icon->iGroup : icon->iGroup & 1);
-	
-	return iGroup;
-	/**if (CAIRO_DOCK_IS_APPLI (icon))
-		return CAIRO_DOCK_APPLI;
-	else if (CAIRO_DOCK_IS_APPLET (icon))
-		return CAIRO_DOCK_APPLET;
-	else if (CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (icon))
-		return CAIRO_DOCK_SEPARATOR12;
-	else
-		return CAIRO_DOCK_LAUNCHER;*/
+	return iGroup;*/
+	return (icon->iGroup < CAIRO_DOCK_NB_GROUPS ? icon->iGroup : icon->iGroup & 1);
 }
 
 
@@ -227,18 +239,6 @@ Icon* cairo_dock_get_last_icon_of_order (GList *pIconList, CairoDockIconGroup iG
 	}
 	return NULL;
 }
-Icon* cairo_dock_get_first_icon_of_true_type (GList *pIconList, CairoDockIconTrueType iType)
-{
-	GList* ic;
-	Icon *icon;
-	for (ic = pIconList; ic != NULL; ic = ic->next)
-	{
-		icon = ic->data;
-		if (icon->iTrueType == iType)
-			return icon;
-	}
-	return NULL;
-}
 
 Icon* cairo_dock_get_pointed_icon (GList *pIconList)
 {
@@ -347,17 +347,39 @@ Icon *cairo_dock_get_icon_with_subdock (GList *pIconList, CairoDock *pSubDock)
 	return NULL;
 }
 
-Icon *cairo_dock_get_icon_with_module (GList *pIconList, CairoDockModule *pModule)
+static gboolean _has_dialog (CairoDialog *pDialog, Icon *pIcon)
 {
-	GList* ic;
-	Icon *icon;
+	return (pDialog->pIcon == pIcon);
+}
+gboolean gldi_icon_has_dialog (Icon *pIcon)
+{
+	CairoDialog *pDialog = gldi_dialogs_foreach ((GCompareFunc)_has_dialog, pIcon);
+	return (pDialog != NULL);
+}
+
+Icon *gldi_icons_get_without_dialog (GList *pIconList)
+{
+	if (pIconList == NULL)
+		return NULL;
+
+	Icon *pIcon = cairo_dock_get_first_icon_of_group (pIconList, CAIRO_DOCK_SEPARATOR12);
+	if (pIcon != NULL && ! gldi_icon_has_dialog (pIcon) && pIcon->cParentDockName != NULL && ! cairo_dock_icon_is_being_removed (pIcon))
+		return pIcon;
+	
+	pIcon = cairo_dock_get_pointed_icon (pIconList);
+	if (pIcon != NULL && ! CAIRO_DOCK_IS_NORMAL_APPLI (pIcon) && ! GLDI_OBJECT_IS_APPLET_ICON (pIcon) && ! gldi_icon_has_dialog (pIcon) && pIcon->cParentDockName != NULL && ! cairo_dock_icon_is_being_removed (pIcon))
+		return pIcon;
+
+	GList *ic;
 	for (ic = pIconList; ic != NULL; ic = ic->next)
 	{
-		icon = ic->data;
-		if (icon->pModuleInstance->pModule == pModule)
-			return icon;
+		pIcon = ic->data;
+		if (! gldi_icon_has_dialog (pIcon) && ! CAIRO_DOCK_IS_NORMAL_APPLI (pIcon) && ! GLDI_OBJECT_IS_APPLET_ICON (pIcon) && pIcon->cParentDockName != NULL && ! cairo_dock_icon_is_being_removed (pIcon))
+			return pIcon;
 	}
-	return NULL;
+	
+	pIcon = cairo_dock_get_first_icon (pIconList);
+	return pIcon;
 }
 
 void cairo_dock_get_icon_extent (Icon *pIcon, int *iWidth, int *iHeight)
@@ -366,11 +388,11 @@ void cairo_dock_get_icon_extent (Icon *pIcon, int *iWidth, int *iHeight)
 	*iHeight = pIcon->image.iHeight;
 }
 
-void cairo_dock_get_current_icon_size (Icon *pIcon, CairoContainer *pContainer, double *fSizeX, double *fSizeY)
+void cairo_dock_get_current_icon_size (Icon *pIcon, GldiContainer *pContainer, double *fSizeX, double *fSizeY)
 {
 	if (pContainer->bIsHorizontal)
 	{
-		if (myIconsParam.bConstantSeparatorSize && CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (pIcon))
+		if (myIconsParam.bConstantSeparatorSize && GLDI_OBJECT_IS_SEPARATOR_ICON (pIcon))
 		{
 			*fSizeX = pIcon->fWidth;
 			*fSizeY = pIcon->fHeight;
@@ -383,7 +405,7 @@ void cairo_dock_get_current_icon_size (Icon *pIcon, CairoContainer *pContainer,
 	}
 	else
 	{
-		if (myIconsParam.bConstantSeparatorSize && CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (pIcon))
+		if (myIconsParam.bConstantSeparatorSize && GLDI_OBJECT_IS_SEPARATOR_ICON (pIcon))
 		{
 			*fSizeX = pIcon->fHeight;
 			*fSizeY = pIcon->fWidth;
@@ -396,7 +418,7 @@ void cairo_dock_get_current_icon_size (Icon *pIcon, CairoContainer *pContainer,
 	}
 }
 
-void cairo_dock_compute_icon_area (Icon *icon, CairoContainer *pContainer, GdkRectangle *pArea)
+void cairo_dock_compute_icon_area (Icon *icon, GldiContainer *pContainer, GdkRectangle *pArea)
 {
 	double fReflectSize = 0;
 	if (pContainer->bUseReflect)
@@ -503,7 +525,7 @@ void cairo_dock_move_icon_after_icon (CairoDock *pDock, Icon *icon1, Icon *icon2
 	//g_print ("icon1->fOrder:%.2f\n", icon1->fOrder);
 	
 	//\_________________ On change l'ordre dans le fichier du lanceur 1.
-	cairo_dock_write_order_in_conf_file (icon1, icon1->fOrder);
+	gldi_theme_icon_write_order_in_conf_file (icon1, icon1->fOrder);
 	
 	//\_________________ On change sa place dans la liste.
 	pDock->icons = g_list_remove (pDock->icons, icon1);
@@ -528,21 +550,11 @@ void cairo_dock_move_icon_after_icon (CairoDock *pDock, Icon *icon1, Icon *icon2
 		cairo_dock_normalize_icons_order (pDock->icons, icon1->iGroup);
 	
 	//\_________________ Notify everybody.
-	cairo_dock_notify_on_object (pDock, NOTIFICATION_ICON_MOVED, icon1, pDock);
+	gldi_object_notify (pDock, NOTIFICATION_ICON_MOVED, icon1, pDock);
 }
 
 
-
-void cairo_dock_update_icon_s_container_name (Icon *icon, const gchar *cNewParentDockName)
-{
-	g_free (icon->cParentDockName);
-	icon->cParentDockName = g_strdup (cNewParentDockName);
-	
-	cairo_dock_write_container_name_in_conf_file (icon, cNewParentDockName);
-}
-
-
-void cairo_dock_set_icon_name (const gchar *cIconName, Icon *pIcon, G_GNUC_UNUSED CairoContainer *pContainer_useless)  // fonction proposee par Necropotame.
+void gldi_icon_set_name (Icon *pIcon, const gchar *cIconName)  // fonction proposee par Necropotame.
 {
 	g_return_if_fail (pIcon != NULL);  // le contexte sera verifie plus loin.
 	gchar *cUniqueName = NULL;
@@ -551,7 +563,7 @@ void cairo_dock_set_icon_name (const gchar *cIconName, Icon *pIcon, G_GNUC_UNUSE
 	{
 		cUniqueName = cairo_dock_get_unique_dock_name (cIconName);
 		cIconName = cUniqueName;
-		cairo_dock_rename_dock (pIcon->cName, pIcon->pSubDock, cUniqueName);
+		gldi_dock_rename (pIcon->pSubDock, cUniqueName);
 	}
 	if (pIcon->cName != cIconName)
 	{
@@ -567,17 +579,17 @@ void cairo_dock_set_icon_name (const gchar *cIconName, Icon *pIcon, G_GNUC_UNUSE
 		cairo_dock_redraw_container (pIcon->pContainer);  // this is not really optimized, ideally the view should provide a way to redraw the label area only...
 }
 
-void cairo_dock_set_icon_name_printf (Icon *pIcon, G_GNUC_UNUSED CairoContainer *pContainer_useless, const gchar *cIconNameFormat, ...)
+void gldi_icon_set_name_printf (Icon *pIcon, const gchar *cIconNameFormat, ...)
 {
 	va_list args;
 	va_start (args, cIconNameFormat);
 	gchar *cFullText = g_strdup_vprintf (cIconNameFormat, args);
-	cairo_dock_set_icon_name (cFullText, pIcon, NULL);
+	gldi_icon_set_name (pIcon, cFullText);
 	g_free (cFullText);
 	va_end (args);
 }
 
-void cairo_dock_set_quick_info (Icon *pIcon, G_GNUC_UNUSED CairoContainer *pContainer_useless, const gchar *cQuickInfo)
+void gldi_icon_set_quick_info (Icon *pIcon, const gchar *cQuickInfo)
 {
 	g_return_if_fail (pIcon != NULL);
 	
@@ -592,97 +604,17 @@ void cairo_dock_set_quick_info (Icon *pIcon, G_GNUC_UNUSED CairoContainer *pCont
 	cairo_dock_load_icon_quickinfo (pIcon);
 }
 
-void cairo_dock_set_quick_info_printf (Icon *pIcon, CairoContainer *pContainer_useless, const gchar *cQuickInfoFormat, ...)
+void gldi_icon_set_quick_info_printf (Icon *pIcon, const gchar *cQuickInfoFormat, ...)
 {
 	va_list args;
 	va_start (args, cQuickInfoFormat);
 	gchar *cFullText = g_strdup_vprintf (cQuickInfoFormat, args);
-	cairo_dock_set_quick_info (pIcon, pContainer_useless, cFullText);
+	gldi_icon_set_quick_info (pIcon, cFullText);
 	g_free (cFullText);
 	va_end (args);
 }
 
 
-gchar *cairo_dock_cut_string (const gchar *cString, int iNbCaracters)  // gere l'UTF-8
-{
-	g_return_val_if_fail (cString != NULL, NULL);
-	gchar *cTruncatedName = NULL;
-	gsize bytes_read, bytes_written;
-	GError *erreur = NULL;
-	gchar *cUtf8Name = g_locale_to_utf8 (cString,
-		-1,
-		&bytes_read,
-		&bytes_written,
-		&erreur);  // inutile sur Ubuntu, qui est nativement UTF8, mais sur les autres on ne sait pas.
-	if (erreur != NULL)
-	{
-		cd_warning (erreur->message);
-		g_error_free (erreur);
-		erreur = NULL;
-	}
-	if (cUtf8Name == NULL)  // une erreur s'est produite, on tente avec la chaine brute.
-		cUtf8Name = g_strdup (cString);
-	
-	const gchar *cEndValidChain = NULL;
-	int iStringLength;
-	if (g_utf8_validate (cUtf8Name, -1, &cEndValidChain))
-	{
-		iStringLength = g_utf8_strlen (cUtf8Name, -1);
-		int iNbChars = -1;
-		if (iNbCaracters < 0)
-		{
-			iNbChars = MAX (0, iStringLength + iNbCaracters);
-		}
-		else if (iStringLength > iNbCaracters)
-		{
-			iNbChars = iNbCaracters;
-		}
-		
-		if (iNbChars != -1)
-		{
-			cTruncatedName = g_new0 (gchar, 8 * (iNbChars + 4));  // 8 octets par caractere.
-			if (iNbChars != 0)
-				g_utf8_strncpy (cTruncatedName, cUtf8Name, iNbChars);
-			
-			gchar *cTruncature = g_utf8_offset_to_pointer (cTruncatedName, iNbChars);
-			*cTruncature = '.';
-			*(cTruncature+1) = '.';
-			*(cTruncature+2) = '.';
-		}
-	}
-	else
-	{
-		iStringLength = strlen (cString);
-		int iNbChars = -1;
-		if (iNbCaracters < 0)
-		{
-			iNbChars = MAX (0, iStringLength + iNbCaracters);
-		}
-		else if (iStringLength > iNbCaracters)
-		{
-			iNbChars = iNbCaracters;
-		}
-		
-		if (iNbChars != -1)
-		{
-			cTruncatedName = g_new0 (gchar, iNbCaracters + 4);
-			if (iNbChars != 0)
-				strncpy (cTruncatedName, cString, iNbChars);
-			
-			cTruncatedName[iNbChars] = '.';
-			cTruncatedName[iNbChars+1] = '.';
-			cTruncatedName[iNbChars+2] = '.';
-		}
-	}
-	if (cTruncatedName == NULL)
-		cTruncatedName = cUtf8Name;
-	else
-		g_free (cUtf8Name);
-	//g_print (" -> etiquette : %s\n", cTruncatedName);
-	return cTruncatedName;
-}
-
-
 GdkPixbuf *cairo_dock_icon_buffer_to_pixbuf (Icon *icon)
 {
 	g_return_val_if_fail (icon != NULL, NULL);
@@ -692,12 +624,18 @@ GdkPixbuf *cairo_dock_icon_buffer_to_pixbuf (Icon *icon)
 
 cairo_t *cairo_dock_begin_draw_icon_cairo (Icon *pIcon, gint iRenderingMode, cairo_t *pCairoContext)
 {
+	/*if (pIcon->pContainer)
+		// g_print ("= %s %dx%d\n", pIcon->cName, pIcon->pContainer->iWidth, pIcon->pContainer->iHeight);
+	else
+		// g_print ("= %s no container yet\n", pIcon->cName); // e.g. 'indicator' applets -> maybe a return is needed?
+	*/
+
 	cairo_t *ctx = cairo_dock_begin_draw_image_buffer_cairo (&pIcon->image, iRenderingMode, pCairoContext);
 	
 	if (ctx && iRenderingMode != 1)
 	{
 		if (g_pIconBackgroundBuffer.pSurface != NULL
-		&& ! CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (pIcon))
+		&& ! GLDI_OBJECT_IS_SEPARATOR_ICON (pIcon))
 		{
 			int iWidth, iHeight;
 			cairo_dock_get_icon_extent (pIcon, &iWidth, &iHeight);
@@ -714,14 +652,14 @@ void cairo_dock_end_draw_icon_cairo (Icon *pIcon)
 	cairo_dock_end_draw_image_buffer_cairo (&pIcon->image);
 }
 
-gboolean cairo_dock_begin_draw_icon (Icon *pIcon, G_GNUC_UNUSED CairoContainer *pContainer, gint iRenderingMode)
+gboolean cairo_dock_begin_draw_icon (Icon *pIcon, gint iRenderingMode)
 {
 	gboolean r = cairo_dock_begin_draw_image_buffer_opengl (&pIcon->image, pIcon->pContainer, iRenderingMode);
 	
 	if (r && iRenderingMode != 1)
 	{
 		if (g_pIconBackgroundBuffer.iTexture != 0
-		&& ! CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (pIcon))
+		&& ! GLDI_OBJECT_IS_SEPARATOR_ICON (pIcon))
 		{
 			int iWidth, iHeight;
 			cairo_dock_get_icon_extent (pIcon, &iWidth, &iHeight);
@@ -739,7 +677,65 @@ gboolean cairo_dock_begin_draw_icon (Icon *pIcon, G_GNUC_UNUSED CairoContainer *
 	return r;
 }
 
-void cairo_dock_end_draw_icon (Icon *pIcon, G_GNUC_UNUSED CairoContainer *pContainer)
+void cairo_dock_end_draw_icon (Icon *pIcon)
 {
 	cairo_dock_end_draw_image_buffer_opengl (&pIcon->image, pIcon->pContainer);
 }
+
+
+void gldi_theme_icon_write_container_name_in_conf_file (Icon *pIcon, const gchar *cParentDockName)
+{
+	if (GLDI_OBJECT_IS_USER_ICON (pIcon))
+	{
+		g_return_if_fail (pIcon->cDesktopFileName != NULL);
+		gchar *cDesktopFilePath = *pIcon->cDesktopFileName == '/' ? g_strdup (pIcon->cDesktopFileName) : g_strdup_printf ("%s/%s", g_cCurrentLaunchersPath, pIcon->cDesktopFileName);
+		cairo_dock_update_conf_file (cDesktopFilePath,
+			G_TYPE_STRING, "Desktop Entry", "Container", cParentDockName,
+			G_TYPE_INVALID);
+		g_free (cDesktopFilePath);
+	}
+	else if (GLDI_OBJECT_IS_APPLET_ICON (pIcon))
+	{
+		cairo_dock_update_conf_file (pIcon->pModuleInstance->cConfFilePath,
+			G_TYPE_STRING, "Icon", "dock name", cParentDockName,
+			G_TYPE_INVALID);
+	}
+}
+
+void gldi_theme_icon_write_order_in_conf_file (Icon *pIcon, double fOrder)
+{
+	if (GLDI_OBJECT_IS_USER_ICON (pIcon))
+	{
+		g_return_if_fail (pIcon->cDesktopFileName != NULL);
+		gchar *cDesktopFilePath = *pIcon->cDesktopFileName == '/' ? g_strdup (pIcon->cDesktopFileName) : g_strdup_printf ("%s/%s", g_cCurrentLaunchersPath, pIcon->cDesktopFileName);
+		cairo_dock_update_conf_file (cDesktopFilePath,
+			G_TYPE_DOUBLE, "Desktop Entry", "Order", fOrder,
+			G_TYPE_INVALID);
+		g_free (cDesktopFilePath);
+	}
+	else if (GLDI_OBJECT_IS_APPLET_ICON (pIcon))
+	{
+		cairo_dock_update_conf_file (pIcon->pModuleInstance->cConfFilePath,
+			G_TYPE_DOUBLE, "Icon", "order", fOrder,
+			G_TYPE_INVALID);
+	}
+}
+
+
+
+gboolean gldi_icon_launch_command (Icon *pIcon)
+{
+	// notify startup
+	gldi_class_startup_notify (pIcon);
+
+	// launch command
+	const gchar *cCommand = pIcon->cCommand;
+	const gchar *cWorkingDirectory = pIcon->cWorkingDirectory;
+	if (! cCommand)
+		cCommand = cairo_dock_get_class_command (pIcon->cClass);
+
+	gboolean bSuccess = cairo_dock_launch_command_full (cCommand, cWorkingDirectory);
+	if (! bSuccess)
+		gldi_class_startup_notify_end (pIcon->cClass);
+	return bSuccess;
+}
