@@ -42,18 +42,6 @@ G_BEGIN_DECLS
 * Specialized Icons are created by the corresponding factory.
 */
 
-/// Definition of the type of icons.
-typedef enum {
-	CAIRO_DOCK_ICON_TYPE_LAUNCHER = 0,
-	CAIRO_DOCK_ICON_TYPE_CONTAINER,
-	CAIRO_DOCK_ICON_TYPE_SEPARATOR,
-	CAIRO_DOCK_ICON_TYPE_CLASS_CONTAINER,
-	CAIRO_DOCK_ICON_TYPE_APPLI,
-	CAIRO_DOCK_ICON_TYPE_APPLET,
-	CAIRO_DOCK_ICON_TYPE_OTHER,
-	CAIRO_DOCK_NB_ICON_TYPES
-	} CairoDockIconTrueType;
-
 /// Available groups of icons.
 typedef enum {
 	CAIRO_DOCK_LAUNCHER = 0,  // launchers and applets, and applis if mixed
@@ -77,8 +65,6 @@ typedef enum {
 struct _IconInterface {
 	/// function that loads the icon surface (and optionnally texture).
 	void (*load_image) (Icon *icon);
-	/// function called when the icon is deleted from the current theme.
-	gboolean (*on_delete) (Icon *icon);
 	/// function called when the user drag something over the icon for more than 500ms.
 	void (*action_on_drag_hover) (Icon *icon);
 	};
@@ -89,13 +75,11 @@ struct _Icon {
 	/// object
 	GldiObject object;
 	gpointer pDataSlot[CAIRO_DOCK_NB_DATA_SLOT];
-	/// type of the icon.
-	CairoDockIconTrueType iTrueType;
 	/// group of the icon.
 	CairoDockIconGroup iGroup;
 	/// interface
 	IconInterface iface;
-	CairoContainer *pContainer;  // container where the icon is currently.
+	GldiContainer *pContainer;  // container where the icon is currently.
 	
 	//\____________ properties.
 	// generic.
@@ -118,12 +102,13 @@ struct _Icon {
 	gint iSubdockViewType;
 	/// a hint to indicate the icon should be kept static (no animation like bouncing).
 	gboolean bStatic;
-	/// a flag that allows the icon to be always visible, even with the dock is hidden.
+	/// a flag that allows the icon to be always visible, even when the dock is hidden.
 	gboolean bAlwaysVisible;
 	gboolean bIsDemandingAttention;
 	gboolean bHasHiddenBg;
-	gdouble *pHiddenBgColor;  // NULL to use the default color
+	GldiColor *pHiddenBgColor;  // NULL to use the default color
 	gboolean bIgnoreQuicklist;  // TRUE to not display the Ubuntu's quicklist of the class
+	gboolean bHasIndicator;
 	
 	// Launcher.
 	gchar *cDesktopFileName;  // nom (et non pas chemin) du fichier .desktop
@@ -133,28 +118,14 @@ struct _Icon {
 	gint iVolumeID;
 	gchar **pMimeTypes;
 	gchar *cWmClass;
+	gchar *cInitialName;
 	
 	// Appli.
-	Window Xid;
-	gboolean bIsHidden;
-	gboolean bIsFullScreen;
-	gboolean bIsMaximized;
-	guint iDemandsAttention;  // a mask of CairoAppliAttentionFlag
-	gboolean bHasIndicator;
-	GtkAllocation windowGeometry;
-	gint iNumDesktop;
-	gint iViewPortX, iViewPortY;
-	gint iStackOrder;
-	gint iLastCheckTime;
-	gchar *cInitialName;
-	gchar *cLastAttentionDemand;
-	gint iAge;  // age of the window (a mere growing integer).
-	Pixmap iBackingPixmap;
-	//Damage iDamageHandle;
+	GldiWindowActor *pAppli;
 	
 	// Applet.
-	CairoDockModuleInstance *pModuleInstance;
-	CairoDockModuleInstance *pAppletOwner;
+	GldiModuleInstance *pModuleInstance;
+	GldiModuleInstance *pAppletOwner;
 	
 	//\____________ Buffers.
 	gdouble fWidth, fHeight;  // size at rest in the container (including ratio and orientation).
@@ -202,15 +173,15 @@ struct _Icon {
 	gint iHideLabel;
 	gint iThumbnailX, iThumbnailY;  // X icon geometry for apps
 	gint iThumbnailWidth, iThumbnailHeight;
-	gboolean bBeingRemovedByCairo;  // devrait etre dans pDataSlot...
 	
+	gboolean bIsLaunching;  // a mere recopy of gldi_class_is_starting()
 	gpointer reserved[4];
 };
 
 typedef void (*CairoIconContainerLoadFunc) (void);
 typedef void (*CairoIconContainerUnloadFunc) (void);
-typedef void (*CairoIconContainerRenderFunc) (Icon *pIcon, CairoContainer *pContainer, int w, int h, cairo_t *pCairoContext);
-typedef void (*CairoIconContainerRenderOpenGLFunc) (Icon *pIcon, CairoContainer *pContainer, int w, int h);
+typedef void (*CairoIconContainerRenderFunc) (Icon *pIcon, GldiContainer *pContainer, int w, int h, cairo_t *pCairoContext);
+typedef void (*CairoIconContainerRenderOpenGLFunc) (Icon *pIcon, GldiContainer *pContainer, int w, int h);
 
 /// Definition of an Icon container (= an icon holding a sub-dock) renderer.
 struct _CairoIconContainerRenderer {
@@ -220,18 +191,23 @@ struct _CairoIconContainerRenderer {
 	CairoIconContainerRenderOpenGLFunc render_opengl;
 };
 
+/** Say if an object is an Icon.
+*@param obj the object.
+*@return TRUE if the object is an icon.
+*/
+#define CAIRO_DOCK_IS_ICON(obj) gldi_object_is_manager_child (obj, &myIconObjectMgr)
 
-#define CAIRO_DOCK_ICON_TYPE_IS_LAUNCHER(icon) (icon != NULL && (icon)->iTrueType == CAIRO_DOCK_ICON_TYPE_LAUNCHER)
-#define CAIRO_DOCK_ICON_TYPE_IS_CONTAINER(icon) (icon != NULL && (icon)->iTrueType == CAIRO_DOCK_ICON_TYPE_CONTAINER)
-#define CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR(icon) (icon != NULL && (icon)->iTrueType == CAIRO_DOCK_ICON_TYPE_SEPARATOR)
-#define CAIRO_DOCK_ICON_TYPE_IS_CLASS_CONTAINER(icon) (icon != NULL && (icon)->iTrueType == CAIRO_DOCK_ICON_TYPE_CLASS_CONTAINER)
-#define CAIRO_DOCK_ICON_TYPE_IS_APPLI(icon) (icon != NULL && (icon)->iTrueType == CAIRO_DOCK_ICON_TYPE_APPLI)
-#define CAIRO_DOCK_ICON_TYPE_IS_APPLET(icon) (icon != NULL && (icon)->iTrueType == CAIRO_DOCK_ICON_TYPE_APPLET)
+#define CAIRO_DOCK_ICON_TYPE_IS_LAUNCHER GLDI_OBJECT_IS_LAUNCHER_ICON
+#define CAIRO_DOCK_ICON_TYPE_IS_CONTAINER GLDI_OBJECT_IS_STACK_ICON
+#define CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR GLDI_OBJECT_IS_SEPARATOR_ICON
+#define CAIRO_DOCK_ICON_TYPE_IS_CLASS_CONTAINER GLDI_OBJECT_IS_CLASS_ICON
+#define CAIRO_DOCK_ICON_TYPE_IS_APPLI GLDI_OBJECT_IS_APPLI_ICON
+#define CAIRO_DOCK_ICON_TYPE_IS_APPLET GLDI_OBJECT_IS_APPLET_ICON
 
 /** TRUE if the icon holds a window.
 *@param icon an icon.
 */
-#define CAIRO_DOCK_IS_APPLI(icon) (icon != NULL && (icon)->Xid != 0)
+#define CAIRO_DOCK_IS_APPLI(icon) (icon != NULL && (icon)->pAppli != NULL)
 
 /** TRUE if the icon holds an instance of a module.
 *@param icon an icon.
@@ -265,22 +241,31 @@ struct _CairoIconContainerRenderer {
 *TRUE if the icon is an icon d'applet detachable en desklet.
 *@param icon an icon.
 */
-#define CAIRO_DOCK_IS_DETACHABLE_APPLET(icon) (CAIRO_DOCK_IS_APPLET (icon) && (icon)->pModuleInstance->bCanDetach)
+#define CAIRO_DOCK_IS_DETACHABLE_APPLET(icon) (CAIRO_DOCK_IS_APPLET (icon) && ((icon)->pModuleInstance->pModule->pVisitCard->iContainerType & CAIRO_DOCK_MODULE_CAN_DESKLET))
 
 
 /** Create an empty icon.
 *@return the newly allocated icon object.
 */
-Icon *cairo_dock_new_icon (void);
+Icon *gldi_icon_new (void);
 
-void cairo_dock_free_icon_buffers (Icon *icon);
+
+/** Create an Icon that will behave like a launcher. It's especially useful for applets that want to fill a sub-dock or a desklet (the icon is not loaded by the function). Be careful that the strings are not duplicated. Therefore, you must use g_strdup() if you want to set a constant string; and must not free the strings after calling this function.
+* @param cName label of the icon
+* @param cFileName name of an image
+* @param cCommand a command, or NULL
+* @param cQuickInfo a quick-info, or NULL
+* @param fOrder order of the icon in its container.
+* @return the newly created icon.
+*/
+Icon * cairo_dock_create_dummy_launcher (gchar *cName, gchar *cFileName, gchar *cCommand, gchar *cQuickInfo, double fOrder);
 
 
 /* Cree la surface de reflection d'une icone (pour cairo).
 *@param pIcon l'icone.
 *@param pContainer le container de l'icone.
 */
-void cairo_dock_add_reflection_to_icon (Icon *pIcon, CairoContainer *pContainer);
+void cairo_dock_add_reflection_to_icon (Icon *pIcon, GldiContainer *pContainer);
 
 
 gboolean cairo_dock_apply_icon_background_opengl (Icon *icon);
@@ -289,7 +274,7 @@ gboolean cairo_dock_apply_icon_background_opengl (Icon *icon);
 *@param icon the icon.
 *@param pContainer its container.
 */
-void cairo_dock_load_icon_image (Icon *icon, CairoContainer *pContainer);
+void cairo_dock_load_icon_image (Icon *icon, GldiContainer *pContainer);
 #define cairo_dock_reload_icon_image cairo_dock_load_icon_image
 
 /**Fill the label buffer (surface & texture) of a given icon, according to a text description.
@@ -306,7 +291,7 @@ void cairo_dock_load_icon_quickinfo (Icon *icon);
 *@param pIcon the icon.
 *@param pContainer its container.
 */
-void cairo_dock_load_icon_buffers (Icon *pIcon, CairoContainer *pContainer);
+void cairo_dock_load_icon_buffers (Icon *pIcon, GldiContainer *pContainer);
 
 void cairo_dock_trigger_load_icon_buffers (Icon *pIcon);
 
@@ -316,5 +301,10 @@ void cairo_dock_draw_subdock_content_on_icon (Icon *pIcon, CairoDock *pDock);
 #define cairo_dock_set_subdock_content_renderer(pIcon, view) (pIcon)->iSubdockViewType = view
 
 
+void gldi_icon_detach (Icon *pIcon);
+
+void gldi_icon_insert_in_container (Icon *pIcon, GldiContainer *pContainer, gboolean bAnimateIcon);
+
+
 G_END_DECLS
 #endif
