@@ -27,7 +27,6 @@
 #include "cairo-dock-icon-factory.h"
 #include "cairo-dock-module-instance-manager.h"  // gldi_module_instance_reload
 #include "cairo-dock-desklet-manager.h"  // gldi_desklets_foreach_icons
-#include "cairo-dock-utils.h"  // cairo_dock_colors_differ
 #include "cairo-dock-log.h"
 #include "cairo-dock-config.h"
 #include "cairo-dock-class-manager.h"  // cairo_dock_deinhibite_class
@@ -37,7 +36,6 @@
 #include "cairo-dock-dock-manager.h"  // gldi_icons_foreach_in_docks
 #include "cairo-dock-dialog-manager.h"  // cairo_dock_remove_dialog_if_any
 #include "cairo-dock-data-renderer.h"  // cairo_dock_remove_data_renderer_on_icon
-#include "cairo-dock-file-manager.h"  // cairo_dock_fm_remove_monitor_full
 #include "cairo-dock-animations.h"  // cairo_dock_animation_will_be_visible
 #include "cairo-dock-dock-facility.h"  // cairo_dock_update_dock_size
 #include "cairo-dock-icon-facility.h"  // gldi_icons_foreach_of_type
@@ -50,6 +48,7 @@
 #include "cairo-dock-launcher-manager.h"  // GLDI_OBJECT_IS_LAUNCHER_ICON
 #include "cairo-dock-applet-manager.h"  // GLDI_OBJECT_IS_APPLET_ICON
 #include "cairo-dock-backends-manager.h"  // cairo_dock_foreach_icon_container_renderer
+#include "cairo-dock-style-manager.h"
 #define _MANAGER_DEF_
 #include "cairo-dock-icon-manager.h"
 
@@ -244,7 +243,6 @@ gchar *cairo_dock_search_icon_s_path (const gchar *cFileName, gint iDesiredIconS
 	const gchar *cSuffixTab[4] = {".svg", ".png", ".xpm", NULL};
 	gboolean bHasSuffix=FALSE, bFileFound=FALSE, bHasVersion=FALSE;
 	GtkIconInfo* pIconInfo = NULL;
-	int j;
 	gchar *str = strrchr (cFileName, '.');
 	bHasSuffix = (str != NULL && g_ascii_isalpha (*(str+1)));  // exemple : "firefox.svg", but not "firefox-3.0"
 	bHasVersion = (str != NULL && g_ascii_isdigit (*(str+1)) && g_ascii_isdigit (*(str-1)) && str-1 != cFileName);  // doit finir par x.y, x et y ayant autant de chiffres que l'on veut.
@@ -254,7 +252,7 @@ gchar *cairo_dock_search_icon_s_path (const gchar *cFileName, gint iDesiredIconS
 	{
 		if (! bHasSuffix)  // test all the suffix one by one.
 		{
-			j = 0;
+			int j = 0;
 			while (cSuffixTab[j] != NULL)
 			{
 				g_string_printf (sIconPath, "%s/%s%s", g_cCurrentIconsPath, cFileName, cSuffixTab[j]);
@@ -488,7 +486,6 @@ static gboolean get_config (GKeyFile *pKeyFile, CairoIconsParam *pIcons)
 				pIcons->iSeparatorType = CAIRO_DOCK_NORMAL_SEPARATOR;
 			else
 			{
-				gsize length=0;
 				if (strcmp (cMainDockDefaultRendererName, "3D plane") == 0)
 				{
 					pIcons->iSeparatorType = g_key_file_get_integer (keyfile, "Inclinated Plane", "draw separator", NULL);
@@ -497,27 +494,22 @@ static gboolean get_config (GKeyFile *pKeyFile, CairoIconsParam *pIcons)
 				{
 					pIcons->iSeparatorType = g_key_file_get_integer (keyfile, "Curve", "draw curve separator", NULL);
 				}
-				double *color = g_key_file_get_double_list (keyfile, "Inclinated Plane", "separator color", &length, NULL);
-				if (length > 0)
-					memcpy (pIcons->fSeparatorColor, color, length*sizeof (gdouble));
-				else
-				{
-					pIcons->fSeparatorColor[0] = pIcons->fSeparatorColor[1] = pIcons->fSeparatorColor[2] = .9;
-				}
-				if (length < 4)
-					pIcons->fSeparatorColor[3] = 1.;
+				cairo_dock_get_color_key_value (keyfile, "Inclinated Plane", "separator color", &bFlushConfFileNeeded, &pIcons->fSeparatorColor, NULL, NULL, NULL);
 				g_key_file_free (keyfile);
 			}
 		}
 		g_key_file_set_integer (pKeyFile, "Icons", "separator type", pIcons->iSeparatorType);
-		g_key_file_set_double_list (pKeyFile, "Icons", "separator color", pIcons->fSeparatorColor, 4);
+		g_key_file_set_double_list (pKeyFile, "Icons", "separator color", (double*)&pIcons->fSeparatorColor.rgba, 4);
 		g_free (cMainDockDefaultRendererName);
 	}
 	else
 	{
-		double couleur[4] = {0.9,0.9,1.0,1.0};
-		cairo_dock_get_double_list_key_value (pKeyFile, "Icons", "separator color", &bFlushConfFileNeeded, pIcons->fSeparatorColor, 4, couleur, NULL, NULL);
+		GldiColor couleur = {{0.9,0.9,1.0,1.0}};
+		cairo_dock_get_color_key_value (pKeyFile, "Icons", "separator color", &bFlushConfFileNeeded, &pIcons->fSeparatorColor, &couleur, NULL, NULL);
 	}
+	
+	pIcons->bSeparatorUseDefaultColors = (cairo_dock_get_integer_key_value (pKeyFile, "Icons", "separator_style", &bFlushConfFileNeeded, 1, NULL, NULL) == 0);
+	
 	if (pIcons->iSeparatorType == CAIRO_DOCK_NORMAL_SEPARATOR)
 		pIcons->cSeparatorImage = cairo_dock_get_string_key_value (pKeyFile, "Icons", "separator image", &bFlushConfFileNeeded, NULL, "Separators", NULL);
 
@@ -525,101 +517,67 @@ static gboolean get_config (GKeyFile *pKeyFile, CairoIconsParam *pIcons)
 
 	pIcons->bConstantSeparatorSize = cairo_dock_get_boolean_key_value (pKeyFile, "Icons", "force size", &bFlushConfFileNeeded, TRUE, "Separators", NULL);
 	
-	///pIcons->fReflectSize = pIcons->iIconHeight * pIcons->fReflectHeightRatio;
-	
 	//\___________________ labels font
 	CairoIconsParam *pLabels = pIcons;
 	gboolean bCustomFont = cairo_dock_get_boolean_key_value (pKeyFile, "Labels", "custom", &bFlushConfFileNeeded, TRUE, NULL, NULL);
 	
-	gchar *cFontDescription = (bCustomFont ? cairo_dock_get_string_key_value (pKeyFile, "Labels", "police", &bFlushConfFileNeeded, NULL, "Icons", NULL) : NULL);
-	if (cFontDescription == NULL)
-		cFontDescription = cairo_dock_get_default_system_font ();
+	gchar *cFont = (bCustomFont ? cairo_dock_get_string_key_value (pKeyFile, "Labels", "police", &bFlushConfFileNeeded, NULL, "Icons", NULL) : NULL);
+	gldi_text_description_set_font (&pLabels->iconTextDescription, cFont);
 	
-	PangoFontDescription *fd = pango_font_description_from_string (cFontDescription);
-	pLabels->iconTextDescription.cFont = g_strdup (pango_font_description_get_family (fd));
-	pLabels->iconTextDescription.iSize = pango_font_description_get_size (fd);
-	if (!pango_font_description_get_size_is_absolute (fd))
-		pLabels->iconTextDescription.iSize /= PANGO_SCALE;
-	if (!bCustomFont)
-		pLabels->iconTextDescription.iSize *= 1.33;  // c'est pas beau, mais ca evite de casser tous les themes.
-	if (pLabels->iconTextDescription.iSize == 0)
-		pLabels->iconTextDescription.iSize = 14;
-	pLabels->iconTextDescription.iWeight = pango_font_description_get_weight (fd);
-	pLabels->iconTextDescription.iStyle = pango_font_description_get_style (fd);
-	
-	if (g_key_file_has_key (pKeyFile, "Labels", "size", NULL))  // anciens parametres.
-	{
-		pLabels->iconTextDescription.iSize = g_key_file_get_integer (pKeyFile, "Labels", "size", NULL);
-		int iLabelWeight = g_key_file_get_integer (pKeyFile, "Labels", "weight", NULL);
-		pLabels->iconTextDescription.iWeight = cairo_dock_get_pango_weight_from_1_9 (iLabelWeight);
-		gboolean bLabelStyleItalic = g_key_file_get_boolean (pKeyFile, "Labels", "italic", NULL);
-		if (bLabelStyleItalic)
-			pLabels->iconTextDescription.iStyle = PANGO_STYLE_ITALIC;
-		else
-			pLabels->iconTextDescription.iStyle = PANGO_STYLE_NORMAL;
-		
-		pango_font_description_set_size (fd, pLabels->iconTextDescription.iSize * PANGO_SCALE);
-		pango_font_description_set_weight (fd, pLabels->iconTextDescription.iWeight);
-		pango_font_description_set_style (fd, pLabels->iconTextDescription.iStyle);
-		
-		g_free (cFontDescription);
-		cFontDescription = pango_font_description_to_string (fd);
-		g_key_file_set_string (pKeyFile, "Labels", "police", cFontDescription);
-		bFlushConfFileNeeded = TRUE;
-	}
-	pango_font_description_free (fd);
-	g_free (cFontDescription);
+	cd_debug ("label font: %s, %d\n", pLabels->iconTextDescription.cFont, pLabels->iconTextDescription.iSize);
 	
 	//\___________________ labels text color
 	pLabels->iconTextDescription.bOutlined = cairo_dock_get_boolean_key_value (pKeyFile, "Labels", "text oulined", &bFlushConfFileNeeded, TRUE, NULL, NULL);
 	
-	double couleur_label[3] = {1., 1., 1.};
-	cairo_dock_get_double_list_key_value (pKeyFile, "Labels", "text color start", &bFlushConfFileNeeded, pLabels->iconTextDescription.fColorStart, 3, couleur_label, "Icons", NULL);
-	
-	cairo_dock_get_double_list_key_value (pKeyFile, "Labels", "text color stop", &bFlushConfFileNeeded, pLabels->iconTextDescription.fColorStop, 3, couleur_label, "Icons", NULL);
-	
-	pLabels->iconTextDescription.bVerticalPattern = cairo_dock_get_boolean_key_value (pKeyFile, "Labels", "vertical label pattern", &bFlushConfFileNeeded, TRUE, "Icons", NULL);
-
-	double couleur_backlabel[4] = {0., 0., 0., 0.5};
-	cairo_dock_get_double_list_key_value (pKeyFile, "Labels", "text background color", &bFlushConfFileNeeded, pLabels->iconTextDescription.fBackgroundColor, 4, couleur_backlabel, "Icons", NULL);
-	if (!g_key_file_has_key (pKeyFile, "Labels", "qi same", NULL))  // old params
+	GldiColor couleur_backlabel = {{0., 0., 0., 0.85}};
+	GldiColor couleur_label = {{1., 1., 1., 1.}};
+	gboolean bDefaultColors = (cairo_dock_get_integer_key_value (pKeyFile, "Labels", "style", &bFlushConfFileNeeded, 0, NULL, NULL) == 0);
+	pLabels->iconTextDescription.bUseDefaultColors = bDefaultColors;
+	if (bDefaultColors)
 	{
-		gboolean bUseBackgroundForLabel = cairo_dock_get_boolean_key_value (pKeyFile, "Labels", "background for label", &bFlushConfFileNeeded, FALSE, "Icons", NULL);
-		if (! bUseBackgroundForLabel)
+		pLabels->iconTextDescription.bOutlined = FALSE;
+	}
+	else
+	{
+		cairo_dock_get_color_key_value (pKeyFile, "Labels", "text color", &bFlushConfFileNeeded, &pLabels->iconTextDescription.fColorStart, &couleur_label, "Labels", "text color start");
+		
+		GldiColor couleur_linelabel = {{0., 0., 0., 1}};
+		cairo_dock_get_color_key_value (pKeyFile, "Labels", "text line color", &bFlushConfFileNeeded, &pLabels->iconTextDescription.fLineColor, &couleur_linelabel, NULL, NULL);
+		
+		cairo_dock_get_color_key_value (pKeyFile, "Labels", "text bg color", &bFlushConfFileNeeded, &pLabels->iconTextDescription.fBackgroundColor, &couleur_backlabel, "Icons", "text background color");
+		if (!g_key_file_has_key (pKeyFile, "Labels", "qi same", NULL))  // old params
 		{
-			pLabels->iconTextDescription.fBackgroundColor[3] = 0;  // ne sera pas dessine.
-			g_key_file_set_double_list (pKeyFile, "Icons", "text background color", pLabels->iconTextDescription.fBackgroundColor, 4);
+			gboolean bUseBackgroundForLabel = cairo_dock_get_boolean_key_value (pKeyFile, "Labels", "background for label", &bFlushConfFileNeeded, FALSE, "Icons", NULL);
+			if (! bUseBackgroundForLabel)
+			{
+				pLabels->iconTextDescription.fBackgroundColor.rgba.alpha = 0;  // ne sera pas dessine.
+				g_key_file_set_double_list (pKeyFile, "Icons", "text background color", (double*)&pLabels->iconTextDescription.fBackgroundColor.rgba, 4);
+			}
 		}
 	}
 	
 	pLabels->iconTextDescription.iMargin = cairo_dock_get_integer_key_value (pKeyFile, "Labels", "text margin", &bFlushConfFileNeeded, 4, NULL, NULL);
 	
 	//\___________________ quick-info
-	memcpy (&pLabels->quickInfoTextDescription, &pLabels->iconTextDescription, sizeof (CairoDockLabelDescription));
+	gldi_text_description_copy (&pLabels->quickInfoTextDescription, &pLabels->iconTextDescription);
 	pLabels->quickInfoTextDescription.iMargin = 1;  // to minimize the surface of the quick-info (0 would be too much).
-	pLabels->quickInfoTextDescription.cFont = g_strdup (pLabels->iconTextDescription.cFont);
-	pLabels->quickInfoTextDescription.iSize = 12;
-	pLabels->quickInfoTextDescription.iWeight = PANGO_WEIGHT_HEAVY;
-	pLabels->quickInfoTextDescription.iStyle = PANGO_STYLE_NORMAL;
+	pLabels->quickInfoTextDescription.iSize = 12;  // no need to update the fd, it will be done when loading the text buffer
 	
 	gboolean bQuickInfoSameLook = cairo_dock_get_boolean_key_value (pKeyFile, "Labels", "qi same", &bFlushConfFileNeeded, TRUE, NULL, NULL);
-	if (bQuickInfoSameLook)
+	if ( !bQuickInfoSameLook)
 	{
-		memcpy (pLabels->quickInfoTextDescription.fBackgroundColor, pLabels->iconTextDescription.fBackgroundColor, 4 * sizeof (gdouble));
-		memcpy (pLabels->quickInfoTextDescription.fColorStart, pLabels->iconTextDescription.fColorStart, 3 * sizeof (gdouble));
+		cairo_dock_get_color_key_value (pKeyFile, "Labels", "qi bg color", &bFlushConfFileNeeded, &pLabels->quickInfoTextDescription.fBackgroundColor, &couleur_backlabel, NULL, NULL);
+		cairo_dock_get_color_key_value (pKeyFile, "Labels", "qi text color", &bFlushConfFileNeeded, &pLabels->quickInfoTextDescription.fColorStart, &couleur_label, NULL, NULL);
+		pLabels->quickInfoTextDescription.bUseDefaultColors = FALSE;
 	}
-	else
-	{
-		cairo_dock_get_double_list_key_value (pKeyFile, "Labels", "qi bg color", &bFlushConfFileNeeded, pLabels->quickInfoTextDescription.fBackgroundColor, 4, couleur_backlabel, NULL, NULL);
-		cairo_dock_get_double_list_key_value (pKeyFile, "Labels", "qi text color", &bFlushConfFileNeeded, pLabels->quickInfoTextDescription.fColorStart, 3, couleur_label, NULL, NULL);
-	}
-	memcpy (pLabels->quickInfoTextDescription.fColorStop, pLabels->quickInfoTextDescription.fColorStart, 3 * sizeof (gdouble));
 	
 	pLabels->iLabelSize = (pLabels->iconTextDescription.iSize != 0 ?
 		pLabels->iconTextDescription.iSize +
 		(pLabels->iconTextDescription.bOutlined ? 2 : 0) +
-		2 * pLabels->iconTextDescription.iMargin
-		+ 6 : 0);
+		2 * pLabels->iconTextDescription.iMargin +
+		6  // 2px linewidth + 3px to take into account the y offset of the characters + 1 px to take into account the gap between icon and label
+		: 0);
+	cd_debug ("iLabelSize: %d (%d)\n", pLabels->iLabelSize, pLabels->iconTextDescription.iSize);
 	
 	//\___________________ labels visibility
 	int iShowLabel = cairo_dock_get_integer_key_value (pKeyFile, "Labels", "show_labels", &bFlushConfFileNeeded, -1, NULL, NULL);
@@ -647,8 +605,6 @@ static gboolean get_config (GKeyFile *pKeyFile, CairoIconsParam *pIcons)
 	pLabels->fLabelAlphaThreshold = cairo_dock_get_double_key_value (pKeyFile, "Labels", "alpha threshold", &bFlushConfFileNeeded, 10., "System", NULL);
 	pLabels->fLabelAlphaThreshold = (pLabels->fLabelAlphaThreshold + 10.) / 10.;  // [0;50] -> [1;6]
 	
-	pLabels->bTextAlwaysHorizontal = cairo_dock_get_boolean_key_value (pKeyFile, "Labels", "always horizontal", &bFlushConfFileNeeded, FALSE, "System", NULL);
-	
 	return bFlushConfFileNeeded;
 }
 
@@ -665,8 +621,8 @@ static void reset_config (CairoIconsParam *pIcons)
 	
 	// labels
 	CairoIconsParam *pLabels = pIcons;
-	g_free (pLabels->iconTextDescription.cFont);
-	g_free (pLabels->quickInfoTextDescription.cFont);
+	gldi_text_description_reset (&pLabels->iconTextDescription);
+	gldi_text_description_reset (&pLabels->quickInfoTextDescription);
 }
 
 
@@ -789,15 +745,16 @@ static void _calculate_icons (G_GNUC_UNUSED const gchar *cDockName, CairoDock *p
 	cairo_dock_calculate_dock_icons (pDock);
 }
 
+static void _cairo_dock_resize_one_dock (G_GNUC_UNUSED const gchar *cDockName, CairoDock *pDock, G_GNUC_UNUSED gpointer data)
+{
+	cairo_dock_update_dock_size (pDock);
+}
+
 static void _reload_one_label (Icon *pIcon, G_GNUC_UNUSED gpointer data)
 {
 	cairo_dock_load_icon_text (pIcon);
 	cairo_dock_load_icon_quickinfo (pIcon);
 }
-static void _cairo_dock_resize_one_dock (G_GNUC_UNUSED const gchar *cDockName, CairoDock *pDock, G_GNUC_UNUSED gpointer data)
-{
-	cairo_dock_update_dock_size (pDock);
-}
 
 static void reload (CairoIconsParam *pPrevIcons, CairoIconsParam *pIcons)
 {
@@ -807,14 +764,13 @@ static void reload (CairoIconsParam *pPrevIcons, CairoIconsParam *pIcons)
 	gboolean bSeparatorsNeedReload = (pPrevIcons->iSeparatorWidth != pIcons->iSeparatorWidth
 		|| pPrevIcons->iSeparatorHeight != pIcons->iSeparatorHeight
 		|| pPrevIcons->iSeparatorType != pIcons->iSeparatorType
-		|| cairo_dock_colors_differ (pPrevIcons->fSeparatorColor, pIcons->fSeparatorColor));  // same if color has changed (for the flat separator rendering)
+		|| gldi_color_compare (&pPrevIcons->fSeparatorColor, &pIcons->fSeparatorColor));  // same if color has changed (for the flat separator rendering)
 	gboolean bSeparatorNeedRedraw = (g_strcmp0 (pPrevIcons->cSeparatorImage, pIcons->cSeparatorImage) != 0
 		|| pPrevIcons->bRevolveSeparator != pIcons->bRevolveSeparator);
 	
 	if (bSeparatorsNeedReload || bSeparatorNeedRedraw)
 	{
 		gldi_docks_foreach ((GHFunc)_reload_separators, GINT_TO_POINTER(bSeparatorsNeedReload));
-		return;
 	}
 	
 	gboolean bThemeChanged = (g_strcmp0 (pIcons->cIconTheme, pPrevIcons->cIconTheme) != 0);
@@ -919,8 +875,6 @@ static void unload (void)
 		g_pGradationTexture[1] = 0;
 	}
 	
-	cairo_dock_reset_source_context ();
-	
 	_cairo_dock_unload_icon_theme ();
 }
 
@@ -929,6 +883,38 @@ static void unload (void)
  /// INIT ///
 ////////////
 
+static gboolean on_style_changed (G_GNUC_UNUSED gpointer data)
+{
+	cd_debug ("Icons: style changed to %d", myIconsParam.iconTextDescription.bUseDefaultColors);
+	
+	if (myIconsParam.iconTextDescription.cFont == NULL)  // default font -> reload our text description
+	{
+		gldi_text_description_set_font (&myIconsParam.iconTextDescription, NULL);
+		myIconsParam.quickInfoTextDescription.fd = pango_font_description_copy (myIconsParam.iconTextDescription.fd);
+	}
+	
+	if (myIconsParam.iconTextDescription.bUseDefaultColors || myIconsParam.iconTextDescription.cFont == NULL)  // reload labels and quick-info
+	{
+		cd_debug ("reload labels...");
+		gldi_icons_foreach ((GldiIconFunc) _reload_one_label, NULL);
+	}
+	
+	// if label size changed, reload docks views
+	int iLabelSize = (myIconsParam.iconTextDescription.iSize != 0 ?
+		myIconsParam.iconTextDescription.iSize +
+		(myIconsParam.iconTextDescription.bOutlined ? 2 : 0) +
+		2 * myIconsParam.iconTextDescription.iMargin +
+		6  // 2px linewidth + 3px to take into account the y offset of the characters + 1 px to take into account the gap between icon and label
+		: 0);
+	if (iLabelSize != myIconsParam.iLabelSize)
+	{
+		cd_debug ("myIconsParam.iLabelSize: %d -> %d (%d)", myIconsParam.iLabelSize, iLabelSize, myIconsParam.iconTextDescription.iSize);
+		myIconsParam.iLabelSize = iLabelSize;
+		gldi_docks_foreach ((GHFunc) _cairo_dock_resize_one_dock, NULL);
+	}
+	return GLDI_NOTIFICATION_LET_PASS;
+}
+
 static void init (void)
 {
 	gldi_object_register_notification (&myDesktopMgr,
@@ -939,7 +925,10 @@ static void init (void)
 		NOTIFICATION_RENDER_ICON,
 		(GldiNotificationFunc) cairo_dock_render_icon_notification,
 		GLDI_RUN_FIRST, NULL);
-	
+	gldi_object_register_notification (&myStyleMgr,
+		NOTIFICATION_STYLE_CHANGED,
+		(GldiNotificationFunc) on_style_changed,
+		GLDI_RUN_AFTER, NULL);
 }
 
   ///////////////
