@@ -33,13 +33,12 @@
 #include "cairo-dock-task.h"
 #include "cairo-dock-config.h"
 #include "cairo-dock-log.h"
-#include "cairo-dock-notifications.h"
 #define _MANAGER_DEF_
 #include "cairo-dock-packages.h"
 
 // public (manager, config, data)
 CairoConnectionParam myConnectionParam;
-CairoConnectionManager myConnectionMgr;
+GldiManager myConnectionMgr;
 
 // dependancies
 
@@ -282,15 +281,15 @@ static void _free_dl (gpointer *pSharedMemory)
 	g_free (pSharedMemory[4]);
 	g_free (pSharedMemory);
 }
-CairoDockTask *cairo_dock_download_file_async (const gchar *cURL, const gchar *cLocalPath, GFunc pCallback, gpointer data)
+GldiTask *cairo_dock_download_file_async (const gchar *cURL, const gchar *cLocalPath, GFunc pCallback, gpointer data)
 {
 	gpointer *pSharedMemory = g_new0 (gpointer, 5);
 	pSharedMemory[0] = g_strdup (cURL);
 	pSharedMemory[1] = g_strdup (cLocalPath);
 	pSharedMemory[2] = pCallback;
 	pSharedMemory[3] = data;
-	CairoDockTask *pTask = cairo_dock_new_task_full (0, (CairoDockGetDataAsyncFunc) _dl_file, (CairoDockUpdateSyncFunc) _finish_dl, (GFreeFunc) _free_dl, pSharedMemory);
-	cairo_dock_launch_task (pTask);
+	GldiTask *pTask = gldi_task_new_full (0, (GldiGetDataAsyncFunc) _dl_file, (GldiUpdateSyncFunc) _finish_dl, (GFreeFunc) _free_dl, pSharedMemory);
+	gldi_task_launch (pTask);
 	return pTask;
 }
 
@@ -388,14 +387,14 @@ static void _free_dl_content (gpointer *pSharedMemory)
 	g_free (pSharedMemory[3]);
 	g_free (pSharedMemory);
 }
-CairoDockTask *cairo_dock_get_url_data_async (const gchar *cURL, GFunc pCallback, gpointer data)
+GldiTask *cairo_dock_get_url_data_async (const gchar *cURL, GFunc pCallback, gpointer data)
 {
 	gpointer *pSharedMemory = g_new0 (gpointer, 6);
 	pSharedMemory[0] = g_strdup (cURL);
 	pSharedMemory[1] = pCallback;
 	pSharedMemory[2] = data;
-	CairoDockTask *pTask = cairo_dock_new_task_full (0, (CairoDockGetDataAsyncFunc) _dl_file_content, (CairoDockUpdateSyncFunc) _finish_dl_content, (GFreeFunc) _free_dl_content, pSharedMemory);
-	cairo_dock_launch_task (pTask);
+	GldiTask *pTask = gldi_task_new_full (0, (GldiGetDataAsyncFunc) _dl_file_content, (GldiUpdateSyncFunc) _finish_dl_content, (GFreeFunc) _free_dl_content, pSharedMemory);
+	gldi_task_launch (pTask);
 	return pTask;
 }
 
@@ -741,7 +740,7 @@ static void _discard_list_packages (gpointer *pSharedMemory)
 		g_hash_table_unref (pSharedMemory[5]);
 	g_free (pSharedMemory);
 }
-CairoDockTask *cairo_dock_list_packages_async (const gchar *cSharePackagesDir, const gchar *cUserPackagesDir, const gchar *cDistantPackagesDir, CairoDockGetPackagesFunc pCallback, gpointer data, GHashTable *pTable)
+GldiTask *cairo_dock_list_packages_async (const gchar *cSharePackagesDir, const gchar *cUserPackagesDir, const gchar *cDistantPackagesDir, CairoDockGetPackagesFunc pCallback, gpointer data, GHashTable *pTable)
 {
 	gpointer *pSharedMemory = g_new0 (gpointer, 6);
 	pSharedMemory[0] = g_strdup (cSharePackagesDir);
@@ -750,8 +749,8 @@ CairoDockTask *cairo_dock_list_packages_async (const gchar *cSharePackagesDir, c
 	pSharedMemory[3] = pCallback;
 	pSharedMemory[4] = data;
 	pSharedMemory[5] = pTable;  // can be NULL
-	CairoDockTask *pTask = cairo_dock_new_task_full (0, (CairoDockGetDataAsyncFunc) _list_packages, (CairoDockUpdateSyncFunc) _finish_list_packages, (GFreeFunc) _discard_list_packages, pSharedMemory);
-	cairo_dock_launch_task (pTask);
+	GldiTask *pTask = gldi_task_new_full (0, (GldiGetDataAsyncFunc)_list_packages, (GldiUpdateSyncFunc)_finish_list_packages, (GFreeFunc) _discard_list_packages, pSharedMemory);
+	gldi_task_launch (pTask);
 	return pTask;
 }
 
@@ -893,22 +892,22 @@ static void init (void)
 void gldi_register_connection_manager (void)
 {
 	// Manager
-	memset (&myConnectionMgr, 0, sizeof (CairoConnectionManager));
-	myConnectionMgr.mgr.cModuleName 	= "Connection";
-	myConnectionMgr.mgr.init 		= init;
-	myConnectionMgr.mgr.load 		= NULL;
-	myConnectionMgr.mgr.unload 		= NULL;
-	myConnectionMgr.mgr.reload 		= (GldiManagerReloadFunc)NULL;
-	myConnectionMgr.mgr.get_config 	= (GldiManagerGetConfigFunc)get_config;
-	myConnectionMgr.mgr.reset_config = (GldiManagerResetConfigFunc)reset_config;
+	memset (&myConnectionMgr, 0, sizeof (GldiManager));
+	gldi_object_init (GLDI_OBJECT(&myConnectionMgr), &myManagerObjectMgr, NULL);
+	myConnectionMgr.cModuleName  = "Connection";
+	// interface
+	myConnectionMgr.init         = init;
+	myConnectionMgr.load         = NULL;
+	myConnectionMgr.unload       = NULL;
+	myConnectionMgr.reload       = (GldiManagerReloadFunc)NULL;
+	myConnectionMgr.get_config   = (GldiManagerGetConfigFunc)get_config;
+	myConnectionMgr.reset_config = (GldiManagerResetConfigFunc)reset_config;
 	// Config
-	myConnectionMgr.mgr.pConfig = (GldiManagerConfigPtr)&myConnectionParam;
-	myConnectionMgr.mgr.iSizeOfConfig = sizeof (CairoConnectionParam);
+	myConnectionMgr.pConfig = (GldiManagerConfigPtr)&myConnectionParam;
+	myConnectionMgr.iSizeOfConfig = sizeof (CairoConnectionParam);
 	// data
-	myConnectionMgr.mgr.pData = (GldiManagerDataPtr)NULL;
-	myConnectionMgr.mgr.iSizeOfData = 0;
+	myConnectionMgr.pData = (GldiManagerDataPtr)NULL;
+	myConnectionMgr.iSizeOfData = 0;
 	// signals
-	cairo_dock_install_notifications_on_object (&myConnectionMgr, NB_NOTIFICATIONS_CONNECTION);
-	// register
-	gldi_register_manager (GLDI_MANAGER(&myConnectionMgr));
+	gldi_object_install_notifications (&myConnectionMgr, NB_NOTIFICATIONS_CONNECTION);  // we don't have a Connection Object, so let's put the signals here
 }
