@@ -39,11 +39,7 @@
 #include "cairo-dock-opengl.h"  // for texture_from_pixmap
 #include "cairo-dock-X-utilities.h"
 
-#if (GTK_MAJOR_VERSION >= 3)
 #include <cairo/cairo-xlib.h>  // needed for cairo_xlib_surface_create
-#else
-#include <gdk/gdkx.h>  // gdk_xid_table_lookup (gtk2)
-#endif
 
 extern gboolean g_bEasterEggs;
 extern CairoDockGLConfig g_openglConfig;
@@ -91,6 +87,7 @@ static Atom s_aNetWmName;
 static Atom s_aWmName;
 static Atom s_aUtf8String;
 static Atom s_aString;
+static unsigned char error_code = Success;
 
 static GtkAllocation *_get_screens_geometry (int *pNbScreens);
 
@@ -110,7 +107,8 @@ typedef struct {
 
 static int _cairo_dock_xerror_handler (G_GNUC_UNUSED Display * pDisplay, XErrorEvent *pXError)
 {
-	cd_debug ("Error (%d, %d, %d) during an X request on %d", pXError->error_code, pXError->request_code, pXError->minor_code, pXError->resourceid);
+	//g_print ("Error (%d, %d, %d) during an X request on %d\n", pXError->error_code, pXError->request_code, pXError->minor_code, pXError->resourceid);
+	error_code = pXError->error_code;
 	return 0;
 }
 Display *cairo_dock_initialize_X_desktop_support (void)
@@ -177,6 +175,16 @@ Display *cairo_dock_get_X_display (void)
 	return s_XDisplay;
 }
 
+void cairo_dock_reset_X_error_code (void)
+{
+	error_code = Success;
+}
+
+unsigned char cairo_dock_get_X_error_code (void)
+{
+	return error_code;
+}
+
 static GtkAllocation *_get_screens_geometry (int *pNbScreens)
 {
 	GtkAllocation *pScreens = NULL;
@@ -296,7 +304,7 @@ static GtkAllocation *_get_screens_geometry (int *pNbScreens)
 	int i;
 	for (i = 0; i < iBufferNbElements/4; i ++)
 	{
-		g_print ("work area : (%d;%d) %dx%d\n", pXWorkArea[4*i], pXWorkArea[4*i+1], pXWorkArea[4*i+2], pXWorkArea[4*i+3]);
+		// g_print ("work area : (%d;%d) %dx%d\n", pXWorkArea[4*i], pXWorkArea[4*i+1], pXWorkArea[4*i+2], pXWorkArea[4*i+3]);
 	}
 	XFree (pXWorkArea);*/
 	
@@ -538,6 +546,7 @@ void cairo_dock_show_hide_desktop (gboolean bShow)
 		False,
 		SubstructureRedirectMask | SubstructureNotifyMask,
 		&xClientMessage);
+	XFlush (s_XDisplay);
 }
 
 static void cairo_dock_move_current_viewport_to (int iDesktopViewportX, int iDesktopViewportY)
@@ -563,6 +572,7 @@ static void cairo_dock_move_current_viewport_to (int iDesktopViewportX, int iDes
 		False,
 		SubstructureRedirectMask | SubstructureNotifyMask,
 		&xClientMessage);
+	XFlush (s_XDisplay);
 }
 void cairo_dock_set_current_viewport (int iViewportNumberX, int iViewportNumberY)
 {
@@ -592,6 +602,7 @@ void cairo_dock_set_current_desktop (int iDesktopNumber)
 		False,
 		SubstructureRedirectMask | SubstructureNotifyMask,
 		&xClientMessage);
+	XFlush (s_XDisplay);
 }
 
 Pixmap cairo_dock_get_window_background_pixmap (Window Xid)
@@ -630,43 +641,6 @@ GdkPixbuf *cairo_dock_get_pixbuf_from_pixmap (int XPixmapID, gboolean bAddAlpha)
 	//g_print ("%s (%d) : %ux%ux%u (%d;%d)\n", __func__, XPixmapID, iWidth, iHeight, iDepth, x, y);
 
 	//\__________________ On recupere le drawable associe.
-	#if (GTK_MAJOR_VERSION < 3)
-	GdkDrawable *pGdkDrawable = gdk_xid_table_lookup (XPixmapID);
-	if (pGdkDrawable)
-	{
-		g_object_ref (G_OBJECT (pGdkDrawable));
-	}
-	else
-	{
-		//g_print ("pas d'objet GDK present, on en alloue un nouveau\n");
-		GdkScreen* pScreen = gdk_screen_get_default ();
-		pGdkDrawable = gdk_pixmap_foreign_new_for_screen (pScreen, XPixmapID, iWidth, iHeight, iDepth);
-	}
-
-	//\__________________ On recupere la colormap.
-	GdkColormap* pColormap = gdk_drawable_get_colormap (pGdkDrawable);
-	if (pColormap == NULL && gdk_drawable_get_depth (pGdkDrawable) > 1)  // pour les bitmaps, on laisse la colormap a NULL, ils n'en ont pas besoin.
-	{
-		GdkScreen *pScreen = gdk_drawable_get_screen (GDK_DRAWABLE (pGdkDrawable));
-		if (gdk_drawable_get_depth (pGdkDrawable) == 32)
-			pColormap = gdk_screen_get_rgba_colormap (pScreen);
-		else
-			pColormap = gdk_screen_get_rgb_colormap (pScreen);  // au pire on a un colormap nul.
-		//cd_debug ("  pColormap : %x  (pScreen:%x)", pColormap, pScreen);
-	}
-
-	//\__________________ On recupere le buffer dans un GdkPixbuf.
-	GdkPixbuf *pIconPixbuf = gdk_pixbuf_get_from_drawable (NULL,
-		pGdkDrawable,
-		pColormap,
-		0,
-		0,
-		0,
-		0,
-		iWidth,
-		iHeight);
-	g_object_unref (G_OBJECT (pGdkDrawable));
-	#else
 	cairo_surface_t *surface = cairo_xlib_surface_create (s_XDisplay,
 		XPixmapID,
 		DefaultVisual(s_XDisplay, 0),
@@ -678,7 +652,6 @@ GdkPixbuf *cairo_dock_get_pixbuf_from_pixmap (int XPixmapID, gboolean bAddAlpha)
 		iWidth,
 		iHeight);
 	cairo_surface_destroy(surface);
-	#endif
 	g_return_val_if_fail (pIconPixbuf != NULL, NULL);
 
 	//\__________________ On lui ajoute un canal alpha si necessaire.
@@ -716,6 +689,7 @@ void cairo_dock_set_nb_viewports (int iNbViewportX, int iNbViewportY)
 		False,
 		SubstructureRedirectMask | SubstructureNotifyMask,
 		&xClientMessage);
+	XFlush (s_XDisplay);
 }
 
 void cairo_dock_set_nb_desktops (gulong iNbDesktops)
@@ -741,6 +715,7 @@ void cairo_dock_set_nb_desktops (gulong iNbDesktops)
 		False,
 		SubstructureRedirectMask | SubstructureNotifyMask,
 		&xClientMessage);
+	XFlush (s_XDisplay);
 }
 
 
@@ -898,6 +873,7 @@ void cairo_dock_close_xwindow (Window Xid)
 		False,
 		SubstructureRedirectMask | SubstructureNotifyMask,
 		&xClientMessage);
+	XFlush (s_XDisplay);
 	//cairo_dock_set_xwindow_timestamp (Xid, cairo_dock_get_xwindow_timestamp (root));
 }
 
@@ -905,6 +881,7 @@ void cairo_dock_kill_xwindow (Window Xid)
 {
 	g_return_if_fail (Xid > 0);
 	XKillClient (s_XDisplay, Xid);
+	XFlush (s_XDisplay);
 }
 
 void cairo_dock_show_xwindow (Window Xid)
@@ -937,22 +914,21 @@ void cairo_dock_show_xwindow (Window Xid)
 		False,
 		SubstructureRedirectMask | SubstructureNotifyMask,
 		&xClientMessage);
-
-	//cairo_dock_set_xwindow_timestamp (Xid, cairo_dock_get_xwindow_timestamp (root));
+	XFlush (s_XDisplay);
 }
 
 void cairo_dock_minimize_xwindow (Window Xid)
 {
 	g_return_if_fail (Xid > 0);
 	XIconifyWindow (s_XDisplay, Xid, DefaultScreen (s_XDisplay));
-	//Window root = DefaultRootWindow (s_XDisplay);
-	//cairo_dock_set_xwindow_timestamp (Xid, cairo_dock_get_xwindow_timestamp (root));
+	XFlush (s_XDisplay);
 }
 
 void cairo_dock_lower_xwindow (Window Xid)
 {
 	g_return_if_fail (Xid > 0);
 	XLowerWindow (s_XDisplay, Xid);
+	XFlush (s_XDisplay);
 }
 
 
@@ -983,6 +959,7 @@ static void _cairo_dock_change_window_state (Window Xid, gulong iNewValue, Atom
 		&xClientMessage);
 
 	cairo_dock_set_xwindow_timestamp (Xid, cairo_dock_get_xwindow_timestamp (root));
+	XFlush (s_XDisplay);
 }
 void cairo_dock_maximize_xwindow (Window Xid, gboolean bMaximize)
 {
@@ -1047,6 +1024,7 @@ void cairo_dock_move_xwindow_to_absolute_position (Window Xid, int iDesktopNumbe
 		False,
 		SubstructureRedirectMask | SubstructureNotifyMask,
 		&xClientMessage);
+	XFlush (s_XDisplay);
 
 	//cairo_dock_set_xwindow_timestamp (Xid, cairo_dock_get_xwindow_timestamp (root));
 }
@@ -1137,12 +1115,40 @@ gchar *cairo_dock_get_xwindow_class (Window Xid, gchar **cWMClass)
 		cWmClass = g_strdup (pClassHint->res_class);
 		
 		cd_debug ("  res_name : %s(%x); res_class : %s(%x)", pClassHint->res_name, pClassHint->res_name, pClassHint->res_class, pClassHint->res_class);
-		if (strcmp (pClassHint->res_class, "Wine") == 0 && pClassHint->res_name && (g_str_has_suffix (pClassHint->res_name, ".exe") || g_str_has_suffix (pClassHint->res_name, ".EXE")))
+		if (strcmp (pClassHint->res_class, "Wine") == 0 && pClassHint->res_name && (g_str_has_suffix (pClassHint->res_name, ".exe") || g_str_has_suffix (pClassHint->res_name, ".EXE")))  // wine application: use the name instead, because we don't want to group all wine apps togather
 		{
 			cd_debug ("  wine application detected, changing the class '%s' to '%s'", pClassHint->res_class, pClassHint->res_name);
 			cClass = g_ascii_strdown (pClassHint->res_name, -1);
 		}
-		else if (*pClassHint->res_class == '/' && (g_str_has_suffix (pClassHint->res_class, ".exe") || g_str_has_suffix (pClassHint->res_name, ".EXE")))  // cas des applications Mono telles que tomboy ...
+		// chromium web apps (not the browser): same remark as for wine apps
+		else if (pClassHint->res_name && pClassHint->res_name[0] != '\0' && pClassHint->res_class[0] != '\0'
+		         && (strcmp (pClassHint->res_class, "Chromium-browser") == 0 // on Debian, etc.
+		          || strcmp (pClassHint->res_class, "Chromium") == 0         // on Arch, etc.
+		          || strcmp (pClassHint->res_class, "Google-chrome") == 0    // from Google
+		          || strcmp (pClassHint->res_class, "Google-chrome-beta") == 0
+		          || strcmp (pClassHint->res_class, "Google-chrome-unstable") == 0)
+		         && strcmp (pClassHint->res_class+1, pClassHint->res_name+1) != 0) // skip first letter (upper/lowercase)
+		{
+			cClass = g_ascii_strdown (pClassHint->res_name, -1);
+
+			/* Remove spaces. Why do they add spaces here?
+			 * (e.g.: Google-chrome-unstable (/home/$USER/.config/google-chrome-unstable))
+			 */
+			gchar *str = strchr (cClass, ' ');
+			if (str != NULL)
+				*str = '\0';
+
+			/* Replace '.' to '_' (e.g.: www.google.com__calendar). It's to not
+			 * just have 'www' as class (we will drop the rest just here after)
+			 */
+			for (int i = 0; cClass[i] != '\0'; i++)
+			{
+				if (cClass[i] == '.')
+					cClass[i] = '_';
+			}
+			cd_debug ("  chromium application detected, changing the class '%s' to '%s'", pClassHint->res_class, cClass);
+		}
+		else if (*pClassHint->res_class == '/' && (g_str_has_suffix (pClassHint->res_class, ".exe") || g_str_has_suffix (pClassHint->res_name, ".EXE")))  // case of Mono applications like tomboy ...
 		{
 			gchar *str = strrchr (pClassHint->res_class, '/');
 			if (str)
@@ -1154,12 +1160,12 @@ gchar *cairo_dock_get_xwindow_class (Window Xid, gchar **cWMClass)
 		}
 		else
 		{
-			cClass = g_ascii_strdown (pClassHint->res_class, -1);  // on la passe en minuscule, car certaines applis ont la bonne idee de donner des classes avec une majuscule ou non suivant les fenetres.
+			cClass = g_ascii_strdown (pClassHint->res_class, -1);  // down case because some apps change the case depending of their windows...
 		}
-		
-		cairo_dock_remove_version_from_string (cClass);  // on enleve les numeros de version (Openoffice.org-3.1)
-		
-		gchar *str = strchr (cClass, '.');  // on vire les .xxx, sinon on ne sait pas detecter l'absence d'extension quand on cherche l'icone (openoffice.org), ou tout simplement ca empeche de trouver l'icone (jbrout.py).
+
+		cairo_dock_remove_version_from_string (cClass);  // we remore number of version (e.g. Openoffice.org-3.1)
+
+		gchar *str = strchr (cClass, '.');  // we remove all .xxx otherwise we can't detect the lack of extension when looking for an icon (openoffice.org) or it's a problem when looking for an icon (jbrout.py).
 		if (str != NULL)
 			*str = '\0';
 		cd_debug ("got an application with class '%s'", cClass);
@@ -1705,6 +1711,8 @@ GLuint cairo_dock_texture_from_pixmap (Window Xid, Pixmap iBackingPixmap)
 	return texture;
 	
 	#else
+	(void)Xid;  // avoid unused warning
+	(void)iBackingPixmap;
 	return 0;
 	#endif
 }
