@@ -1,3 +1,4 @@
+
 /**
 * This file is a part of the Cairo-Dock project
 *
@@ -23,7 +24,6 @@
 #include <gtk/gtk.h>
 #include <cairo.h>
 
-#include "texture-blur.h"
 #include "gldi-config.h"
 #include "cairo-dock-icon-facility.h"
 #include "cairo-dock-backends-manager.h"
@@ -37,34 +37,21 @@
 #include "cairo-dock-dock-facility.h"
 #include "cairo-dock-object.h"
 #include "cairo-dock-dock-manager.h"
+#include "cairo-dock-style-manager.h"
 #include "cairo-dock-desktop-manager.h"  // gldi_dock_get_screen_width
 #include "cairo-dock-default-view.h"
 
-extern gboolean g_bUseOpenGL;
-
-static GLuint s_iFlatSeparatorTexture = 0;
-
-
-static gboolean cd_default_view_free_data (G_GNUC_UNUSED gpointer pUserData, CairoDock *pDock)  // si la vue 'default' etait dans un plug-in on n'aurait pas besoin de faire ca (on pourrait detruire nos donnees lors du stop_module), si elle etait dans la lib-core on pourrait le faire lors du unload_texture, mais elle est dans le main.
-{
-	if (pDock->bIsMainDock && s_iFlatSeparatorTexture != 0)
-	{
-		//g_print ("%s (%d)\n", __func__, s_iFlatSeparatorTexture);
-		_cairo_dock_delete_texture (s_iFlatSeparatorTexture);
-		s_iFlatSeparatorTexture = 0;
-	}
-	return GLDI_NOTIFICATION_LET_PASS;
-}
-
 
 static void cd_calculate_max_dock_size_default (CairoDock *pDock)
 {
 	cairo_dock_calculate_icons_positions_at_rest_linear (pDock->icons, pDock->fFlatDockWidth);
 
 	pDock->iDecorationsHeight = pDock->iMaxIconHeight * pDock->container.fRatio + 2 * myDocksParam.iFrameMargin;
-
-	double fRadius = MIN (myDocksParam.iDockRadius, (pDock->iDecorationsHeight + myDocksParam.iDockLineWidth) / 2 - 1);
-	double fExtraWidth = myDocksParam.iDockLineWidth + 2 * (fRadius + myDocksParam.iFrameMargin);
+	double fLineWidth = (myDocksParam.bUseDefaultColors ? myStyleParam.iLineWidth : myDocksParam.iDockLineWidth);
+	double fRadius = (myDocksParam.bUseDefaultColors ? myStyleParam.iCornerRadius : myDocksParam.iDockRadius);
+	if (pDock->iDecorationsHeight + fLineWidth - 2 * fRadius < 0)
+		fRadius = (pDock->iDecorationsHeight + fLineWidth) / 2 - 1;
+	double fExtraWidth = fLineWidth + 2 * (fRadius + myDocksParam.iFrameMargin);
 	int iMaxDockWidth = ceil (cairo_dock_calculate_max_dock_width (pDock, pDock->fFlatDockWidth, 1., fExtraWidth));
 	pDock->iOffsetForExtend = 0;
 	pDock->iMaxDockWidth = iMaxDockWidth;
@@ -85,11 +72,11 @@ static void cd_calculate_max_dock_size_default (CairoDock *pDock)
 		}
 	}
 	
-	pDock->iMaxDockHeight = (int) ((1 + myIconsParam.fAmplitude) * pDock->iMaxIconHeight * pDock->container.fRatio) + myDocksParam.iDockLineWidth + myDocksParam.iFrameMargin + (pDock->container.bIsHorizontal || !myIconsParam.bTextAlwaysHorizontal ? myIconsParam.iLabelSize : 0);
+	pDock->iMaxDockHeight = (int) ((1 + myIconsParam.fAmplitude) * pDock->iMaxIconHeight * pDock->container.fRatio) + fLineWidth + myDocksParam.iFrameMargin + (pDock->container.bIsHorizontal ? myIconsParam.iLabelSize : 0);
 	//g_print ("myIconsParam.iLabelSize : %d => %d\n", myIconsParam.iLabelSize, (int)pDock->iMaxDockHeight);
 
 	pDock->iDecorationsWidth = pDock->iMaxDockWidth;
-	pDock->iMinDockHeight = pDock->iMaxIconHeight * pDock->container.fRatio + 2 * myDocksParam.iFrameMargin + 2 * myDocksParam.iDockLineWidth;
+	pDock->iMinDockHeight = pDock->iMaxIconHeight * pDock->container.fRatio + 2 * myDocksParam.iFrameMargin + 2 * fLineWidth;
 	
 	/**if (cairo_dock_is_extended_dock (pDock))  // mode panel etendu.
 	{
@@ -123,43 +110,27 @@ static void cd_calculate_max_dock_size_default (CairoDock *pDock)
 	///else
 		pDock->iMinDockWidth = MAX (1, pDock->fFlatDockWidth);  // fFlatDockWidth peut etre meme negatif avec un dock vide.
 	
-	if (g_bUseOpenGL && s_iFlatSeparatorTexture == 0 && myIconsParam.iSeparatorType == CAIRO_DOCK_FLAT_SEPARATOR)
-		s_iFlatSeparatorTexture = cairo_dock_create_texture_from_raw_data (blurTex, 32, 32);
-	
 	///pDock->iActiveWidth = pDock->iMaxDockWidth;
 	pDock->iActiveWidth = iMaxDockWidth;
 	pDock->iActiveHeight = pDock->iMaxDockHeight;
-	if (! pDock->container.bIsHorizontal && myIconsParam.bTextAlwaysHorizontal)
+	if (! pDock->container.bIsHorizontal)
 		pDock->iMaxDockHeight += 8*myIconsParam.iLabelSize;  // vertical dock, add some padding to draw the labels.	
 }
 
 
 static void _draw_flat_separator (Icon *icon, G_GNUC_UNUSED CairoDock *pDock, cairo_t *pCairoContext, G_GNUC_UNUSED double fDockMagnitude)
 {
-	double fSizeX = icon->fWidth * icon->fScale, fSizeY = icon->fHeight * icon->fScale;
+	double fSizeX = icon->fWidth * icon->fScale, fSizeY = icon->fHeight;
 	cairo_set_operator (pCairoContext, CAIRO_OPERATOR_OVER);
 	
-	cairo_translate (pCairoContext, icon->fDrawX + .25 * fSizeX, icon->fDrawY);
-	double rx = .25*fSizeX;
-	double ry = .5*fSizeY;
-	cairo_pattern_t *pPattern = cairo_pattern_create_radial (ry,
-		ry,
-		0.,
-		ry,
-		ry,
-		ry);
-	cairo_pattern_set_extend (pPattern, CAIRO_EXTEND_NONE);
-	
-	cairo_pattern_add_color_stop_rgba (pPattern,
-		0.,
-		myIconsParam.fSeparatorColor[0], myIconsParam.fSeparatorColor[1], myIconsParam.fSeparatorColor[2], myIconsParam.fSeparatorColor[3]);
-	cairo_pattern_add_color_stop_rgba (pPattern,
-		1.,
-		myIconsParam.fSeparatorColor[0], myIconsParam.fSeparatorColor[1], myIconsParam.fSeparatorColor[2], 0.);
-	cairo_scale (pCairoContext, rx/ry, 1.);
-	cairo_set_source (pCairoContext, pPattern);
-	cairo_paint (pCairoContext);
-	cairo_pattern_destroy (pPattern);
+	if (myIconsParam.bSeparatorUseDefaultColors)
+		gldi_style_colors_set_separator_color (pCairoContext);
+	else
+		gldi_color_set_cairo (pCairoContext, &myIconsParam.fSeparatorColor);
+	cairo_move_to (pCairoContext, icon->fDrawX + .5 * fSizeX, icon->fDrawY + (pDock->container.bDirectionUp ? icon->fHeight * icon->fScale - fSizeY : 0));
+	cairo_set_line_width (pCairoContext, myDocksParam.iDockLineWidth);
+	cairo_rel_line_to (pCairoContext, 0., fSizeY);
+	cairo_stroke (pCairoContext);
 }
 
 static void _draw_physical_separator (Icon *icon, CairoDock *pDock, cairo_t *pCairoContext, G_GNUC_UNUSED double fDockMagnitude)
@@ -176,7 +147,10 @@ static void _draw_physical_separator (Icon *icon, CairoDock *pDock, cairo_t *pCa
 		cairo_fill (pCairoContext);
 		
 		cairo_set_operator (pCairoContext, CAIRO_OPERATOR_OVER);
-		cairo_set_source_rgba (pCairoContext, myDocksParam.fLineColor[0], myDocksParam.fLineColor[1], myDocksParam.fLineColor[2], myDocksParam.fLineColor[3]);
+		if (myDocksParam.bUseDefaultColors)
+			gldi_style_colors_set_line_color (pCairoContext);
+		else
+			gldi_color_set_cairo (pCairoContext, &myDocksParam.fLineColor);
 		
 		cairo_move_to (pCairoContext,
 			-.5*myDocksParam.iDockLineWidth,
@@ -197,7 +171,10 @@ static void _draw_physical_separator (Icon *icon, CairoDock *pDock, cairo_t *pCa
 		cairo_fill (pCairoContext);
 		
 		cairo_set_operator (pCairoContext, CAIRO_OPERATOR_OVER);
-		cairo_set_source_rgba (pCairoContext, myDocksParam.fLineColor[0], myDocksParam.fLineColor[1], myDocksParam.fLineColor[2], myDocksParam.fLineColor[3]);
+		if (myDocksParam.bUseDefaultColors)
+			gldi_style_colors_set_line_color (pCairoContext);
+		else
+			gldi_color_set_cairo (pCairoContext, &myDocksParam.fLineColor);
 		
 		cairo_move_to (pCairoContext,
 			pDock->container.bDirectionUp ? pDock->container.iHeight - pDock->iDecorationsHeight - myDocksParam.iDockLineWidth : 0.,
@@ -224,9 +201,11 @@ static void _cairo_dock_draw_separator (Icon *icon, CairoDock *pDock, cairo_t *p
 static void cd_render_default (cairo_t *pCairoContext, CairoDock *pDock)
 {
 	//\____________________ On trace le cadre.
-	double fLineWidth = myDocksParam.iDockLineWidth;
+	double fLineWidth = (myDocksParam.bUseDefaultColors ? myStyleParam.iLineWidth : myDocksParam.iDockLineWidth);
 	double fMargin = myDocksParam.iFrameMargin;
-	double fRadius = (pDock->iDecorationsHeight + fLineWidth - 2 * myDocksParam.iDockRadius > 0 ? myDocksParam.iDockRadius : (pDock->iDecorationsHeight + fLineWidth) / 2 - 1);
+	double fRadius = (myDocksParam.bUseDefaultColors ? myStyleParam.iCornerRadius : myDocksParam.iDockRadius);
+	if (pDock->iDecorationsHeight + fLineWidth - 2 * fRadius < 0)
+		fRadius = (pDock->iDecorationsHeight + fLineWidth) / 2 - 1;
 	double fExtraWidth = 2 * fRadius + fLineWidth;
 	double fDockWidth;
 	int sens;
@@ -269,7 +248,10 @@ static void cd_render_default (cairo_t *pCairoContext, CairoDock *pDock)
 	if (fLineWidth > 0)
 	{
 		cairo_set_line_width (pCairoContext, fLineWidth);
-		cairo_set_source_rgba (pCairoContext, myDocksParam.fLineColor[0], myDocksParam.fLineColor[1], myDocksParam.fLineColor[2], myDocksParam.fLineColor[3]);
+		if (myDocksParam.bUseDefaultColors)
+			gldi_style_colors_set_line_color (pCairoContext);
+		else
+			gldi_color_set_cairo (pCairoContext, &myDocksParam.fLineColor);
 		cairo_stroke (pCairoContext);
 	}
 	else
@@ -281,8 +263,6 @@ static void cd_render_default (cairo_t *pCairoContext, CairoDock *pDock)
 		cairo_dock_draw_string (pCairoContext, pDock, myIconsParam.iStringLineWidth, FALSE, FALSE);
 
 	//\____________________ On dessine les icones et les etiquettes, en tenant compte de l'ordre pour dessiner celles en arriere-plan avant celles en avant-plan.
-	///cairo_dock_render_icons_linear (pCairoContext, pDock);
-	
 	GList *pFirstDrawnElement = cairo_dock_get_first_drawn_element_linear (pDock->icons);
 	if (pFirstDrawnElement == NULL)
 		return;
@@ -352,6 +332,10 @@ static void cd_render_optimized_default (cairo_t *pCairoContext, CairoDock *pDoc
 	cairo_dock_render_decorations_in_frame (pCairoContext, pDock, fDockOffsetY, fOffsetX - fDeltaXTrapeze, fDockWidth + 2*fDeltaXTrapeze);
 	
 	//\____________________ On dessine la partie du cadre qui va bien.
+	if (myDocksParam.bUseDefaultColors)
+		gldi_style_colors_set_line_color (pCairoContext);
+	else
+		gldi_color_set_cairo (pCairoContext, &myDocksParam.fLineColor);
 	cairo_new_path (pCairoContext);
 
 	if (pDock->container.bIsHorizontal)
@@ -359,28 +343,24 @@ static void cd_render_optimized_default (cairo_t *pCairoContext, CairoDock *pDoc
 		cairo_move_to (pCairoContext, fDockOffsetX, fDockOffsetY - fLineWidth / 2);
 		cairo_rel_line_to (pCairoContext, pArea->width, 0);
 		cairo_set_line_width (pCairoContext, fLineWidth);
-		cairo_set_source_rgba (pCairoContext, myDocksParam.fLineColor[0], myDocksParam.fLineColor[1], myDocksParam.fLineColor[2], myDocksParam.fLineColor[3]);
 		cairo_stroke (pCairoContext);
 
 		cairo_new_path (pCairoContext);
 		cairo_move_to (pCairoContext, fDockOffsetX, (pDock->container.bDirectionUp ? iHeight - fLineWidth / 2 : pDock->iDecorationsHeight + 1.5 * fLineWidth));
 		cairo_rel_line_to (pCairoContext, pArea->width, 0);
 		cairo_set_line_width (pCairoContext, fLineWidth);
-		cairo_set_source_rgba (pCairoContext, myDocksParam.fLineColor[0], myDocksParam.fLineColor[1], myDocksParam.fLineColor[2], myDocksParam.fLineColor[3]);
 	}
 	else
 	{
 		cairo_move_to (pCairoContext, fDockOffsetX - fLineWidth / 2, fDockOffsetY);
 		cairo_rel_line_to (pCairoContext, 0, pArea->height);
 		cairo_set_line_width (pCairoContext, fLineWidth);
-		cairo_set_source_rgba (pCairoContext, myDocksParam.fLineColor[0], myDocksParam.fLineColor[1], myDocksParam.fLineColor[2], myDocksParam.fLineColor[3]);
 		cairo_stroke (pCairoContext);
 
 		cairo_new_path (pCairoContext);
 		cairo_move_to (pCairoContext, (pDock->container.bDirectionUp ? iHeight - fLineWidth / 2 : pDock->iDecorationsHeight + 1.5 * fLineWidth), fDockOffsetY);
 		cairo_rel_line_to (pCairoContext, 0, pArea->height);
 		cairo_set_line_width (pCairoContext, fLineWidth);
-		cairo_set_source_rgba (pCairoContext, myDocksParam.fLineColor[0], myDocksParam.fLineColor[1], myDocksParam.fLineColor[2], myDocksParam.fLineColor[3]);
 	}
 	cairo_stroke (pCairoContext);
 
@@ -433,28 +413,35 @@ static void cd_render_optimized_default (cairo_t *pCairoContext, CairoDock *pDoc
 
 static void _draw_flat_separator_opengl (Icon *icon, CairoDock *pDock, G_GNUC_UNUSED double fDockMagnitude)
 {
-	if (s_iFlatSeparatorTexture == 0)
-		return;
-	
-	double fSizeX = icon->fWidth * icon->fScale, fSizeY = icon->fHeight * icon->fScale;
-	double rx = .4*fSizeX;
-	double ry = .8*fSizeY;
-	
-	_cairo_dock_enable_texture ();
+	double fSizeX = icon->fWidth * icon->fScale, fSizeY = icon->fHeight;
+	if (myIconsParam.bSeparatorUseDefaultColors)
+		gldi_style_colors_set_separator_color (NULL);
+	else
+		gldi_color_set_opengl (&myIconsParam.fSeparatorColor);
+	glPolygonMode (GL_FRONT, GL_LINE);
+	glEnable (GL_LINE_SMOOTH);
+	glHint (GL_LINE_SMOOTH_HINT, GL_NICEST);
+	glEnable (GL_BLEND);
 	_cairo_dock_set_blend_alpha ();
-	glColor4f (myIconsParam.fSeparatorColor[0], myIconsParam.fSeparatorColor[1], myIconsParam.fSeparatorColor[2], myIconsParam.fSeparatorColor[3]);
+	glLineWidth(myDocksParam.iDockLineWidth);
 	
 	if (pDock->container.bIsHorizontal)
 	{
-		glTranslatef (icon->fDrawX + fSizeX/2, pDock->container.iHeight - icon->fDrawY - fSizeY/2, 0.);
-		_cairo_dock_apply_texture_at_size (s_iFlatSeparatorTexture, rx, ry);
+		glTranslatef (icon->fDrawX + fSizeX/2, pDock->container.iHeight - icon->fDrawY - icon->fHeight * icon->fScale + fSizeY/2, 0.);  // must be before the glBegin()
+		glBegin(GL_LINES);
+		glVertex3f(0., -.5*fSizeY, 0.);
+		glVertex3f(0.,  .5*fSizeY, 0.);
 	}
 	else
 	{
 		glTranslatef (icon->fDrawY + fSizeY/2, pDock->container.iWidth - (icon->fDrawX + fSizeX/2), 0.);
-		_cairo_dock_apply_texture_at_size (s_iFlatSeparatorTexture, ry, rx);
+		glBegin(GL_LINES);
+		glVertex3f(-.5*fSizeY, 0., 0.);
+		glVertex3f( .5*fSizeY, 0., 0.);
 	}
-	_cairo_dock_disable_texture ();
+	glEnd();
+	glDisable (GL_LINE_SMOOTH);
+	glDisable (GL_BLEND);
 }
 
 static void _draw_physical_separator_opengl (Icon *icon, CairoDock *pDock, G_GNUC_UNUSED double fDockMagnitude)
@@ -478,7 +465,10 @@ static void _draw_physical_separator_opengl (Icon *icon, CairoDock *pDock, G_GNU
 		glEnd();
 		
 		_cairo_dock_set_blend_alpha ();
-		glColor4f (myDocksParam.fLineColor[0], myDocksParam.fLineColor[1], myDocksParam.fLineColor[2], myDocksParam.fLineColor[3]);
+		if (myDocksParam.bUseDefaultColors)
+			gldi_style_colors_set_line_color (NULL);
+		else
+			gldi_color_set_opengl (&myDocksParam.fLineColor);
 		glPolygonMode(GL_FRONT, GL_LINE);
 		
 		if (! pDock->container.bDirectionUp)
@@ -505,7 +495,10 @@ static void _draw_physical_separator_opengl (Icon *icon, CairoDock *pDock, G_GNU
 		glEnd();
 		
 		_cairo_dock_set_blend_alpha ();
-		glColor4f (myDocksParam.fLineColor[0], myDocksParam.fLineColor[1], myDocksParam.fLineColor[2], myDocksParam.fLineColor[3]);
+		if (myDocksParam.bUseDefaultColors)
+			gldi_style_colors_set_line_color (NULL);
+		else
+			gldi_color_set_opengl (&myDocksParam.fLineColor);
 		glPolygonMode(GL_FRONT, GL_LINE);
 		
 		if (pDock->container.bDirectionUp)
@@ -535,9 +528,11 @@ static void _cairo_dock_draw_separator_opengl (Icon *icon, CairoDock *pDock, dou
 static void cd_render_opengl_default (CairoDock *pDock)
 {
 	//\_____________ On definit notre rectangle.
-	double fLineWidth = myDocksParam.iDockLineWidth;
+	double fLineWidth = (myDocksParam.bUseDefaultColors ? myStyleParam.iLineWidth : myDocksParam.iDockLineWidth);
 	double fMargin = myDocksParam.iFrameMargin;
-	double fRadius = (pDock->iDecorationsHeight + fLineWidth - 2 * myDocksParam.iDockRadius > 0 ? myDocksParam.iDockRadius : (pDock->iDecorationsHeight + fLineWidth) / 2 - 1);
+	double fRadius = (myDocksParam.bUseDefaultColors ? myStyleParam.iCornerRadius : myDocksParam.iDockRadius);
+	if (pDock->iDecorationsHeight + fLineWidth - 2 * fRadius < 0)
+		fRadius = (pDock->iDecorationsHeight + fLineWidth) / 2 - 1;
 	double fExtraWidth = 2 * fRadius + fLineWidth;
 	double fDockWidth;
 	double fFrameHeight = pDock->iDecorationsHeight + fLineWidth;
@@ -565,6 +560,9 @@ static void cd_render_opengl_default (CairoDock *pDock)
 	
 	fDockOffsetY = pDock->iDecorationsHeight + 1.5 * fLineWidth;
 	
+	fDockOffsetX = floor (fDockOffsetX);  // round values so that left and right edges are pixel-aligned
+	fDockWidth = floor (fDockWidth);
+	
 	double fDockMagnitude = cairo_dock_calculate_magnitude (pDock->iMagnitudeIndex);
 	
 	//\_____________ On genere les coordonnees du contour.
@@ -573,7 +571,7 @@ static void cd_render_opengl_default (CairoDock *pDock)
 	//\_____________ On remplit avec le fond.
 	glPushMatrix ();
 	cairo_dock_set_container_orientation_opengl (CAIRO_CONTAINER (pDock));
-	glTranslatef (fDockOffsetX + (fDockWidth+2*fRadius)/2,
+	glTranslatef (fDockOffsetX + (fDockWidth+2*fRadius)/2 + .5,  // +.5 so that left and right edges are pixel-aligned
 		fDockOffsetY - fFrameHeight/2,
 		0.);
 	
@@ -591,7 +589,10 @@ static void cd_render_opengl_default (CairoDock *pDock)
 	if (fLineWidth != 0)
 	{
 		glLineWidth (fLineWidth);
-		glColor4f (myDocksParam.fLineColor[0], myDocksParam.fLineColor[1], myDocksParam.fLineColor[2], myDocksParam.fLineColor[3]);
+		if (myDocksParam.bUseDefaultColors)
+			gldi_style_colors_set_line_color (NULL);
+		else
+			gldi_color_set_opengl (&myDocksParam.fLineColor);
 		_cairo_dock_set_blend_alpha ();
 		cairo_dock_stroke_gl_path (pFramePath, TRUE);
 	}
@@ -688,10 +689,4 @@ void cairo_dock_register_default_renderer (void)
 	pDefaultRenderer->cDisplayedName = gettext (CAIRO_DOCK_DEFAULT_RENDERER_NAME);
 	
 	cairo_dock_register_renderer (CAIRO_DOCK_DEFAULT_RENDERER_NAME, pDefaultRenderer);
-	
-	// when and only when the current theme is unloaded, the main dock is destroyed, and we must release our data.
-	gldi_object_register_notification (&myDockObjectMgr,
-		NOTIFICATION_DESTROY,  // on ne fait cette fonction qu'une fois, donc on peut s'enregistrer ici.
-		(GldiNotificationFunc) cd_default_view_free_data,
-		GLDI_RUN_AFTER, NULL);
 }
