@@ -17,17 +17,20 @@
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include <gdk/gdkx.h>
+#include "gldi-config.h"
+#ifdef HAVE_X11
+#include <X11/Xlib.h>
+#include <X11/Xatom.h>
+#endif
 
 #include "cairo-dock-icon-factory.h"
-#include "cairo-dock-X-utilities.h"
+#include "cairo-dock-desktop-manager.h"
 #include "cairo-dock-log.h"
 #include "cairo-dock-dbus.h"
-#include "cairo-dock-notifications.h"
+#include "cairo-dock-X-utilities.h"  // cairo_dock_get_X_display
 #include "cairo-dock-icon-factory.h"
 #include "cairo-dock-dock-factory.h"
-#include "cairo-dock-X-manager.h"
-#include "cairo-dock-X-utilities.h"
+#include "cairo-dock-windows-manager.h"  // gldi_window_get_id
 #include "cairo-dock-class-manager.h"
 #include "cairo-dock-icon-manager.h"  // myIconsParam.fAmplitude
 #include "cairo-dock-kwin-integration.h"
@@ -64,24 +67,34 @@ static gboolean present_windows (void)
 
 static gboolean present_class (const gchar *cClass)
 {
+	#ifdef HAVE_X11
 	cd_debug ("%s (%s)", __func__, cClass);
 	GList *pIcons = (GList*)cairo_dock_list_existing_appli_with_class (cClass);
 	if (pIcons == NULL)
 		return FALSE;
+	Display *dpy = cairo_dock_get_X_display ();
+	if (! dpy)
+		return FALSE;
 	
-	Atom aPresentWindows = XInternAtom (cairo_dock_get_Xdisplay(), "_KDE_PRESENT_WINDOWS_GROUP", False);
+	Atom aPresentWindows = XInternAtom (dpy, "_KDE_PRESENT_WINDOWS_GROUP", False);
 	Window *data = g_new0 (Window, g_list_length (pIcons));
 	Icon *pOneIcon;
+	GldiWindowActor *xactor;
 	GList *ic;
 	int i = 0;
 	for (ic = pIcons; ic != NULL; ic = ic->next)
 	{
 		pOneIcon = ic->data;
-		data[i++] = pOneIcon->Xid;
+		xactor = (GldiWindowActor*)pOneIcon->pAppli;
+		data[i++] = gldi_window_get_id (xactor);
 	}
-	XChangeProperty(cairo_dock_get_Xdisplay(), data[0], aPresentWindows, aPresentWindows, 32, PropModeReplace, (unsigned char *)data, i);
+	XChangeProperty(dpy, data[0], aPresentWindows, aPresentWindows, 32, PropModeReplace, (unsigned char *)data, i);
 	g_free (data);
 	return TRUE;
+	#else
+	(void)cClass;  // avoid unused parameter
+	return FALSE;
+	#endif
 }
 
 static gboolean present_desktops (void)
@@ -162,9 +175,9 @@ static void _set_one_icon_geometry_for_window_manager (Icon *icon, CairoDock *pD
 		
 	}
 	
-	Atom atom = XInternAtom (cairo_dock_get_Xdisplay(), "_KDE_WINDOW_PREVIEW", False);
+	Atom atom = XInternAtom (gdk_x11_get_default_xdisplay(), "_KDE_WINDOW_PREVIEW", False);
 	Window Xid = gldi_container_get_Xid (CAIRO_CONTAINER (pDock));
-	XChangeProperty (cairo_dock_get_Xdisplay(), Xid, atom, atom, 32, PropModeReplace, (const unsigned char*)data, 1+6);
+	XChangeProperty (gdk_x11_get_default_xdisplay(), Xid, atom, atom, 32, PropModeReplace, (const unsigned char*)data, 1+6);
 }
 */
 /* Not used
@@ -178,12 +191,12 @@ static gboolean _on_enter_icon (gpointer pUserData, Icon *pIcon, CairoDock *pDoc
 	{
 		_set_one_icon_geometry_for_window_manager (NULL, pDock);
 	}
-	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
+	return GLDI_NOTIFICATION_LET_PASS;
 }
 */
 static void _register_kwin_backend (void)
 {
-	CairoDockWMBackend *p = g_new0 (CairoDockWMBackend, 1);
+	GldiDesktopManagerBackend *p = g_new0 (GldiDesktopManagerBackend, 1);
 	
 	p->present_class = present_class;
 	p->present_windows = present_windows;
@@ -191,20 +204,20 @@ static void _register_kwin_backend (void)
 	p->show_widget_layer = show_widget_layer;
 	p->set_on_widget_layer = NULL;  // the Dashboard is not a real widget layer :-/
 	
-	cairo_dock_wm_register_backend (p);
+	gldi_desktop_manager_register_backend (p);
 	
-	/*cairo_dock_register_notification_on_object (&myContainersMgr,
+	/*gldi_object_register_notification (&myContainerObjectMgr,
 		NOTIFICATION_ENTER_ICON,
-		(CairoDockNotificationFunc) _on_enter_icon,
-		CAIRO_DOCK_RUN_FIRST, NULL);*/
+		(GldiNotificationFunc) _on_enter_icon,
+		GLDI_RUN_FIRST, NULL);*/
 }
 
 static void _unregister_kwin_backend (void)
 {
-	cairo_dock_wm_register_backend (NULL);
-	/*cairo_dock_remove_notification_func_on_object (&myContainersMgr,
+	//cairo_dock_wm_register_backend (NULL);
+	/*gldi_object_remove_notification (&myContainerObjectMgr,
 		NOTIFICATION_ENTER_ICON,
-		(CairoDockNotificationFunc) _on_enter_icon, NULL);*/
+		(GldiNotificationFunc) _on_enter_icon, NULL);*/
 }
 
 static void _on_kwin_owner_changed (G_GNUC_UNUSED const gchar *cName, gboolean bOwned, G_GNUC_UNUSED gpointer data)
